@@ -26,13 +26,13 @@
  */
 
 define('INTERNAL', 1);
-define('MENUITEM', 'settings/activitypreferences');
+define('MENUITEM', 'settings/notifications');
 define('SECTION_PLUGINTYPE', 'core');
 define('SECTION_PLUGINNAME', 'account');
-define('SECTION_PAGE', 'activitypreferences');
+define('SECTION_PAGE', 'notifications');
 
 require(dirname(dirname(dirname(dirname(__FILE__)))) . '/init.php');
-define('TITLE', get_string('activityprefs'));
+define('TITLE', get_string('notifications'));
 require_once('pieforms/pieform.php');
 require_once(get_config('libroot') . 'activity.php');
 
@@ -61,6 +61,10 @@ foreach ($activitytypes as $type) {
     else {
         $section = 'activity';
     }
+    if ($dv == 'email' && !isset($maildisabledmsg) && get_account_preference($USER->get('id'),'maildisabled')) {
+        $SESSION->add_error_msg(get_string('maildisableddescription', 'account', get_config('wwwroot') . 'account/'), false);
+        $maildisabledmsg = true;
+    }
     $elements['activity_'.$type->id] = array(
         'defaultvalue' => $dv,
         'type' => 'select',
@@ -94,10 +98,10 @@ $prefsform = pieform(array(
 ));
 
 $smarty = smarty();
-$smarty->assign('prefsdescr', get_string('prefsdescr', 'activity'));
+$smarty->assign('pagedescription', get_string('prefsdescr', 'activity'));
 $smarty->assign('form', $prefsform);
-$smarty->assign('PAGEHEADING', hsc(get_string('activityprefs')));
-$smarty->display('account/activity/preferences/index.tpl');
+$smarty->assign('PAGEHEADING', TITLE);
+$smarty->display('form.tpl');
 
 function activityprefs_submit(Pieform $form, $values) {
     global $activitytypes, $admintypes, $USER;
@@ -113,6 +117,3 @@ function activityprefs_submit(Pieform $form, $values) {
     }
     $form->json_reply(PIEFORM_OK, get_string('prefssaved', 'account'));
 }
-
-
-?>
