@@ -32,12 +32,26 @@ define('INSTALLER', 1);
 require(dirname(dirname(__FILE__)).'/init.php');
 require(get_config('libroot') . 'upgrade.php');
 
+if (param_integer('finished', 0)) {
+    foreach (site_warnings() as $w) {
+        $SESSION->add_error_msg($w);
+    }
+    if ($missing = check_installed_plugins()) {
+        $message = get_string('installedpluginsmissing', 'admin') . ': ';
+        $message .= join(', ', $missing) . '.';
+        $message .= '  ' . get_string('ensurepluginsexist', 'admin', get_config('docroot'));
+        $SESSION->add_error_msg($message);
+    }
+    redirect();
+}
+
 $smarty = smarty();
 
 $upgrades = check_upgrades();
 if (!empty($upgrades['core']->install)) {
     define('TITLE', get_string('installation', 'admin'));
     $smarty->assign('upgradeheading', get_string('performinginstallation', 'admin'));
+    log_info('Starting Mahara installation...');
 }
 else {
     define('TITLE', get_string('upgrades', 'admin'));
@@ -129,9 +143,14 @@ $js = <<< EOJS
                             else {
                                 message = {$successstring};
                             }
-                            message += data.newversion;
+                            message += data.newversion ? data.newversion : '?';
                         }
                         $(data.key).innerHTML = '<img src="{$successicon}" alt=":)" />  ' + message;
+                        if (data.feedback) {
+                            var feedback_element = DIV();
+                            feedback_element.innerHTML = data.feedback;
+                            appendChildNodes('messages', feedback_element);
+                        }
                         processNext();
                     }
                     else {
@@ -164,6 +183,25 @@ if (isset($upgrades['core'])) {
 }
 $smarty->display('admin/upgrade.tpl');
 
+function check_installed_plugins() {
+    $missing = array();
 
+    foreach (plugin_types() as $plugintype) {
+        if ($installed = plugins_installed($plugintype, true)) {
+            foreach ($installed as $i) {
+                $key = $i->name;
+                if ($plugintype == 'blocktype') {
+                    $key = blocktype_single_to_namespaced($i->name, $i->artefactplugin);
+                }
+                try {
+                    safe_require($plugintype, $key);
+                }
+                catch (SystemException $e) {
+                    $missing[] = "$plugintype:$key";
+                }
+            }
+        }
+    }
 
-?>
+    return $missing;
+}
