@@ -35,6 +35,8 @@ define('SECTION_PLUGINNAME', 'admin');
 require_once('pieforms/pieform.php');
 require_once('institution.php');
 
+$TRANSPORTER = null;
+
 if ($USER->get('admin')) {
     $authinstances = auth_get_auth_instances();
 }
@@ -86,7 +88,10 @@ $elements = array(
     'username' => array(
         'type' => 'text',
         'title' => get_string('username'),
-        'rules' => array('required' => true),
+        'rules' => array(
+            'required' => true,
+            'maxlength' => 236,
+        ),
     ),
     'password' => array(
         'type' => 'text',
@@ -128,6 +133,9 @@ $elements = array(
     ),
 );
 
+if (!$USER->get('admin')) {
+    unset ($elements['authinstance']['defaultvalue']);
+}
 
 $form = pieform(array(
     'name'       => 'adduser',
@@ -141,7 +149,7 @@ $form = pieform(array(
 
 
 function adduser_validate(Pieform $form, $values) {
-    global $USER, $LEAP2A_FILE;
+    global $USER, $TRANSPORTER;
 
     $authobj = AuthFactory::create($values['authinstance']);
 
@@ -167,8 +175,15 @@ function adduser_validate(Pieform $form, $values) {
     $email     = $values['email'];
     $password  = $values['password'];
 
-    if (method_exists($authobj, 'is_username_valid') && !$authobj->is_username_valid($username)) {
-        $form->set_error('username', get_string('usernameinvalidform', 'auth.internal'));
+    if (method_exists($authobj, 'is_username_valid_admin')) {
+        if (!$authobj->is_username_valid_admin($username)) {
+            $form->set_error('username', get_string('usernameinvalidadminform', 'auth.internal'));
+        }
+    }
+    else if (method_exists($authobj, 'is_username_valid')) {
+        if (!$authobj->is_username_valid($username)) {
+            $form->set_error('username', get_string('usernameinvalidform', 'auth.internal'));
+        }
     }
     if (!$form->get_error('username') && record_exists_select('usr', 'LOWER(username) = ?', strtolower($username))) {
         $form->set_error('username', get_string('usernamealreadytaken', 'auth.internal'));
@@ -188,60 +203,33 @@ function adduser_validate(Pieform $form, $values) {
             return;
         }
 
-        $date = time();
-        $nicedate = date('Y/m/d h:i:s', $date);
-        $niceuser = preg_replace('/[^a-zA-Z0-9_-]/', '-', $values['username']);
-
-        $uploaddir = get_config('dataroot') . 'import/' . $niceuser . '-' . $date . '/';
-        $filename = $uploaddir . $values['leap2afile']['name'];
-        check_dir_exists($uploaddir);
-        if (!move_uploaded_file($values['leap2afile']['tmp_name'], $filename)) {
-            $form->set_error('leap2afile', get_string('failedtoobtainuploadedleapfile', 'admin'));
-        }
-
         if ($values['leap2afile']['type'] == 'application/octet-stream') {
             require_once('file.php');
-            $mimetype = file_mime_type($filename);
+            $mimetype = file_mime_type($values['leap2afile']['tmp_name']);
         }
         else {
             $mimetype = $values['leap2afile']['type'];
         }
+        $date = time();
+        $niceuser = preg_replace('/[^a-zA-Z0-9_-]/', '-', $values['username']);
+        safe_require('import', 'leap');
+        $fakeimportrecord = (object)array(
+            'data' => array(
+                'importfile'     => $values['leap2afile']['tmp_name'],
+                'importfilename' => $values['leap2afile']['name'],
+                'importid'       => $niceuser . '-' . $date,
+                'mimetype'       => $mimetype,
+            )
+        );
 
-        safe_require('artefact', 'file');
-        $ziptypes = PluginArtefactFile::get_mimetypes_from_description('zip');
-
-        if (in_array($mimetype, $ziptypes)) {
-            // Unzip the file
-            $command = sprintf('%s %s %s %s',
-                escapeshellcmd(get_config('pathtounzip')),
-                escapeshellarg($filename),
-                get_config('unzipdirarg'),
-                escapeshellarg($uploaddir)
-            );
-            $output = array();
-            exec($command, $output, $returnvar);
-            if ($returnvar != 0) {
-                log_debug("unzip command failed with return value $returnvar");
-                // Let's make it obvious if the cause is obvious :)
-                if ($returnvar == 127) {
-                    log_debug("This means that 'unzip' isn't installed, or the config var \$cfg->pathtounzip is not"
-                        . " pointing at unzip (see Mahara's file lib/config-defaults.php)");
-                }
-                $form->set_error('leap2afile', get_string('failedtounzipleap2afile', 'admin'));
-                return;
-            }
-
-            $filename = $uploaddir . 'leap2a.xml';
-            if (!is_file($filename)) {
-                $form->set_error('leap2afile', get_string('noleap2axmlfiledetected', 'admin'));
-                return;
-            }
-
+        $TRANSPORTER = new LocalImporterTransport($fakeimportrecord);
+        try {
+            $TRANSPORTER->extract_file();
+            PluginImportLeap::validate_transported_data($TRANSPORTER);
         }
-        else if ($mimetype != 'text/xml') {
-            $form->set_error('leap2afile', get_string('fileisnotaziporxmlfile', 'admin'));
+        catch (Exception $e) {
+            $form->set_error('leap2afile', $e->getMessage());
         }
-        $LEAP2A_FILE = $filename;
     }
     else {
         if (!$form->get_error('firstname') && !preg_match('/\S/', $firstname)) {
@@ -266,7 +254,7 @@ function adduser_validate(Pieform $form, $values) {
 }
 
 function adduser_submit(Pieform $form, $values) {
-    global $USER, $SESSION, $LEAP2A_FILE;
+    global $USER, $SESSION, $TRANSPORTER;
     db_begin();
 
     ini_set('max_execution_time', 180);
@@ -305,31 +293,25 @@ function adduser_submit(Pieform $form, $values) {
 
     if (isset($values['leap2afile'])) {
         // And we're good to go
-        $filename = substr($LEAP2A_FILE, strlen(get_config('dataroot')));
-        $logfile  = dirname($LEAP2A_FILE) . '/import.log';
-        require_once(get_config('docroot') . 'import/lib.php');
-        safe_require('import', 'leap');
-        $importer = PluginImport::create_importer(null, (object)array(
+        $importdata = (object)array(
             'token'      => '',
-            //'host'       => '',
             'usr'        => $user->id,
             'queue'      => (int)!(PluginImport::import_immediately_allowed()), // import allowed straight away? Then don't queue
             'ready'      => 0, // maybe 1?
             'expirytime' => db_format_timestamp(time()+(60*60*24)),
             'format'     => 'leap',
-            'data'       => array('filename' => $filename),
             'loglevel'   => PluginImportLeap::LOG_LEVEL_VERBOSE,
             'logtargets' => LOG_TARGET_FILE,
-            'logfile'    => $logfile,
             'profile'    => true,
-        ));
+        );
+        $importer = PluginImport::create_importer(null, $TRANSPORTER, $importdata);
 
         try {
             $importer->process();
-            log_info("Imported user account $user->id from leap2a file, see $logfile for a full log");
+            log_info("Imported user account $user->id from Leap2A file, see " . $importer->get('logfile') . ' for a full log');
         }
         catch (ImportException $e) {
-            log_info("LEAP2A import failed: " . $e->getMessage());
+            log_info("Leap2A import failed: " . $e->getMessage());
             die_info(get_string('leap2aimportfailed', 'admin'));
         }
 
@@ -352,13 +334,24 @@ function adduser_submit(Pieform $form, $values) {
         }
     }
 
+    // Add salt and encrypt the pw, if the auth instance allows for it
+    $userobj = new User();
+    $userobj = $userobj->find_by_id($user->id);
+    $authobj = AuthFactory::create($user->authinstance);
+    if (method_exists($authobj, 'change_password')) {
+        $authobj->change_password($userobj, $user->password);
+    } else {
+        $userobj->password = '';
+        $userobj->salt = auth_get_random_salt();
+        $userobj->commit();
+    }
+    unset($userobj, $authobj);
+
     $SESSION->add_ok_msg(get_string('newusercreated', 'admin'));
     redirect('/admin/users/edit.php?id=' . $user->id);
 }
 
 $smarty = smarty(array('adminadduser'));
 $smarty->assign('form', $form);
-$smarty->assign('PAGEHEADING', hsc(TITLE));
+$smarty->assign('PAGEHEADING', TITLE);
 $smarty->display('admin/users/add.tpl');
-
-?>
