@@ -233,7 +233,5 @@ $smarty->assign('INLINEJAVASCRIPT', $js);
 $smarty->assign('usertypeselector', $usertypeselector);
 $smarty->assign('instructions', get_string('institutionusersinstructions'.$usertype, 'admin'));
 $smarty->assign('institutionusersform', $userlistform);
-$smarty->assign('PAGEHEADING', hsc(TITLE));
+$smarty->assign('PAGEHEADING', TITLE);
 $smarty->display('admin/users/institutionusers.tpl');
-
-?>
