@@ -123,49 +123,18 @@ function api_dummy_method($methodname, $argsarray, $functionname) {
 }
 
 function find_remote_user($username, $wwwroot) {
-    $institution = get_field('host', 'institution', 'wwwroot', $wwwroot);
+    $authinstances = auth_get_auth_instances_for_wwwroot($wwwroot);
 
-    if (false == $institution) {
-        // This should never happen, because if we don't know the host we'll
-        // already have exited
-        throw new XmlrpcServerException('Unknown error');
-    }
-
-    $authinstances = auth_get_auth_instances_for_institution($institution);
-    $candidates    = array();
-    $auths         = array();
-
-    $aiid = 'ai.id';
-    if (!is_mysql()) {
-        $aiid = 'CAST(ai.id AS TEXT)';
-    }
-    $sql = 'SElECT
-                ai.*
-            FROM
-                {auth_instance} ai,
-                {auth_instance} ai2,
-                {auth_instance_config} aic
-            WHERE
-                ai.id = ? AND
-                ai.institution = ? AND
-                ai2.institution = ai.institution AND
-                ' . $aiid . ' = aic.value AND
-                aic.field = \'parent\' AND
-                aic.instance = ai2.id AND
-                ai2.authname = \'xmlrpc\'';
+    $candidates = array();
 
     foreach ($authinstances as $authinstance) {
         if ($authinstance->authname != 'xmlrpc') {
-            $records = get_records_sql_array($sql, array($authinstance->id, $institution));
-            if (false == $records) {
-                continue;
-            }
+            continue;
         }
         try {
             $user = new User;
             $user->find_by_instanceid_username($authinstance->id, $username, true);
-            $candidates[$user->id] = $user;
-            $auths[] = $authinstance->id;
+            $candidates[$authinstance->id] = $user;
         } catch (Exception $e) {
             // we don't care
             continue;
@@ -177,7 +146,7 @@ function find_remote_user($username, $wwwroot) {
     }
 
     safe_require('auth', 'xmlrpc');
-    return array(array_pop($candidates), new AuthXmlrpc(array_pop($auths)));
+    return array(end($candidates), new AuthXmlrpc(key($candidates)));
 }
 
 function fetch_user_image($username) {
@@ -275,6 +244,140 @@ function user_authorise($token, $useragent) {
     return $userdata;
 }
 
+/**
+ * Retrieve a file for a user calling this function
+ * The file is encoded in base64
+ * @global object $REMOTEWWWROOT
+ * @param string $username
+ * @param integer $id Artefact to send
+ * @return array The file content encoded in base 64 + file name
+ */
+function get_file($username, $id) {
+
+    global $REMOTEWWWROOT;
+
+    //check that the user exists
+    list ($user, $authinstance) = find_remote_user($username, $REMOTEWWWROOT);
+    if (!$user) {
+        throw new ExportException("Could not find user $username for $REMOTEWWWROOT");
+    }
+
+    //check that the user is owner of the requested file
+    safe_require('artefact', 'file');
+    $file = artefact_instance_from_id($id);
+    if (!record_exists('artefact', 'owner', $user->id, 'id', $id)) {
+        throw new ExportException("You are not allowed to get this file.");
+    }
+
+    //retrieve the content and send the file encoded in base 64
+    $filecontent = base64_encode(file_get_contents($file->get_path()));
+    return array($filecontent, $file->name);
+}
+
+
+/**
+ * Retrieve list of files/folders matching the search
+ * @global object $REMOTEWWWROOT
+ * @param string $username
+ * @param string $search
+ * @return array list of files/folders matching the search
+ */
+function search_folders_and_files($username, $search='') {
+
+    global $REMOTEWWWROOT;
+
+    //check that the user exists
+    list ($user, $authinstance) = find_remote_user($username, $REMOTEWWWROOT);
+    if (!$user) {
+        throw new ExportException("Could not find user $username for $REMOTEWWWROOT");
+    }
+
+    $list = array();
+    safe_require('artefact', 'file');
+    $filetypes = array_diff(PluginArtefactFile::get_artefact_types(), array('profileicon'));
+    foreach ($filetypes as $k => $v) {
+        if ($v == 'folder') {
+            unset($filetypes[$k]);
+        }
+    }
+    $filetypesql = "('" . join("','", $filetypes) . "')";
+
+    $ownersql = artefact_owner_sql($user->id);
+
+    //retrieve folders and files of a specific Mahara folder
+    $sql = "SELECT
+                *
+            FROM
+                {artefact} a
+            LEFT JOIN {artefact_tag} at ON (at.artefact = a.id)
+            WHERE
+                $ownersql
+                AND
+                (a.title like ? OR at.tag like ?)";
+    $list =  array(
+
+            'files'   => get_records_sql_array($sql." AND artefacttype IN $filetypesql ORDER BY title", array('%'.$search.'%','%'.$search.'%')),
+            'folders' => get_records_sql_array($sql." AND artefacttype = 'folder' ORDER BY title", array('%'.$search.'%','%'.$search.'%'))
+    );
+
+    return $list;
+}
+
+/**
+ * Retrieve file list in a folder
+ * @global object $REMOTEWWWROOT
+ * @param string $username
+ * @param integer $folderid  folder to browse
+ * @return array The complete folder path + list of files for a specific Mahara folder
+ */
+function get_folder_files($username, $folderid) {
+
+    global $REMOTEWWWROOT;
+
+    //check that the user exists
+    list ($user, $authinstance) = find_remote_user($username, $REMOTEWWWROOT);
+    if (!$user) {
+        throw new ExportException("Could not find user $username for $REMOTEWWWROOT");
+    }
+
+    $list = array();
+    safe_require('artefact', 'file');
+    $filetypes = array_diff(PluginArtefactFile::get_artefact_types(), array('profileicon'));
+    foreach ($filetypes as $k => $v) {
+        if ($v == 'folder') {
+            unset($filetypes[$k]);
+        }
+    }
+    $filetypesql = "('" . join("','", $filetypes) . "')";
+
+    $ownersql = artefact_owner_sql($user->id);
+
+    $folderpath = array(); //the complete folder path (some client could need it)
+    if (!empty($folderid)) {
+        $pathsql = " AND parent = $folderid";
+
+        //build the path
+        $parentids = artefact_get_parents_for_cache($folderid); //the closest parent is on the first key
+                                                            //the further parent is on the last key
+        foreach ($parentids as $id => $dump) {
+            $artefact = get_record('artefact', 'id', $id);
+            array_unshift($folderpath, array('path' => $artefact->id, 'name' => $artefact->title));
+        }
+
+    } else {
+        $pathsql = "AND parent IS NULL";
+    }
+    array_unshift($folderpath, array('path' => null, 'name' => 'Root'));
+
+    //retrieve folders and files of a specific Mahara folder
+    $list =  array(
+            'files'   => get_records_select_array('artefact', "artefacttype IN $filetypesql AND $ownersql $pathsql", array(),'title'),
+            'folders' => get_records_select_array('artefact', "artefacttype = 'folder' AND $ownersql $pathsql", array(),'title')
+    );
+
+    return array($folderpath, $list);
+}
+
 function send_content_intent($username) {
     global $REMOTEWWWROOT;
     require_once(get_config('docroot') . 'import/lib.php');
@@ -320,19 +423,32 @@ function send_content_ready($token, $username, $format, $importdata, $fetchnow=f
         throw new ImportException(null, "Queue record has expired");
     }
 
-    $queue->format = $format;
     $class = null;
     try {
         $class = PluginImport::class_from_format($format);
     } catch (Exception $e) {
         throw new ImportException(null, "Invalid format $format");
     }
+
+    $queue->format = $format;
+    if ($class == 'PluginImportLeap') {
+        // don't import persondata over mnet
+        // because it will just silently overwrite stuff
+        // which is not really desirable.
+        $queue->loglevel = get_config('leapovermnetloglevel');
+        $importdata['skippersondata'] = true;
+    }
+    $queue->data = serialize($importdata);
+    update_record('import_queue', $queue);
+    $tr = new MnetImporterTransport($queue);
     try {
-        call_static_method($class, 'validate_import_data', $importdata);
+        $tr->validate_import_data();
     } catch (Exception $e) {
         throw new ImportException(null, 'Invalid importdata: ' . $e->getMessage());
     }
 
+
+
     if (!array_key_exists('totalsize', $importdata)) {
         throw new ImportException(null, 'Invalid importdata: missing totalsize');
     }
@@ -343,15 +459,17 @@ function send_content_ready($token, $username, $format, $importdata, $fetchnow=f
         throw $e;
     }
 
-    $queue->data = serialize($importdata);
-
-    update_record('import_queue', $queue);
 
     $result = new StdClass;
     if ($fetchnow && PluginImport::import_immediately_allowed()) {
         // either immediately spawn a curl request to go fetch the file
-        $importer = PluginImport::create_importer($queue->id, $queue);
+        $importer = PluginImport::create_importer($queue->id, $tr, $queue);
         $importer->prepare();
+        try {
+            $importer->validate_transported_data($tr);
+        } catch (Exception $e) {
+            throw new ImportException(null, 'Invalid importdata: ' . $e->getMessage());
+        }
         $importer->process();
         $importer->cleanup();
         delete_records('import_queue', 'id', $queue->id);
@@ -487,6 +605,7 @@ function submit_view_for_assessment($username, $viewid) {
     $view = new View($viewid);
 
     $view->set('submittedhost', $authinstance->config['wwwroot']);
+    $view->set('submittedtime', db_format_timestamp(time()));
 
     // Create secret key
     $access = View::new_token($view->get('id'), false);
@@ -508,6 +627,12 @@ function submit_view_for_assessment($username, $viewid) {
         }
     }
 
+    $view->commit();
+
+    // Lock view contents
+    require_once(get_config('docroot') . 'artefact/lib.php');
+    ArtefactType::update_locked($user->get('id'));
+
     return $data;
 }
 
@@ -529,6 +654,7 @@ function release_submitted_view($viewid, $assessmentdata, $teacherusername) {
 
     // Release the view for editing
     $view->set('submittedhost', null);
+    $view->set('submittedtime', null);
     $view->commit();
     db_commit();
 }
@@ -734,7 +860,7 @@ function get_peer($wwwroot, $cache=true) {
 
 function get_peer_from_instanceid($authinstanceid) {
     $sql = 'SELECT
-                h.*
+                h.wwwroot, h.name
             FROM
                 {auth_instance_config} aic,
                 {host} h
@@ -759,18 +885,8 @@ function xmldsig_envelope_strip(&$xml) {
     // Does the signature match the data and the public cert?
     $signature_verified = openssl_verify($payload, $signature, $peer->certificate);
 
-    if ($signature_verified == 1) {
-        // Parse the XML
-        try {
-            $xml = new SimpleXMLElement($payload);
-            return $payload;
-        } catch (Exception $e) {
-            throw new MaharaException('Signed payload is not a valid XML document', 6007);
-        }
-    }
-    else if ($signature_verified == 0) {
+    if ($signature_verified == 0) {
         // Maybe the remote host is using a new key?
-        //$new_public_key = get_public_key($wwwroot, $peer->application->name);
         // Make a dummy request so we'll be given a new key
         log_info("Signature verification for message from $wwwroot failed, checking to see if they have a new signature for us");
         require_once(get_config('docroot') . 'api/xmlrpc/client.php');
@@ -781,15 +897,15 @@ function xmldsig_envelope_strip(&$xml) {
         // Now use the new key and re-try verification
         $peer = get_peer($wwwroot, false);
         $signature_verified = openssl_verify($payload, $signature, $peer->certificate);
-        if ($signature_verified == 1) {
-            log_info("Succefully retrieved a new key for $wwwroot");
-            // Parse the XML
-            try {
-                $xml = new SimpleXMLElement($payload);
-                return $payload;
-            } catch (Exception $e) {
-                throw new MaharaException('Signed payload is not a valid XML document', 6007);
-            }
+    }
+
+    if ($signature_verified == 1) {
+        // Parse the XML
+        try {
+            $xml = new SimpleXMLElement($payload);
+            return $payload;
+        } catch (Exception $e) {
+            throw new MaharaException('Signed payload is not a valid XML document', 6007);
         }
     }
 
@@ -917,7 +1033,7 @@ return <<<EOF
         <Signature Id="MoodleSignature" xmlns="http://www.w3.org/2000/09/xmldsig#">
             <SignedInfo>
                 <CanonicalizationMethod Algorithm="http://www.w3.org/TR/2001/REC-xml-c14n-20010315"/>
-                <SignatureMethod Algorithm="http://www.w3.org/2000/09/xmldsig#dsa-sha1"/>
+                <SignatureMethod Algorithm="http://www.w3.org/2000/09/xmldsig#rsa-sha1"/>
                 <Reference URI="#XMLRPC-MSG">
                     <DigestMethod Algorithm="http://www.w3.org/2000/09/xmldsig#sha1"/>
                     <DigestValue>$digest</DigestValue>
@@ -1193,17 +1309,25 @@ class OpenSslRepo {
         // ensure we remove trailing slashes
         $dn["commonName"] = preg_replace(':/$:', '', $dn["commonName"]);
 
-        if (!$new_key = openssl_pkey_new()) {
+        $config = array();
+        $opensslcnf = get_config('opensslcnf');
+        if ($opensslcnf) {
+            $config['config'] = $opensslcnf;
+        } else {
+            $config = null;
+        }
+
+        if (!$new_key = openssl_pkey_new($config)) {
             throw new ConfigException(get_string('errorcouldnotgeneratenewsslkey', 'auth'));
         }
 
-        if (!$csr_rsc = openssl_csr_new($dn, $new_key, array('private_key_bits',2048))) {
+        if (!$csr_rsc = openssl_csr_new($dn, $new_key, $config)) {
             // This behaviour has been observed once before, on an ubuntu hardy box. 
             // The php5-openssl package was installed but somehow openssl 
             // wasn't.
             throw new ConfigException(get_string('errorcouldnotgeneratenewsslkey', 'auth'));
         }
-        $selfSignedCert = openssl_csr_sign($csr_rsc, null, $new_key, 365 /*days*/);
+        $selfSignedCert = openssl_csr_sign($csr_rsc, null, $new_key, 365 /*days*/, $config);
         unset($csr_rsc); // Free up the resource
 
         // We export our self-signed certificate to a string.
@@ -1212,7 +1336,7 @@ class OpenSslRepo {
 
         // Export your public/private key pair as a PEM encoded string. You
         // can protect it with an optional passphrase if you wish.
-        $export = openssl_pkey_export($new_key, $this->keypair['keypair_PEM'] /* , $passphrase */);
+        $export = openssl_pkey_export($new_key, $this->keypair['keypair_PEM'] , null /*$passphrase */, $config);
         openssl_pkey_free($new_key);
         unset($new_key); // Free up the resource
 
@@ -1321,4 +1445,3 @@ class PublicKey {
         return $this->{$name};
     }
 }
-?>
