@@ -46,7 +46,16 @@ class PluginBlocktypeRecentposts extends PluginBlocktype {
         $configdata = $instance->get('configdata');
 
         $result = '';
+        $limit = isset($configdata['count']) ? (int) $configdata['count'] : 10;
+
         if (!empty($configdata['artefactids'])) {
+            $before = 'TRUE';
+            if ($instance->get_view()->is_submitted()) {
+                if ($submittedtime = $instance->get_view()->get('submittedtime')) {
+                    // Don't display posts added after the submitted date.
+                    $before = "a.ctime < '$submittedtime'";
+                }
+            }
             $artefactids = implode(', ', array_map('db_quote', $configdata['artefactids']));
             if (!$mostrecent = get_records_sql_array(
             'SELECT a.title, ' . db_format_tsfield('a.ctime', 'ctime') . ', p.title AS parenttitle, a.id, a.parent
@@ -54,10 +63,11 @@ class PluginBlocktypeRecentposts extends PluginBlocktype {
                 JOIN {artefact} p ON a.parent = p.id
                 JOIN {artefact_blog_blogpost} ab ON (ab.blogpost = a.id AND ab.published = 1)
                 WHERE a.artefacttype = \'blogpost\'
-                AND a.parent IN ( ' . $artefactids . ' ) 
-                AND a.owner = (SELECT owner from {view} WHERE id = ?)
+                AND a.parent IN ( ' . $artefactids . ' )
+                AND a.owner = (SELECT "owner" from {view} WHERE id = ?)
+                AND ' . $before . '
                 ORDER BY a.ctime DESC
-                LIMIT 10', array($instance->get('view')))) {
+                LIMIT ' . $limit, array($instance->get('view')))) {
                 $mostrecent = array();
             }
             // format the dates
@@ -80,7 +90,15 @@ class PluginBlocktypeRecentposts extends PluginBlocktype {
     public static function instance_config_form($instance) {
         safe_require('artefact', 'blog');
         $configdata = $instance->get('configdata');
-        $elements = array(self::artefactchooser_element((isset($configdata['artefactids'])) ? $configdata['artefactids'] : null));
+        $elements = array(self::artefactchooser_element((isset($configdata['artefactids'])) ? $configdata['artefactids'] : null),
+            'count' => array(
+                'type' => 'text',
+                'title' => get_string('itemstoshow', 'blocktype.blog/recentposts'),
+                'defaultvalue' => isset($configdata['count']) ? $configdata['count'] : 10,
+                'size' => 3,
+            ),
+        );
+	
         return $elements;
     }
 
@@ -98,15 +116,6 @@ class PluginBlocktypeRecentposts extends PluginBlocktype {
         );
     }
 
-    /**
-     * Optional method. If specified, changes the order in which the artefacts are sorted in the artefact chooser.
-     *
-     * This is a valid SQL string for the ORDER BY clause. Fields you can sort on are as per the artefact table
-     */
-    public static function artefactchooser_get_sort_order() {
-        return 'title';
-    }
-
     public static function default_copy_type() {
         return 'nocopy';
     }
@@ -120,5 +129,3 @@ class PluginBlocktypeRecentposts extends PluginBlocktype {
     }
 
 }
-
-?>
