@@ -48,14 +48,20 @@ class PluginArtefactBlog extends PluginArtefact {
     }
 
     public static function menu_items() {
-        return array(
-            array(
-                'path'   => 'myportfolio/blogs',
-                'url'    => 'artefact/blog/',
-                'title'  => get_string('myblogs', 'artefact.blog'),
-                'weight' => 30,
-            ),
+        global $USER;
+        $tab = array(
+            'path'   => 'content/blogs',
+            'weight' => 40,
         );
+        if ($USER->get_account_preference('multipleblogs')) {
+            $tab['url']   = 'artefact/blog/';
+            $tab['title'] = get_string('blogs', 'artefact.blog');
+        }
+        else {
+            $tab['url']   = 'artefact/blog/view/';
+            $tab['title'] = get_string('blog', 'artefact.blog');
+        }
+        return array('content/blogs' => $tab);
     }
 
     public static function get_cron() {
@@ -138,10 +144,6 @@ class ArtefactTypeBlog extends ArtefactType {
         }
     }
 
-    public function is_container() {
-        return true;
-    }
-
     /**
      * This function updates or inserts the artefact.  This involves putting
      * some data in the artefact table (handled by parent::commit()), and then
@@ -194,11 +196,7 @@ class ArtefactTypeBlog extends ArtefactType {
     }
 
     /**
-     * Renders a blog for a view. This involves using a tablerenderer to paginate the posts.
-     *
-     * This uses some legacy stuff from the old views interface, including its 
-     * dependence on javascript and the table renderer, which would be nice to 
-     * fix using the new pagination stuff some time.
+     * Renders a blog.
      *
      * @param  array  Options for rendering
      * @return array  A two key array, 'html' and 'javascript'.
@@ -206,6 +204,39 @@ class ArtefactTypeBlog extends ArtefactType {
     public function render_self($options) {
         $this->add_to_render_path($options);
 
+        if (!isset($options['limit'])) {
+            $limit = self::pagination;
+        }
+        else if ($options['limit'] === false) {
+            $limit = null;
+        }
+        else {
+            $limit = (int) $options['limit'];
+        }
+        $offset = isset($options['offset']) ? intval($options['offset']) : 0;
+
+        if (!isset($options['countcomments'])) {
+            // Count comments if this is a view
+            $options['countcomments'] = (!empty($options['viewid']));
+        }
+
+        $posts = ArtefactTypeBlogpost::get_posts($this->id, $limit, $offset, $options);
+
+        $template = 'artefact:blog:viewposts.tpl';
+
+        $baseurl = get_config('wwwroot') . 'view/artefact.php?artefact=' . $this->id;
+        if (!empty($options['viewid'])) {
+            $baseurl .= '&view=' . $options['viewid'];
+        }
+        $pagination = array(
+            'baseurl' => $baseurl,
+            'id' => 'blogpost_pagination',
+            'datatable' => 'postlist',
+            'jsonscript' => 'artefact/blog/posts.json.php',
+        );
+
+        ArtefactTypeBlogpost::render_posts($posts, $template, $options, $pagination);
+
         $smarty = smarty_core();
         if (isset($options['viewid'])) {
             $smarty->assign('artefacttitle', '<a href="' . get_config('wwwroot') . 'view/artefact.php?artefact='
@@ -216,53 +247,15 @@ class ArtefactTypeBlog extends ArtefactType {
             $smarty->assign('artefacttitle', hsc($this->get('title')));
         }
 
+        $options['hidetitle'] = true;
         $smarty->assign('options', $options);
-        $smarty->assign('description', clean_html($this->get('description')));
+        $smarty->assign('description', $this->get('description'));
         $smarty->assign('owner', $this->get('owner'));
         $smarty->assign('tags', $this->get('tags'));
 
-        // Remove unnecessary options for blog posts
-        unset($options['hidetitle']);
+        $smarty->assign_by_ref('posts', $posts);
 
-        $page = (isset($options['page'])) ? abs(intval($options['page'])) : abs(param_integer('page', 1));
-        $offset = $page ? $page * self::pagination - self::pagination : 1;
-
-        $postids = get_column_sql("
-            SELECT a.id
-            FROM {artefact} a
-            LEFT JOIN {artefact_blog_blogpost} bp ON a.id = bp.blogpost
-            WHERE a.parent = ?
-            AND bp.published = 1
-            ORDER BY a.ctime DESC
-            LIMIT ? OFFSET ?", array($this->get('id'), self::pagination, $offset));
-        $postcount = $this->count_published_posts();
-
-        $data = array();
-        foreach($postids as $postid) {
-            $blogpost = new ArtefactTypeBlogPost($postid);
-            $data[] = array(
-                'id' => $postid,
-                'content' => $blogpost->render_self($options)
-            );
-        }
-        $smarty->assign('postdata', $data);
-
-        // Pagination
-        if ($postcount > self::pagination) {
-            $baselink = get_config('wwwroot') . 'view/artefact.php?artefact=' . $this->get('id');
-            if (isset($options['viewid'])) {
-                $baselink .= '&view=' . $options['viewid'];
-            }
-
-            if ($offset + self::pagination < $postcount) {
-                $smarty->assign('olderpostslink',  $baselink . '&page=' . ($page + 1));
-            }
-            if ($offset > 0) {
-                $smarty->assign('newerpostslink',  $baselink . '&page=' . ($page - 1));
-            }
-        }
-
-        return array('html' => $smarty->fetch('blocktype:blog:blog_render_self.tpl'), 'javascript' => '');
+        return array('html' => $smarty->fetch('artefact:blog:blog.tpl'), 'javascript' => '');
     }
 
                 
@@ -287,20 +280,27 @@ class ArtefactTypeBlog extends ArtefactType {
     public static function get_blog_list($limit, $offset) {
         global $USER;
         ($result = get_records_sql_array("
-         SELECT * FROM {artefact} WHERE owner = ? AND artefacttype = 'blog'
-         ORDER BY title LIMIT ? OFFSET ?", array($USER->get('id'), $limit, $offset)))
+         SELECT b.id, b.title, b.description, b.locked, COUNT(p.id) AS postcount
+         FROM {artefact} b LEFT JOIN {artefact} p ON (p.parent = b.id AND p.artefacttype = 'blogpost')
+         WHERE b.owner = ? AND b.artefacttype = 'blog'
+         GROUP BY b.id, b.title, b.description, b.locked
+         ORDER BY b.title", array($USER->get('id')), $offset, $limit))
             || ($result = array());
 
+        foreach ($result as &$r) {
+            if (!$r->locked) {
+                $r->deleteform = ArtefactTypeBlog::delete_form($r->id);
+            }
+        }
+
         $count = (int)get_field('artefact', 'COUNT(*)', 'owner', $USER->get('id'), 'artefacttype', 'blog');
 
         return array($count, $result);
     }
 
     public static function build_blog_list_html(&$blogs) {
-        global $USER;
         $smarty = smarty_core();
         $smarty->assign_by_ref('blogs', $blogs);
-        $smarty->assign('SESSKEY', $USER->get('sesskey'));
         $blogs->tablerows = $smarty->fetch('artefact:blog:bloglist.tpl');
         $pagination = build_pagination(array(
             'id' => 'bloglist_pagination',
@@ -390,6 +390,26 @@ class ArtefactTypeBlog extends ArtefactType {
             AND bp.published = 1", array($this->get('id')));
     }
 
+    public static function delete_form($id) {
+        global $THEME;
+        return pieform(array(
+            'name' => 'delete_' . $id,
+            'successcallback' => 'delete_blog_submit',
+            'renderer' => 'oneline',
+            'elements' => array(
+                'delete' => array(
+                    'type' => 'hidden',
+                    'value' => $id,
+                ),
+                'submit' => array(
+                    'type' => 'image',
+                    'src' => $THEME->get_url('images/icon_close.gif'),
+                    'elementtitle' => get_string('delete', 'artefact.blog'),
+                    'confirm' => get_string('deleteblog?', 'artefact.blog'),
+                ),
+            ),
+        ));
+    }
 }
 
 /**
@@ -426,6 +446,9 @@ class ArtefactTypeBlogPost extends ArtefactType {
                 throw new ArtefactNotFoundException(get_string('blogpostdoesnotexist', 'artefact.blog'));
             }
         }
+        else {
+            $this->allowcomments = 1; // Turn comments on for new posts
+        }
     }
 
     /**
@@ -501,6 +524,20 @@ class ArtefactTypeBlogPost extends ArtefactType {
         db_commit();
     }
 
+    public static function bulk_delete($artefactids) {
+        if (empty($artefactids)) {
+            return;
+        }
+
+        $idstr = join(',', array_map('intval', $artefactids));
+
+        db_begin();
+        delete_records_select('artefact_blog_blogpost', 'blogpost IN (' . $idstr . ')');
+        parent::bulk_delete($artefactids);
+        db_commit();
+    }
+
+
     /**
      * Checks that the person viewing this blog is the owner. If not, throws an 
      * AccessDeniedException. Used in the blog section to ensure only the 
@@ -520,11 +557,14 @@ class ArtefactTypeBlogPost extends ArtefactType {
 
     public function render_self($options) {
         $smarty = smarty_core();
+        $artefacturl = get_config('wwwroot') . 'view/artefact.php?artefact=' . $this->get('id');
+        if (isset($options['viewid'])) {
+            $artefacturl .= '&view=' . $options['viewid'];
+        }
+        $smarty->assign('artefacturl', $artefacturl);
         if (empty($options['hidetitle'])) {
             if (isset($options['viewid'])) {
-                $smarty->assign('artefacttitle', '<a href="' . get_config('wwwroot') . 'view/artefact.php?artefact='
-                     . $this->get('id') . '&amp;view=' . $options['viewid']
-                     . '">' . hsc($this->get('title')) . '</a>');
+                $smarty->assign('artefacttitle', '<a href="' . $artefacturl . '">' . hsc($this->get('title')) . '</a>');
             }
             else {
                 $smarty->assign('artefacttitle', hsc($this->get('title')));
@@ -532,10 +572,17 @@ class ArtefactTypeBlogPost extends ArtefactType {
         }
 
         // We need to make sure that the images in the post have the right viewid associated with them
-        $postcontent = clean_html($this->get('description'));
+        $postcontent = $this->get('description');
         if (isset($options['viewid'])) {
             safe_require('artefact', 'file');
             $postcontent = ArtefactTypeFolder::append_view_url($postcontent, $options['viewid']);
+            if (isset($options['countcomments']) && $this->allowcomments) {
+                safe_require('artefact', 'comment');
+                $empty = array();
+                $ids = array($this->id);
+                $commentcount = ArtefactTypeComment::count_comments($empty, $ids);
+                $smarty->assign('commentcount', $commentcount ? $commentcount[$this->id]->comments : 0);
+            }
         }
         $smarty->assign('artefactdescription', $postcontent);
         $smarty->assign('artefact', $this);
@@ -581,54 +628,139 @@ class ArtefactTypeBlogPost extends ArtefactType {
     }
 
     /**
-     * This function returns a list of the current user's blog posts, for the
-     * given blog.
+     * This function returns a list of posts in a given blog.
      *
-     * @param User
      * @param integer
      * @param integer
+     * @param integer
+     * @param array
      */
-    public static function get_posts(User $user, $id, $limit = self::pagination, $offset = 0) {
-        ($result = get_records_sql_assoc("
-         SELECT a.id, a.title, a.description, " . db_format_tsfield('a.ctime', 'ctime') . ', ' . db_format_tsfield('a.mtime', 'mtime') . ", bp.published
-         FROM {artefact} a
-          LEFT OUTER JOIN {artefact_blog_blogpost} bp
-           ON a.id = bp.blogpost
-         WHERE a.parent = ?
-          AND a.artefacttype = 'blogpost'
-          AND a.owner = ?
-         ORDER BY bp.published ASC, a.ctime DESC
-         LIMIT ? OFFSET ?;", array(
-            $id,
-            $user->get('id'),
-            $limit,
-            $offset
-        )))
-            || ($result = array());
+    public static function get_posts($id, $limit, $offset, $viewoptions=null) {
 
-        $count = (int)get_field('artefact', 'COUNT(*)', 'owner', $user->get('id'), 
-                                'artefacttype', 'blogpost', 'parent', $id);
+        $results = array(
+            'limit'  => $limit,
+            'offset' => $offset,
+        );
 
-        if (count($result) > 0) {
-            // Get the attached files.
-            $files = ArtefactType::attachments_from_id_list(array_map(create_function('$a', 'return $a->id;'), $result));
-            if ($files) {
-                safe_require('artefact', 'file');
-                foreach ($files as &$file) {
-                    $file->icon = call_static_method(generate_artefact_class_name($file->artefacttype), 'get_icon', array('id' => $file->attachment));
-                    $result[$file->artefact]->files[] = $file;
-                }
+        // If viewoptions is null, we're getting posts for the my blogs area,
+        // and we should get all posts & show drafts first.  Otherwise it's a
+        // blog in a view, and we should only get published posts.
+
+        $from = "
+            FROM {artefact} a LEFT JOIN {artefact_blog_blogpost} bp ON a.id = bp.blogpost
+            WHERE a.artefacttype = 'blogpost' AND a.parent = ?";
+
+        if (!is_null($viewoptions)) {
+            if (isset($viewoptions['before'])) {
+                $from .= " AND a.ctime < '{$viewoptions['before']}'";
             }
+            $from .= ' AND bp.published = 1';
+        }
 
-            // Format dates properly
-            foreach ($result as &$post) {
-                $post->ctime = format_date($post->ctime, 'strftimedaydatetime');
-                $post->mtime = format_date($post->mtime);
-                $post->description = clean_html($post->description);
+        $results['count'] = count_records_sql('SELECT COUNT(*) ' . $from, array($id));
+
+        $data = get_records_sql_assoc('
+            SELECT
+                a.id, a.title, a.description, a.author, a.authorname, ' .
+                db_format_tsfield('a.ctime', 'ctime') . ', ' . db_format_tsfield('a.mtime', 'mtime') . ',
+                a.locked, bp.published, a.allowcomments ' . $from . '
+            ORDER BY bp.published ASC, a.ctime DESC',
+            array($id),
+            $offset, $limit
+        );
+
+        if (!$data) {
+            $results['data'] = array();
+            return $results;
+        }
+
+        // Get the attached files.
+        $postids = array_map(create_function('$a', 'return $a->id;'), $data);
+        $files = ArtefactType::attachments_from_id_list($postids);
+        if ($files) {
+            safe_require('artefact', 'file');
+            foreach ($files as &$file) {
+                $file->icon = call_static_method(generate_artefact_class_name($file->artefacttype), 'get_icon', array('id' => $file->attachment));
+                $data[$file->artefact]->files[] = $file;
             }
         }
 
-        return array($count, array_values($result));
+        if ($tags = ArtefactType::tags_from_id_list($postids)) {
+            foreach($tags as &$at) {
+                $data[$at->artefact]->tags[] = $at->tag;
+            }
+        }
+
+        // Get comment counts
+        if (!empty($viewoptions['countcomments'])) {
+            safe_require('artefact', 'comment');
+            $viewids = array();
+            $commentcounts = ArtefactTypeComment::count_comments($viewids, array_keys($data));
+        }
+
+        foreach ($data as &$post) {
+            // Format dates properly
+            if (is_null($viewoptions)) {
+                // My Blogs area: create forms for publishing & deleting posts.
+                if (!$post->published) {
+                    $post->publish = ArtefactTypeBlogpost::publish_form($post->id);
+                }
+                $post->delete = ArtefactTypeBlogpost::delete_form($post->id);
+            }
+            else {
+                $by = $post->author ? display_default_name($post->author) : $post->authorname;
+                $post->postedby = get_string('postedbyon', 'artefact.blog', $by, format_date($post->ctime));
+                if (isset($commentcounts)) {
+                    $post->commentcount = isset($commentcounts[$post->id]) ? $commentcounts[$post->id]->comments : 0;
+                }
+            }
+            $post->ctime = format_date($post->ctime, 'strftimedaydatetime');
+            $post->mtime = format_date($post->mtime);
+
+            // Ensure images in the post have the right viewid associated with them
+            if (!empty($viewoptions['viewid'])) {
+                safe_require('artefact', 'file');
+                $post->description = ArtefactTypeFolder::append_view_url($post->description, $viewoptions['viewid']);
+            }
+        }
+
+        $results['data'] = array_values($data);
+
+        return $results;
+    }
+
+    /**
+     * This function renders a list of posts as html
+     *
+     * @param array posts
+     * @param string template
+     * @param array options
+     * @param array pagination
+     */
+    public function render_posts(&$posts, $template, $options, $pagination) {
+        $smarty = smarty_core();
+        $smarty->assign('options', $options);
+        $smarty->assign('posts', $posts['data']);
+
+        $posts['tablerows'] = $smarty->fetch($template);
+
+        if ($posts['limit'] && $pagination) {
+            $pagination = build_pagination(array(
+                'id' => $pagination['id'],
+                'class' => 'center',
+                'datatable' => $pagination['datatable'],
+                'url' => $pagination['baseurl'],
+                'jsonscript' => $pagination['jsonscript'],
+                'count' => $posts['count'],
+                'limit' => $posts['limit'],
+                'offset' => $posts['offset'],
+                'numbersincludefirstlast' => false,
+                'resultcounttextsingular' => get_string('post', 'artefact.blog'),
+                'resultcounttextplural' => get_string('posts', 'artefact.blog'),
+            ));
+            $posts['pagination'] = $pagination['html'];
+            $posts['pagination_js'] = $pagination['javascript'];
+        }
     }
 
     /** 
@@ -670,6 +802,54 @@ class ArtefactTypeBlogPost extends ArtefactType {
     }
 
 
+    public static function publish_form($id) {
+        return pieform(array(
+            'name' => 'publish_' . $id,
+            'successcallback' => 'publish_submit',
+            'jsform' => true,
+            'jssuccesscallback' => 'publish_success',
+            'renderer' => 'oneline',
+            'elements' => array(
+                'publish' => array(
+                    'type' => 'hidden',
+                    'value' => $id,
+                    'help' => true,
+                ),
+                'submit' => array(
+                    'type' => 'submit',
+                    'class' => 'publish',
+                    'value' => get_string('publish', 'artefact.blog'),
+                ),
+            ),
+        ));
+    }
+
+
+    public static function delete_form($id) {
+        global $THEME;
+        return pieform(array(
+            'name' => 'delete_' . $id,
+            'successcallback' => 'delete_submit',
+            'jsform' => true,
+            'jssuccesscallback' => 'delete_success',
+            'renderer' => 'oneline',
+            'elements' => array(
+                'delete' => array(
+                    'type' => 'hidden',
+                    'value' => $id,
+                    'help' => true,
+                ),
+                'submit' => array(
+                    'type' => 'image',
+                    'src' => $THEME->get_url('images/icon_close.gif'),
+                    'elementtitle' => get_string('delete', 'artefact.blog'),
+                    'confirm' => get_string('deleteblogpost?', 'artefact.blog'),
+                ),
+            ),
+        ));
+    }
+
+
     /**
      * This function publishes the blog post.
      *
@@ -757,6 +937,3 @@ class ArtefactTypeBlogPost extends ArtefactType {
         return artefact_get_references_in_html($this->get('description'));
     }
 }
-
-
-?>
