@@ -47,7 +47,7 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
 
     public static function postinst($oldversion) {
         if ($oldversion == 0) {
-            set_config_plugin('blocktype', 'internalmedia', 'enabledtypes', serialize(array('flv')));
+            set_config_plugin('blocktype', 'internalmedia', 'enabledtypes', serialize(array('flv', 'mp3')));
         }
     }
 
@@ -87,12 +87,14 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
                 'title' => get_string('width'),
                 'size' => 3,
                 'defaultvalue' => (isset($configdata['width'])) ? $configdata['width'] : '',
+                'rules' => array('minvalue' => 1, 'maxvalue' => 2000),
             ),
             'height' => array(
                 'type' => 'text',
                 'title' => get_string('height'),
                 'size' => 3,
                 'defaultvalue' => (isset($configdata['height'])) ? $configdata['height'] : '',
+                'rules' => array('minvalue' => 1, 'maxvalue' => 2000),
             ),
         );
     }
@@ -110,9 +112,6 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
     }
 
     public static function artefactchooser_element($default=null) {
-        $extraselect = 'filetype IN (' . join(',', array_map('db_quote', self::get_allowed_mimetypes())) . ')';
-        $extrajoin   = ' JOIN {artefact_file_files} ON {artefact_file_files}.artefact = a.id ';
-
         return array(
             'name' => 'artefactid',
             'type'  => 'artefactchooser',
@@ -122,8 +121,6 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
             'limit' => 5,
             'selectone' => true,
             'artefacttypes' => array('file'),
-            'extraselect' => $extraselect,
-            'extrajoin' => $extrajoin,
             'template' => 'artefact:file:artefactchooser-element.tpl',
         );
     }
@@ -220,7 +217,7 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
             'wmv'       => 'wmp_player', // tested
             'mpeg'      => 'qt_player',  // tested
             'avi'       => 'wmp_player', // tested
-            'mp4_video' => 'qt_player', // tested
+            'mp4_video' => 'flow_player', // tested
             /* commenting out for now
             'ram'   => 'real_player',
             'rm'    => 'real_player',
@@ -265,9 +262,11 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
 
         $id = 'blocktype_internalmedia_flow_' . time() . $count;
         $url = self::get_download_link($artefact, $block);
-        $url = str_replace('&', '%26', $url); // Flash needs these escaped
+        $escapedurl = str_replace('&', '%26', $url); // Flash needs these escaped
 
-        $playerurl =  get_config('wwwroot') . 'lib/flowplayer/flowplayer-3.2.4.swf';
+        $baseurl = get_config('wwwroot') . 'artefact/file/blocktype/internalmedia/';
+
+        $playerurl = $baseurl . 'flowplayer/flowplayer-3.2.4.swf';
         $autohide = 'true';
         $type = '';
         $audio = '';
@@ -278,18 +277,17 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
             $type = 'type: "audio",'; // force the player to use the audio plugin
             $buffering = 'false'; // without this autoPlay will also be set to true
             $audio = ', audio: {
-		                  url: "'.get_config('wwwroot').'lib/flowplayer.audio/flowplayer.audio-3.2.1.swf",
+		                  url: "' . $baseurl . 'flowplayer.audio/flowplayer.audio-3.2.1.swf"
 		             }';
         }
 
         $html =  '<a href="' . $url . '">' . hsc($artefact->get('title')) . '</a><br>
-               <span class="blocktype_internalmedia_mp3" id="' . $id . '"
-                     style="display:block;width:'.$width.'px;height:'.$height.'px;">(' 
-               . get_string('flashanimation', 'blocktype.file/internalmedia') . ')</span>
+               <span class="blocktype_internalmedia_mp3" id="' . $id . '" style="display:block;width:'.$width.'px;height:'.$height.'px;"></span>
+               <span id="' . $id . '_h">' . get_string('flashanimation', 'blocktype.file/internalmedia') . '</span>
                <script type="text/javascript">
                flowplayer("'.$id.'", "'.$playerurl.'", {
                    clip:  {
-                       url: "'.$url.'",
+                       url: "'.$escapedurl.'",
                        '.$type.'
                        autoPlay: false,
                        autoBuffering: '.$buffering.'
@@ -303,12 +301,13 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
                           time:false,
                           stop:false,
                           playlist:false,
-                          fullscreen:false,
+                          fullscreen:true,
                           scrubber: true,
                           autoHide: '.$autohide.'
                       }'.$audio.'
                    }
                }).load();
+               addElementClass("' . $id . '_h", "hidden");
                </script>
 ';
         return $html;
@@ -402,7 +401,7 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
       codebase="http://www.apple.com/qtactivex/qtplugin.cab" ' . $size . '>
      <param name="pluginspage" value="http://www.apple.com/quicktime/download/">
      <param name="src" value="' . $url . '">
-     <param name="coltroller" value="true">
+     <param name="controller" value="true">
      <param name="loop" value="false">
      <param name="autoplay" value="' . $autostart . '">
      <param name="autostart" value="' . $autostart . '">
@@ -432,7 +431,7 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
             return '';
         }
         define('BLOCKTYPE_INTERNALMEDIA_JS_INCLUDED', true);
-        return '<script src="'.get_config('wwwroot').'lib/flowplayer/flowplayer-3.2.4.js"></script>
+        return '<script src="'.get_config('wwwroot').'artefact/file/blocktype/internalmedia/flowplayer/flowplayer-3.2.4.js"></script>
              <script src="' . get_config('wwwroot') . 'artefact/file/blocktype/internalmedia/swfobject.js" type="text/javascript"></script>
              <script defer="defer" src="' . get_config('wwwroot') . 'artefact/file/blocktype/internalmedia/eolas_fix.js" type="text/javascript"></script>';
     }
@@ -442,5 +441,3 @@ class PluginBlocktypeInternalmedia extends PluginBlocktype {
     }
 
 }
-
-?>
