@@ -28,9 +28,9 @@
 defined('INTERNAL') || die();
 
 /**
- * Implements LEAP2A import of file/folder related entries into Mahara
+ * Implements Leap2A import of file/folder related entries into Mahara
  *
- * For more information about LEAP file importing, see:
+ * For more information about Leap file importing, see:
  * http://wiki.mahara.org/Developer_Area/Import//Export/LEAP_Import/File_Artefact_Plugin
  *
  * TODO:
@@ -252,8 +252,7 @@ class LeapImportFile extends LeapImportArtefactPlugin {
             return;
         }
         // TODO: might want to make it easier to get at the directory where the import files are
-        $data = $importer->get('data');
-        $dir = dirname($data['filename']);
+        $dir = dirname($importer->get('filename'));
 
         // Note: this data is passed (eventually) to ArtefactType->__construct, 
         // which calls strtotime on the dates for us
@@ -277,10 +276,10 @@ class LeapImportFile extends LeapImportArtefactPlugin {
             $data->parent = $parent;
         }
 
-        $pathname = $dir . DIRECTORY_SEPARATOR . $pathname;
+        $pathname = $dir . '/' . $pathname;
 
         // This API sucks, but that's not my problem
-        if (!$id = ArtefactTypeFile::save_file($pathname, $data, $importer->get('usrobj'))) {
+        if (!$id = ArtefactTypeFile::save_file($pathname, $data, $importer->get('usrobj'), true)) {
             $importer->trace("WARNING: the file for entry $entry->id does not exist in the import (path={$pathname})");
             return;
         }
@@ -397,5 +396,3 @@ class LeapImportFile extends LeapImportArtefactPlugin {
     }
 
 }
-
-?>
