@@ -34,8 +34,6 @@ $string['aboutme'] = 'About Me';
 $string['fieldstoshow'] = 'Fields to show';
 $string['introtext'] = 'Introduction Text';
 $string['useintroductioninstead'] = 'You can use your introduction profile field instead by enabling that and leaving this field blank';
-$string['dontshowprofileicon'] = "Don't show a profile icon";
+$string['dontshowprofileicon'] = "Don't show a profile picture";
 $string['dontshowemail'] = "Don't show email address";
-$string['uploadaprofileicon'] = "You have no profile icons. <a href=\"%sartefact/file/profileicons.php\" target=\"_blank\">Upload one</a>";
-
-?>
+$string['uploadaprofileicon'] = "You have no profile pictures. <a href=\"%sartefact/file/profileicons.php\" target=\"_blank\">Upload one</a>";
