@@ -26,19 +26,20 @@
  */
 
 define('INTERNAL', 1);
-define('MENUITEM', 'profile/edit');
+define('MENUITEM', 'content/profile');
 define('SECTION_PLUGINTYPE', 'artefact');
 define('SECTION_PLUGINNAME', 'internal');
 define('SECTION_PAGE', 'index');
 
 require(dirname(dirname(dirname(__FILE__))) . '/init.php');
-define('TITLE', get_string('editprofile','artefact.internal'));
+define('TITLE', get_string('profile','artefact.internal'));
 require_once('pieforms/pieform.php');
 safe_require('artefact', 'internal');
 
 $fieldset = param_alpha('fs', 'aboutme');
 
 $element_list = call_static_method('ArtefactTypeProfile', 'get_all_fields');
+$element_data = ArtefactTypeProfile::get_field_element_data();
 $element_required = call_static_method('ArtefactTypeProfile', 'get_mandatory_fields');
 
 // load existing profile information
@@ -84,6 +85,7 @@ foreach ( $element_list as $element => $type ) {
         $items[$element] = array(
             'type'  => 'html',
             'title' => get_string($element, 'artefact.internal'),
+            'value' => '--',
         );
         if (isset($profilefields[$element])) {
             $items[$element]['value'] = clean_html($profilefields[$element]);
@@ -96,18 +98,26 @@ foreach ( $element_list as $element => $type ) {
         'title' => get_string($element, 'artefact.internal'),
     );
 
+    if (isset($element_data[$element]['rules'])) {
+        $items[$element]['rules'] = $element_data[$element]['rules'];
+    }
+
     if ($type == 'wysiwyg') {
         $items[$element]['rows'] = 10;
         $items[$element]['cols'] = 50;
+        $items[$element]['rules'] = array('maxlength' => 65536);
     }
     if ($type == 'textarea') {
         $items[$element]['rows'] = 4;
         $items[$element]['cols'] = 50;
     }
+    if ($type == 'text') {
+        $items[$element]['size'] = 30;
+    }
     if ($element == 'country') {
-        $items[$element]['options'] = getoptions_country();
-        // @todo configure default country somehow...
-        $items[$element]['defaultvalue'] = 'nz';
+        $countries = getoptions_country();
+        $items[$element]['options'] = array('' => get_string('nocountryselected')) + $countries;
+        $items[$element]['defaultvalue'] = get_config('country');
     }
 
     if (get_helpfile_location('artefact', 'internal', 'profileform', $element)) {
@@ -131,12 +141,15 @@ if ($items['firstname']) {
     $items['firstname']['autofocus'] = true;
 }
 
+
+$items['maildisabled']['ignore'] = !get_account_preference($USER->get('id'),'maildisabled');
+$items['maildisabled']['value'] = get_string('maildisableddescription', 'account', get_config('wwwroot') . 'account/');
+
 // build form elements
 $elements = array(
     'topsubmit' => array(
-        'type'  => 'submitcancel',
-        'value' => array(get_string('saveprofile','artefact.internal'), get_string('viewmyprofile', 'artefact.internal')),
-        'goto' => get_config('wwwroot') . 'user/view.php?id=' . $USER->get('id'),
+        'type'  => 'submit',
+        'value' => get_string('saveprofile','artefact.internal'),
     ),
     'profile' => array(
         'type' => 'fieldset',
@@ -148,7 +161,7 @@ $elements = array(
         'type' => 'fieldset',
         'legend' => get_string('contact', 'artefact.internal'),
         'class' => $fieldset != 'contact' ? 'collapsed' : '',
-        'elements' => get_desired_fields($items, array('email', 'officialwebsite', 'personalwebsite', 'blogaddress', 'address', 'town', 'city', 'country', 'homenumber', 'businessnumber', 'mobilenumber', 'faxnumber'), 'contact'),
+        'elements' => get_desired_fields($items, array('email', 'maildisabled', 'officialwebsite', 'personalwebsite', 'blogaddress', 'address', 'town', 'city', 'country', 'homenumber', 'businessnumber', 'mobilenumber', 'faxnumber'), 'contact'),
     ),
     'messaging' => array(
         'type' => 'fieldset',
@@ -167,9 +180,8 @@ $elements = array(
         'value' => $fieldset,
     ),
     'submit' => array(
-        'type'  => 'submitcancel',
-        'value' => array(get_string('saveprofile','artefact.internal'), get_string('viewmyprofile', 'artefact.internal')),
-        'goto' => get_config('wwwroot') . 'user/view.php?id=' . $USER->get('id'),
+        'type'  => 'submit',
+        'value' => get_string('saveprofile','artefact.internal'),
     )
 );
 
@@ -187,11 +199,20 @@ $profileform = pieform(array(
 
 function get_desired_fields(&$allfields, $desiredfields, $section) {
     global $USER;
-    $return = array();
-    $return["{$section}description"] = array(
-        'type'  => 'html',
-        'labelhtml' => ($section == 'about') ? '<div id="profileicon"><a href="' . get_config('wwwroot') . 'artefact/file/profileicons.php"><img src="' . get_config('wwwroot') . 'thumb.php?type=profileiconbyid&maxsize=100&id=' . intval($USER->get('profileicon')) . '" alt=""></a></div>' : '',
-        'value' => get_string("{$section}description", 'artefact.internal')
+    if ($section == 'about') {
+        $label = '<div id="profileicon"><a href="' . get_config('wwwroot') . 'artefact/file/profileicons.php"><img src="' . get_config('wwwroot') . 'thumb.php?type=profileicon&maxsize=100&id=' . intval($USER->get('id')) . '" alt=""></a></div>';
+        $descr = get_string('aboutdescription', 'artefact.internal');
+    }
+    else {
+        $label = '';
+        $descr = get_string('infoisprivate', 'artefact.internal');
+    }
+    $return = array(
+        "{$section}description" => array(
+            'type'      => 'html',
+            'labelhtml' => $label,
+            'value'     => $descr,
+        )
     );
     foreach ($desiredfields as $field) {
         if (isset($allfields[$field])) {
@@ -226,6 +247,7 @@ function profileform_validate(Pieform $form, $values) {
             }
         }
     }
+
 }
 
 function profileform_submit(Pieform $form, $values) {
@@ -262,6 +284,7 @@ function profileform_submit(Pieform $form, $values) {
 
                 $key = get_random_key();
                 $key_url = get_config('wwwroot') . 'artefact/internal/validate.php?email=' . rawurlencode($email) . '&key=' . $key;
+                $key_url_decline = $key_url . '&decline=1';
 
                 try {
                     email_user(
@@ -277,7 +300,7 @@ function profileform_submit(Pieform $form, $values) {
                         ),
                         null,
                         get_string('emailvalidation_subject', 'artefact.internal'),
-                        get_string('emailvalidation_body', 'artefact.internal', $USER->get('firstname'), $email, $key_url)
+                        get_string('emailvalidation_body', 'artefact.internal', $USER->get('firstname'), $email, $key_url, $key_url_decline)
                     );
                 }
                 catch (EmailException $e) {
@@ -298,10 +321,10 @@ function profileform_submit(Pieform $form, $values) {
 
             // remove old addresses
             foreach ($profilefields['email']['validated'] as $email) {
-                if (
-                    in_array($email, $values['email']['validated'])
-                    || in_array($email, $values['email']['unvalidated'])
-                ) {
+                if (in_array($email, $values['email']['validated'])) {
+                    continue;
+                }
+                if (!empty($values['email']['unvalidated']) && in_array($email, $values['email']['unvalidated'])) {
                     continue;
                 }
 
@@ -322,7 +345,8 @@ function profileform_submit(Pieform $form, $values) {
             foreach ($profilefields['email']['unvalidated'] as $email) {
                 if (
                     in_array($email, $values['email']['validated'])
-                    || in_array($email, $values['email']['unvalidated'])
+                    || (isset($values['email']['unvalidated'])
+                        && in_array($email, $values['email']['unvalidated']))
                 ) {
                     continue;
                 }
@@ -364,6 +388,9 @@ function profileform_submit(Pieform $form, $values) {
                 $USER->commit();
             }
         }
+        else if ($element == 'maildisabled') {
+            continue;
+        }
         else {
             if (!isset($profilefields[$element]) || $values[$element] != $profilefields[$element]) {
                 $classname = generate_artefact_class_name($element);
@@ -421,12 +448,12 @@ $smarty = smarty(array('artefact/internal/js/profile.js'), array(), array(
 
 
 $smarty->assign('profileform', $profileform);
-$smarty->assign('PAGEHEADING', hsc(get_string('editprofile', 'artefact.internal')));
+$smarty->assign('PAGEHEADING', TITLE);
 $smarty->display('artefact:internal:index.tpl');
 
 
 function locked_profile_fields() {
-    global $USER;
+    global $USER, $SESSION;
 
     // Profile fields are locked for a user if they are locked by any
     // institution the user is a member of, but not an admin for.
@@ -434,11 +461,19 @@ function locked_profile_fields() {
     $lockinginstitutions[] = 'mahara';
     $lockinginstitutions = array_diff($lockinginstitutions, $USER->get('admininstitutions'));
 
-    return get_records_select_assoc(
+    $locked = get_records_select_assoc(
         'institution_locked_profile_field',
         'name IN (' . join(',', array_map('db_quote', $lockinginstitutions)) . ')',
         null, '', 'profilefield,name'
     );
-}
 
-?>
+    if ($remotelocked = $SESSION->get('lockedfields')) {
+        foreach ($remotelocked as $f) {
+            if (!isset($locked[$f])) {
+                $locked[$f] = $f;
+            }
+        }
+    }
+
+    return $locked;
+}
