@@ -44,8 +44,6 @@ class PluginBlocktypeEntireresume extends PluginBlocktype {
     public static function render_instance(BlockInstance $instance, $editing=false) {
         require_once(get_config('docroot') . 'artefact/lib.php');
         $smarty = smarty_core();
-        //$configdata = $instance->get('configdata');
-        //$configdata['viewid'] = $instance->get('view');
 
         // Get data about the resume fields the user has
         $return = '';
@@ -109,8 +107,8 @@ class PluginBlocktypeEntireresume extends PluginBlocktype {
                 SELECT id
                 FROM {artefact}
                 WHERE artefacttype IN(' . $artefacttypes . ')
-                AND owner = (
-                    SELECT owner
+                AND "owner" = (
+                    SELECT "owner"
                     FROM {view}
                     WHERE id = ?
                 )', array($blockinstance->get('view')));
@@ -142,5 +140,3 @@ class PluginBlocktypeEntireresume extends PluginBlocktype {
     }
 
 }
-
-?>
