@@ -1,7 +1,8 @@
 <?php
 /**
  * Mahara: Electronic portfolio, weblog, resume builder and social networking
- * Copyright (C) 2006-2008 Catalyst IT Ltd (http://www.catalyst.net.nz)
+ * Copyright (C) 2006-2009 Catalyst IT Ltd and others; see:
+ *                         http://wiki.mahara.org/Contributors
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +22,7 @@
  * @author     Howard Miller <howard.miller@udcf.gla.ac.uk>
  * @license    http://www.gnu.org/copyleft/gpl.html GNU GPL
  * @copyright  (C) 2008 Howard Miller <howard.miller@udcf.gla.ac.uk>
- * @copyright  (C) 2008 Catalyst IT Ltd http://catalyst.net.nz
+ * @copyright  (C) 2008-2009 Catalyst IT Ltd http://catalyst.net.nz
  * @copyright  (C) portions from Moodle, (C) Martin Dougiamas http://dougiamas.com
  */
 
@@ -44,7 +45,9 @@ class AuthLdap extends Auth {
         $this->config['search_sub'] = 'yes';  
         $this->config['bind_dn'] = '';
         $this->config['bind_pw'] = '';
-        $this->config['version'] = '2';
+        $this->config['version'] = 3;
+        $this->config['starttls'] = 0;
+        $this->config['updateuserinfoonlogin'] = 0;
         $this->config['weautocreateusers'] = 1;
         $this->config['firstnamefield' ] = '';
         $this->config['surnamefield'] = '';
@@ -93,7 +96,12 @@ class AuthLdap extends Auth {
         if (empty($username) or empty($password)) {    
             return false;
         }
+        // For update user info on login
+        $update = false;
 
+        if ('1' == $this->config['updateuserinfoonlogin']) {
+                $update = true;
+        }
         // Missed out AD bit, someone might want to put it back :-)
 
         // attempt ldap connection
@@ -111,12 +119,33 @@ class AuthLdap extends Auth {
             $ldap_login = @ldap_bind($ldapconnection, $ldap_user_dn, $password);
             ldap_close($ldapconnection);
             if ($ldap_login) {
+                if ($user->id && $update) {
+                    // Define ldap attributes
+                    $ldapattributes = array();
+                    $ldapattributes['firstname'] = $this->config['firstnamefield'];
+                    $ldapattributes['lastname']  = $this->config['surnamefield' ];
+                    $ldapattributes['email']     = $this->config['emailfield' ];
+
+                    // Retrieve information of user from LDAP
+                    $ldapdetails = $this->get_userinfo_ldap($username, $ldapattributes);
+
+                    // Match database and ldap entries and update in database if required
+                    $fieldstoimport = array('firstname', 'lastname', 'email');
+                    foreach ($fieldstoimport as $field) {
+                        if (!empty($ldapdetails[$field]) && ($user->$field != $ldapdetails[$field])) {
+                            $user->$field = $ldapdetails[$field];
+                            set_profile_field($user->id, $field, $user->$field);
+                        }
+                    }
+               }
                 return true;
             }
         }
         else {
             @ldap_close($ldapconnection);
-            throw new AuthUnknownUserException('Cannot connect to any LDAP hosts');
+            // let's do some logging too
+            log_warn("LDAP connection failed: ".$this->config['host_url'].'/'.$this->config['contexts']);
+            throw new AuthInstanceException(get_string('cannotconnect', 'auth.ldap'));
         }
 
         return false;  // No match
@@ -161,6 +190,12 @@ class AuthLdap extends Auth {
                  ldap_set_option($connresult, LDAP_OPT_REFERRALS, 0);
             }
 
+            if (!empty($this->config['starttls'])) {
+                if (!ldap_start_tls($connresult)) {
+                    return false;
+                }
+            }
+
             if (!empty($binddn)) {
                 // bind with search-user
                 $bindresult = ldap_bind($connresult, $binddn,$bindpwd);
@@ -382,7 +417,9 @@ class PluginAuthLdap extends PluginAuth {
         'search_sub'        => 'yes',
         'bind_dn'           => '',
         'bind_pw'           => '',
-        'version'           => 2,
+        'version'           => 3,
+        'starttls'          => 0,
+        'updateuserinfoonlogin' => 0,
         'weautocreateusers' => 1,
         'firstnamefield'    => '',
         'surnamefield'      => '',
@@ -515,7 +552,7 @@ class PluginAuthLdap extends PluginAuth {
                 'help'  => true,
             ),
             'bind_pw' => array(
-                'type'  => 'text',
+                'type'  => 'password',
                 'title' => get_string('password', 'auth.ldap'),
                 'defaultvalue' => self::$default_config['bind_pw'],
                 'help'  => true,
@@ -530,6 +567,18 @@ class PluginAuthLdap extends PluginAuth {
                 'defaultvalue' => self::$default_config['version'],
                 'help'  => true,
             ),
+            'starttls' => array(
+                'type'  => 'checkbox',
+                'title' => get_string('starttls', 'auth.ldap'),
+                'defaultvalue' => self::$default_config['starttls'],
+            ),
+            'updateuserinfoonlogin' => array(
+                'type'  => 'checkbox',
+                'title' => get_string('updateuserinfoonlogin', 'auth.ldap'),
+                'description' => get_string('updateuserinfoonloginadnote', 'auth.ldap'),
+                'defaultvalue' => self::$default_config['updateuserinfoonlogin'],
+                'help'  => true,
+            ),
             'weautocreateusers' => array(
                 'type'  => 'checkbox',
                 'title' => get_string('weautocreateusers', 'auth.ldap'),
@@ -610,6 +659,8 @@ class PluginAuthLdap extends PluginAuth {
                                         'bind_dn' => $values['bind_dn'],
                                         'bind_pw' => $values['bind_pw'],
                                         'version' => $values['version'],
+                                        'starttls' => $values['starttls'],
+                                        'updateuserinfoonlogin' => $values['updateuserinfoonlogin'],
                                         'weautocreateusers' => $values['weautocreateusers'],
                                         'firstnamefield' => $values['firstnamefield'],
                                         'surnamefield' => $values['surnamefield'],
@@ -635,5 +686,3 @@ class PluginAuthLdap extends PluginAuth {
 
 
 }
-
-?>
