@@ -29,6 +29,7 @@ defined('INTERNAL') || die();
 
 require('session.php');
 require(get_config('docroot') . 'auth/user.php');
+require_once(get_config('docroot') . '/lib/htmloutput.php');
 
 /**
  * Unknown user exception
@@ -212,7 +213,7 @@ abstract class Auth {
      */
     public function user_exists($username) {
         $this->must_be_ready();
-        if (record_exists('usr', 'LOWER(username)', strtolower($username))) {
+        if (record_exists_select('usr', 'LOWER(username) = ?', array(strtolower($username)))) {
             return true;
         }
         throw new AuthUnknownUserException("\"$username\" is not known to Auth");
@@ -382,6 +383,10 @@ function auth_setup () {
             log_debug("Strange: user " . $USER->get('username') . " had no authinstance set in their session");
         }
 
+        if (function_exists('local_logout')) {
+            local_logout();
+        }
+
         $USER->logout();
         $SESSION->add_ok_msg(get_string('loggedoutok'));
         redirect();
@@ -444,9 +449,8 @@ function auth_setup () {
             json_reply('global', get_string('sessiontimedoutreload'), 1);
         }
         if (defined('IFRAME')) {
-            $frame = '<html><head></head><body onload="parent.show_login_form(\'ajaxlogin_iframe\')"></body></html>';
             header('Content-type: text/html');
-            echo $frame;
+            print_auth_frame();
             exit;
         }
 
@@ -478,6 +482,10 @@ function auth_setup () {
         
         // Check if the page is public or the site is configured to be public.
         if (defined('PUBLIC') && !isset($_GET['login'])) {
+            if ($lang = param_alphanumext('lang', null)) {
+                $SESSION->set('lang', $lang);
+                current_language($lang);
+            }
             return;
         }
 
@@ -701,6 +709,10 @@ function auth_get_available_auth_types($institution=null) {
 function auth_check_required_fields() {
     global $USER, $SESSION;
 
+    if (defined('NOCHECKREQUIREDFIELDS')) {
+        return;
+    }
+
     $changepassword = true;
     $elements = array();
 
@@ -813,7 +825,7 @@ function auth_check_required_fields() {
         }
         if ($field == 'country') {
             $elements[$field]['options'] = getoptions_country();
-            $elements[$field]['defaultvalue'] = 'nz';
+            $elements[$field]['defaultvalue'] = get_config('country');
         }
 
         if ($field == 'email') {
@@ -898,8 +910,7 @@ function requiredfields_submit(Pieform $form, $values) {
             $SESSION->add_ok_msg(get_string('passwordsaved'));
         }
         else {
-            // TODO: Exception is the wrong type here!
-            throw new Exception('Attempt by "' . $USER->get('username') . '@'
+            throw new SystemException('Attempt by "' . $USER->get('username') . '@'
                 . $USER->get('institution') . 'to change their password failed');
         }
     }
@@ -971,7 +982,8 @@ function auth_draw_login_page($message=null, Pieform $form=null) {
     }
     $smarty = smarty(array(), array(), array(), array('pagehelp' => false, 'sidebars' => false));
     $smarty->assign('login_form', $loginform);
-    $smarty->assign('PAGEHEADING', hsc(get_string('loginto', 'mahara', get_config('sitename'))));
+    $smarty->assign('PAGEHEADING', get_string('loginto', 'mahara', get_config('sitename')));
+    $smarty->assign('LOGINPAGE', true);
     $smarty->display('login.tpl');
     exit;
 }
@@ -1012,26 +1024,21 @@ function auth_get_login_form() {
     // remembers the GET and POST data sent to it and resends that on
     // afterwards. 
     $action = '';
-    if (get_config('httpswwwroot')) {
-        $action = rtrim(get_config('httpswwwroot'), '/') . hsc(strip_querystring(get_relative_script_path()));
-    }
     if ($_GET) {
         if (isset($_GET['logout'])) {
             // You can log the user out on any particular page by appending
             // ?logout to the URL. In this case, we don't want the "action"
             // of the url to include that, or be blank, else the next time
             // the user logs in they will be logged out again.
-            if ($action == '') {
-                $action = hsc(substr($_SERVER['REQUEST_URI'], 0, strpos($_SERVER['REQUEST_URI'], '?')));
-            }
+            $action = hsc(substr($_SERVER['REQUEST_URI'], 0, strpos($_SERVER['REQUEST_URI'], '?')));
         } else {
             $action .= '?';
             foreach ($_GET as $key => $value) {
-                if ($key != 'logout' && $key != 'login') {
-                    $action .= hsc($key) . '=' . hsc($value) . '&amp;';
+                if ($key != 'login') {
+                    $action .= hsc($key) . '=' . hsc($value) . '&';
                 }
             }
-            $action = substr($action, 0, -5);
+            $action = substr($action, 0, -1);
         }
     }
     if ($_POST) {
@@ -1281,7 +1288,7 @@ function login_submit(Pieform $form, $values) {
 
     // Check if the user's account has been suspended
     if ($USER->suspendedcusr) {
-        $suspendedctime  = $USER->suspendedctime;
+        $suspendedctime  = strftime(get_string('strftimedaydate'), $USER->suspendedctime);
         $suspendedreason = $USER->suspendedreason;
         $USER->logout();
         die_info(get_string('accountsuspended', 'mahara', $suspendedctime, $suspendedreason));
@@ -1290,19 +1297,6 @@ function login_submit(Pieform $form, $values) {
     // User is allowed to log in
     //$USER->login($userdata);
     auth_check_required_fields();
-
-    if (get_config('httpswwwroot') && !defined('JSON')) {
-        // If we are using HTTPS for logins we need to go back to
-        // non-HTTPS URLs. Otherwise, Javascript (and possibly CSS)
-        // breaks. Don't use get_full_script_path(), as it doesn't
-        // work if someone sets httpswwwroot to something like
-        // 'https://x.y.z.w:443/...'  (unlikely, but
-        // possible). get_full_script_path() doesn't gives us the
-        // ':443' part and things break horribly.
-        $parts = parse_url(get_config('httpswwwroot'));
-        $httpsrequest = rtrim($parts['path'], '/');
-        redirect(hsc(substr(get_script_path(), strlen($httpsrequest))));
-    }
 }
 
 /**
@@ -1313,6 +1307,24 @@ function auth_clean_partial_registrations() {
         WHERE expiry < ?', array(db_format_timestamp(time())));
 }
 
+
+function _email_or_notify($user, $subject, $bodytext, $bodyhtml) {
+    try {
+        email_user($user, null, $subject, $bodytext, $bodyhtml);
+    }
+    catch (EmailDisabledException $e) {
+        // Send a notification instead - email is disabled for this user
+        $message = new StdClass;
+        $message->users = array($user->id);
+        $message->subject = $subject;
+        $message->message = $bodytext;
+
+        require_once('activity.php');
+        activity_occurred('maharamessage', $message);
+    }
+}
+
+
 /**
  * Sends notification e-mails to users in two situations:
  *
@@ -1343,8 +1355,7 @@ function auth_handle_account_expiries() {
         AND expirymailsent = 0', array(time() + $warn))) {
         foreach ($users as $user) {
             $displayname  = display_name($user);
-            email_user($user, null,
-                get_string('accountexpirywarning'),
+            _email_or_notify($user, get_string('accountexpirywarning'),
                 get_string('accountexpirywarningtext', 'mahara', $displayname, $sitename, $daystoexpire, $wwwroot . 'contact.php', $sitename),
                 get_string('accountexpirywarninghtml', 'mahara', $displayname, $sitename, $daystoexpire, $wwwroot . 'contact.php', $sitename)
             );
@@ -1371,7 +1382,7 @@ function auth_handle_account_expiries() {
             AND inactivemailsent = 0', array(time()))) {
             foreach ($users as $user) {
                 $displayname = display_name($user);
-                email_user($user, null, get_string('accountinactivewarning'),
+                _email_or_notify($user, get_string('accountinactivewarning'),
                     get_string('accountinactivewarningtext', 'mahara', $displayname, $sitename, $daystoexpire, $sitename),
                     get_string('accountinactivewarninghtml', 'mahara', $displayname, $sitename, $daystoexpire, $sitename)
                 );
@@ -1406,12 +1417,11 @@ function auth_handle_account_expiries() {
         AND ui.expirymailsent = 0', array(time() + $warn))) {
         foreach ($users as $user) {
             $displayname  = display_name($user);
-            email_user($user, null,
-                get_string('institutionmembershipexpirywarning'),
+            _email_or_notify($user, get_string('institutionmembershipexpirywarning'),
                 get_string('institutionmembershipexpirywarningtext', 'mahara', $displayname, $user->institutionname,
-                           $sitename, $daystoexpire, $wwwroot . 'contact.php', $sitename),
+                    $sitename, $daystoexpire, $wwwroot . 'contact.php', $sitename),
                 get_string('institutionmembershipexpirywarninghtml', 'mahara', $displayname, $user->institutionname,
-                           $sitename, $daystoexpire, $wwwroot . 'contact.php', $sitename)
+                    $sitename, $daystoexpire, $wwwroot . 'contact.php', $sitename)
             );
             set_field('usr_institution', 'expirymailsent', 1, 'usr', $user->id,
                       'institution', $user->institution);
@@ -1453,8 +1463,7 @@ function auth_handle_institution_expiries() {
             // Email site administrators
             foreach ($siteadmins as $user) {
                 $user_displayname  = display_name($user);
-                email_user($user, null,
-                    get_string('institutionexpirywarning'),
+                _email_or_notify($user, get_string('institutionexpirywarning'),
                     get_string('institutionexpirywarningtext_site', 'mahara', $user_displayname, $institution_displayname, $daystoexpire, $sitename, $sitename),
                     get_string('institutionexpirywarninghtml_site', 'mahara', $user_displayname, $institution_displayname, $daystoexpire, $sitename, $sitename)
                 );
@@ -1467,8 +1476,7 @@ function auth_handle_institution_expiries() {
             );
             foreach ($institutionaladmins as $user) {
                 $user_displayname  = display_name($user);
-                email_user($user, null,
-                    get_string('institutionexpirywarning'),
+                _email_or_notify($user, get_string('institutionexpirywarning'),
                     get_string('institutionexpirywarningtext_institution', 'mahara', $user_displayname, $institution_displayname, $sitename, $daystoexpire, $wwwroot . 'contact.php', $sitename),
                     get_string('institutionexpirywarninghtml_institution', 'mahara', $user_displayname, $institution_displayname, $sitename, $daystoexpire, $wwwroot . 'contact.php', $sitename)
                 );
@@ -1503,6 +1511,8 @@ function auth_remove_old_session_files() {
     // here. In particular, -mtime +1 means files older than about two days 
     // will be removed
     exec('find ' . escapeshellarg(get_config('dataroot') . 'sessions') . ' -type f -mtime +1 | xargs -n 1000 -r rm');
+    // Throw away records of old login sessions. Should check whether any are still alive.
+    delete_records_select('usr_session', 'ctime < ?', array(db_format_timestamp(time() - 86400 * 30)));
 }
 
 /**
@@ -1515,10 +1525,6 @@ function auth_generate_login_form() {
     if (!get_config('installed')) {
         return;
     }
-    $action='';
-    if (get_config('httpswwwroot')) {
-        $action = rtrim(get_config('httpswwwroot'), '/') . hsc(strip_querystring(get_relative_script_path()));
-    }
     require_once('pieforms/pieform.php');
     if (count_records('institution', 'registerallowed', 1, 'suspended', 0)) {
         $registerlink = '<a href="' . get_config('wwwroot') . 'register.php" tabindex="2">' . get_string('register') . '</a><br>';
@@ -1530,7 +1536,6 @@ function auth_generate_login_form() {
         'name'       => 'login',
         'renderer'   => 'div',
         'submit'     => false,
-        'action'     => $action,
         'plugintype' => 'auth',
         'pluginname' => 'internal',
         'autofocus'  => false,
@@ -1549,6 +1554,9 @@ function auth_generate_login_form() {
                 'title'       => get_string('password') . ':',
                 'description' => get_string('passworddescription'),
                 'defaultvalue'       => '',
+                'rules' => array(
+                    'required'    => true
+                )
             ),
             'submit' => array(
                 'type'  => 'submit',
@@ -1610,6 +1618,10 @@ function password_validate(Pieform $form, $values, $user) {
 
 }
 
+function auth_get_random_salt() {
+    return substr(md5(rand(1000000, 9999999)), 2, 8);
+}
+
 class PluginAuth extends Plugin {
 
     public static function get_event_subscriptions() {
@@ -1675,5 +1687,3 @@ class PluginAuth extends Plugin {
         return false;
     }
 }
-
-?>
