@@ -96,10 +96,11 @@ class AuthSaml extends Auth {
         $lastname        = $attributes[$this->config['surnamefield']][0];
         $email           = $attributes[$this->config['emailfield']][0];
         $institutionname = $this->institution;
-        
-        $virgin = false;
 
-        $oldlastlogin = null;
+        if (!$firstname or !$lastname or !$email) {
+            throw new AuthInstanceException(get_string('errormissinguserattributes', 'auth.saml'));
+        }
+        
         $create = false;
         $update = false;
 
@@ -235,6 +236,7 @@ class AuthSaml extends Auth {
 
         // We know who our user is now. Bring em back to life.
 //        ensure_session();
+        log_debug("remote user '$remoteuser' ");
         $result = $USER->reanimate($user->id, $this->instanceid);
         $SESSION->set('authinstance', $this->instanceid);
 
@@ -395,9 +397,6 @@ class PluginAuthSaml extends PluginAuth {
             'institutionregex' => array(
                 'type'  => 'checkbox',
                 'title' => get_string('institutionregex', 'auth.saml'),
-                'rules' => array(
-                'required' => false,
-                ),
                 'defaultvalue' => self::$default_config['institutionregex'],
                 'help' => true,
             ),
@@ -457,12 +456,12 @@ class PluginAuthSaml extends PluginAuth {
 
     public static function validate_config_options($values, $form) {
 
-        // fix problems with config validation interface incorrect between site/institution
-        if (get_class($values) == 'Pieform') {
+        if ($values instanceof Pieform) {
             $tmp = $form;
             $form = $values;
             $values = $tmp;
         }
+        // fix problems with config validation interface incorrect between site/institution
         if (isset($values['authglobalconfig'])) {
             // SimpleSAMLPHP lib directory must have right things
             if (! file_exists($values['simplesamlphplib'].'/lib/_autoload.php')) {
@@ -557,5 +556,3 @@ class PluginAuthSaml extends PluginAuth {
         return $values;
     }
 }
-
-?>
