@@ -91,6 +91,9 @@ class User {
             'parentuser'       => null,
             'loginanyway'       => false,
             'sesskey'          => '',
+            'ctime'            => null,
+            'views'            => array(),
+            'showhomeinfo'     => 1
         );
         $this->attributes = array();
 
@@ -111,7 +114,8 @@ class User {
                     ' . db_format_tsfield('lastlogin') . ', 
                     ' . db_format_tsfield('lastlastlogin') . ',
                     ' . db_format_tsfield('lastaccess') . ',
-                    ' . db_format_tsfield('suspendedctime') . '
+                    ' . db_format_tsfield('suspendedctime') . ',
+                    ' . db_format_tsfield('ctime') . '
                 FROM
                     {usr}
                 WHERE
@@ -148,7 +152,8 @@ class User {
                     ' . db_format_tsfield('lastlogin') . ',
                     ' . db_format_tsfield('lastlastlogin') . ',
                     ' . db_format_tsfield('lastaccess') . ',
-                    ' . db_format_tsfield('suspendedctime') . '
+                    ' . db_format_tsfield('suspendedctime') . ',
+                    ' . db_format_tsfield('ctime') . '
                 FROM
                     {usr}
                 WHERE
@@ -178,6 +183,7 @@ class User {
             throw new InvalidArgumentException('parameter must be a positive integer to create a User object');
         }
 
+        $username = strtolower($username);
         if ($remoteuser) {
             // See if the user has either the child or the parent authinstance. 
             // Most of the time, it's the parent auth instance that is 
@@ -198,7 +204,7 @@ class User {
                                     JOIN
                                         {auth_remote_user} aru ON (us.id = aru.localusr)
                                     WHERE
-                                        aru.remoteusername = ' . db_quote($username) . '
+                                        LOWER(aru.remoteusername) = ' . db_quote($username) . '
                                         AND us.authinstance = ' . db_quote($parentid) . '
                                 )
                                 AND
@@ -213,13 +219,14 @@ class User {
                         ' . db_format_tsfield('u.lastlogin', 'lastlogin') . ',
                         ' . db_format_tsfield('u.lastlastlogin', 'lastlastlogin') . ',
                         ' . db_format_tsfield('u.lastaccess', 'lastaccess') . ',
-                        ' . db_format_tsfield('u.suspendedctime', 'suspendedctime') . '
+                        ' . db_format_tsfield('u.suspendedctime', 'suspendedctime') . ',
+                        ' . db_format_tsfield('u.ctime', 'ctime') . '
                     FROM {usr} u
                     LEFT JOIN {auth_remote_user} r ON u.id = r.localusr
                     WHERE
                         (
                             (
-                                r.remoteusername = ?
+                                LOWER(r.remoteusername) = ?
                                 AND r.authinstance = ?
                             )'
                             . $parentwhere
@@ -234,13 +241,14 @@ class User {
                         ' . db_format_tsfield('lastlogin') . ',
                         ' . db_format_tsfield('lastlastlogin') . ',
                         ' . db_format_tsfield('lastaccess') . ',
-                        ' . db_format_tsfield('suspendedctime') . '
+                        ' . db_format_tsfield('suspendedctime') . ',
+                        ' . db_format_tsfield('ctime') . '
                     FROM
                         {usr}
                     WHERE
                         LOWER(username) = ? AND
-                        authinstance = ' . db_quote($instanceid);
-            $user = get_record_sql($sql, array($username));
+                        authinstance = ?';
+            $user = get_record_sql($sql, array($username, $instanceid));
         }
 
         if (false == $user) {
@@ -251,6 +259,61 @@ class User {
         return $this;
     }
 
+    /**
+     * Populates this object with the user record identified by a mobile 'token'
+     *
+     * @throws AuthUnknownUserException If the user cannot be found. 
+     */
+    public function find_by_mobileuploadtoken($token, $username) {
+
+        if (!is_string($token)) {
+            throw new InvalidArgumentException('Input parameters must be strings to create a User object from token');
+        }
+
+        $sql = 'SELECT
+                        u.*,
+                        ' . db_format_tsfield('u.expiry', 'expiry') . ',
+                        ' . db_format_tsfield('u.lastlogin', 'lastlogin') . ',
+                        ' . db_format_tsfield('u.lastlastlogin', 'lastlastlogin') . ',
+                        ' . db_format_tsfield('u.lastaccess', 'lastaccess') . ',
+                        ' . db_format_tsfield('u.suspendedctime', 'suspendedctime') . ',
+                        ' . db_format_tsfield('u.ctime', 'ctime') . '
+                FROM
+                    {usr} u
+                    LEFT JOIN {usr_account_preference} p ON u.id = p.usr
+                            WHERE p.field=\'mobileuploadtoken\' AND p.value = ? AND u.username = ?
+		';
+
+        $user = get_record_sql($sql, array($token, $username));
+
+        if (false == $user) {
+            throw new AuthUnknownUserException("User with mobile upload token \"$token\" is not known");
+        }
+
+        $this->populate($user);
+        return $this;
+    }
+
+    /**
+     * Refreshes a users mobile 'token' and returns it
+     *
+     */
+    public function refresh_mobileuploadtoken() {
+	$new_token = md5( uniqid() );
+        $this->set_account_preference('mobileuploadtoken', $new_token);
+        $this->set('lastaccess', time());
+	$this->commit();
+	return $new_token;
+    }
+
+    /**
+     * Set stuff that needs to be initialised once before a user record is created.
+     */
+    public function create() {
+        $this->set('ctime', time());
+    }
+
+
     /**
      * Take a row object from the usr table and populate this object with the
      * values
@@ -306,7 +369,7 @@ class User {
         $this->attributes[$key] = $value;
 
         // For now, these fields are saved to the DB elsewhere
-        if ($key != 'activityprefs' && $key !=  'accountprefs') {
+        if ($key != 'activityprefs' && $key != 'accountprefs' && $key != 'views') {
             $this->changed = true;
         }
         return $this;
@@ -386,6 +449,25 @@ class User {
         $this->set('accountprefs', $accountprefs);
     }
 
+
+    public function get_view_by_type($viewtype) {
+        $views = $this->get('views');
+        if (isset($views[$viewtype])) {
+            $viewid = $views[$viewtype];
+        }
+        else {
+            $viewid = get_field('view', 'id', 'type', $viewtype, 'owner', $this->get('id'));
+        }
+        if (!$viewid) {
+            global $USER;
+            if (!$USER->get('id')) {
+                return null;
+            }
+            return $this->install_view($viewtype);
+        }
+        return new View($viewid);
+    }
+
     /**
      * Return the profile view object for this user.
      *
@@ -394,15 +476,7 @@ class User {
      * @return View
      */
     public function get_profile_view() {
-        $viewid = get_field('view', 'id', 'type', 'profile', 'owner', $this->get('id'));
-        if (!$viewid) {
-            global $USER;
-            if (!$USER->get('id')) {
-                return null;
-            }
-            return $this->install_profile_view();
-        }
-        return new View($viewid);
+        return $this->get_view_by_type('profile');
     }
 
     /**
@@ -410,7 +484,7 @@ class User {
      *
      * @return View
      */
-    private function install_profile_view() {
+    protected function install_profile_view() {
         static $systemprofileviewid = null;
 
         db_begin();
@@ -422,6 +496,7 @@ class User {
         list($view) = View::create_from_template(array(
             'owner' => $this->get('id'),
             'title' => get_field('view', 'title', 'id', $systemprofileviewid),
+            'description' => get_string('profiledescription'),
             'type'  => 'profile',
         ), $systemprofileviewid, $this->get('id'));
 
@@ -458,7 +533,69 @@ class User {
         return $view;
     }
 
+    /**
+     * Return the dashboard view object for this user.
+     *
+     * If the user does not yet have a dashboard view, one is created for them.
+     *
+     * @return View
+     */
 
+    /**
+     * Installs a user's dashboard view.
+     *
+     * @return View
+     */
+    protected function install_dashboard_view() {
+        static $systemdashboardviewid = null;
+
+        db_begin();
+        if (is_null($systemdashboardviewid)) {
+            $systemdashboardviewid = get_field('view', 'id', 'owner', 0, 'type', 'dashboard');
+        }
+
+        require_once(get_config('libroot') . 'view.php');
+        list($view) = View::create_from_template(array(
+            'owner' => $this->get('id'),
+            'title' => get_field('view', 'title', 'id', $systemdashboardviewid),
+            'description' => get_string('dashboarddescription'),
+            'type'  => 'dashboard',
+        ), $systemdashboardviewid, $this->get('id'));
+
+        db_commit();
+
+        return $view;
+    }
+
+    protected function install_view($viewtype) {
+        $function = 'install_' . $viewtype . '_view';
+        return $this->$function();
+    }
+
+    // Store the ids of the user's special views (profile, dashboard).  Users can have only
+    // one each of these, so there really should be columns in the user table to store them.
+    protected function load_views() {
+        $types = array('profile', 'dashboard');
+        $views = get_records_select_assoc(
+            'view',
+            '"owner" = ? AND type IN (' . join(',', array_map('db_quote', $types)) . ')',
+            array($this->id),
+            '',
+            'type,id'
+        );
+
+        $specialviews = array();
+        foreach ($types as $type) {
+            if (!empty($views[$type])) {
+                $specialviews[$type] = $views[$type]->id;
+            }
+            else {
+                $view = $this->install_view($type);
+                $specialviews[$type] = $view->get('id');
+            }
+        }
+        $this->set('views', $specialviews);
+    }
 
     /**
      * Determines if the user is currently logged in
@@ -473,7 +610,7 @@ class User {
         $this->stdclass = new StdClass;
         reset($this->defaults);
         foreach (array_keys($this->defaults) as $k) {
-            if ($k == 'expiry' || $k == 'lastlogin' || $k == 'lastlastlogin' || $k == 'lastaccess' || $k == 'suspendedctime') {
+            if ($k == 'expiry' || $k == 'lastlogin' || $k == 'lastlastlogin' || $k == 'lastaccess' || $k == 'suspendedctime' || $k == 'ctime') {
                 $this->stdclass->{$k} = db_format_timestamp($this->get($k));
             } else {
                 $this->stdclass->{$k} = $this->get($k);//(is_null($this->get($k))? 'NULL' : $this->get($k));
@@ -522,6 +659,12 @@ class User {
         }
     }
 
+    public function quota_refresh() {
+        $quotadata = get_record_sql('SELECT quota, quotaused FROM {usr} WHERE id = ?', array($this->get('id')));
+        $this->set('quota', $quotadata->quota);
+        $this->set("quotaused", $quotadata->quotaused);
+    }
+
     public function join_institution($institution) {
         if ($institution != 'mahara' && !$this->in_institution($institution)) {
             require_once('institution.php');
@@ -652,10 +795,18 @@ class User {
             if ($i->staff) {
                 $staffinstitutions[$i->institution] = $i->institution;
             }
-            if (!empty($i->theme) && $i->theme != get_config('theme')) {
+            if (!empty($i->theme) && $this->theme == get_config('theme') && $i->theme != $this->theme) {
                 $this->theme = $i->theme;
             }
         }
+        if ($this->authinstance) {
+            $authobj = AuthFactory::create($this->authinstance);
+            if (isset($institutions[$authobj->institution])) {
+                if ($t = $institutions[$authobj->institution]->theme) {
+                    $this->theme = $t;
+                }
+            }
+        }
         $this->institutions       = $institutions;
         $this->admininstitutions  = $admininstitutions;
         $this->staffinstitutions  = $staffinstitutions;
@@ -675,7 +826,7 @@ class User {
     public function can_view_artefact($a) {
         if ($this->get('admin')
             || ($this->get('id') and $this->get('id') == $a->get('owner'))
-            || $this->is_institutional_admin($a->get('institution'))) {
+            || ($a->get('institution') and $this->is_institutional_admin($a->get('institution')))) {
             return true;
         }
         if ($a->get('group')) {
@@ -691,7 +842,7 @@ class User {
     public function can_edit_artefact($a) {
         if ($this->get('admin')
             || ($this->get('id') and $this->get('id') == $a->get('owner'))
-            || $this->is_institutional_admin($a->get('institution'))) {
+            || ($a->get('institution') and $this->is_institutional_admin($a->get('institution')))) {
             return true;
         }
         $group = $a->get('group');
@@ -710,9 +861,23 @@ class User {
         return false;
     }
 
+    public function can_publish_artefact($a) {
+        if (($this->get('id') and $this->get('id') == $a->get('owner'))
+            || ($a->get('institution') and $this->is_institutional_admin($a->get('institution')))) {
+            return true;
+        }
+        $group = $a->get('group');
+        if ($group) {
+            return count_records_sql("SELECT COUNT(*) FROM {artefact_access_role} ar
+                INNER JOIN {group_member} g ON ar.role = g.role
+                WHERE ar.artefact = ? AND g.member = ? AND ar.can_publish = 1 AND g.group = ?", array($a->get('id'), $this->get('id'), $group));
+        }
+        return false;
+    }
+
     public function can_edit_view($v) {
         $owner = $v->get('owner');
-        if ($owner == $this->get('id')) {
+        if ($owner > 0 && $owner == $this->get('id')) {
             return true;
         }
         $institution = $v->get('institution');
@@ -723,11 +888,28 @@ class User {
         if ($group) {
             $editroles = $v->get('editingroles');
             $this->reset_grouproles();
+            if ($v->get('type') == 'grouphomepage' && $this->grouproles[$group] != 'admin') {
+                return false;
+            }
             return isset($this->grouproles[$group]) && in_array($this->grouproles[$group], $editroles);
         }
         return false;
     }
 
+    /**
+     * Function to check current user can edit collection
+     *
+     * This is fairly straightforward at the moment but it might require more
+     * if groups are allowed collections and other amendments in the future
+     */
+    public function can_edit_collection($c) {
+        $owner = $c->get('owner');
+        if ($owner == $this->get('id')) {
+            return true;
+        }
+        return false;
+    }
+
     public function can_delete_self() {
         if (!$this->get('admin')) {
             // Users who belong to an institution that doesn't allow
@@ -811,7 +993,8 @@ class LiveUser extends User {
                     ' . db_format_tsfield('lastlogin') . ',
                     ' . db_format_tsfield('lastlastlogin') . ',
                     ' . db_format_tsfield('lastaccess') . ',
-                    ' . db_format_tsfield('suspendedctime') . '
+                    ' . db_format_tsfield('suspendedctime') . ',
+                    ' . db_format_tsfield('ctime') . '
                 FROM
                     {usr}
                 WHERE
@@ -866,9 +1049,11 @@ class LiveUser extends User {
                     throw new AccessTotallyDeniedException(get_string('accesstotallydenied_institutionsuspended', 'mahara', $authinstance->displayname, $sitename));
                     return false;
                 }
+
                 return true;
             }
-        } catch  (AuthInstanceException $e) {
+        }
+        catch (AuthInstanceException $e) {
             return false;
         }
         
@@ -896,6 +1081,10 @@ class LiveUser extends User {
 
         // Unset session variables related to authentication
         $this->SESSION->set('authinstance', null);
+        if (get_config('installed') && !defined('INSTALLER') && $this->get('sessionid')
+            && function_exists('table_exists') && table_exists('usr_session')) {
+            delete_records('usr_session', 'session', $this->get('sessionid'));
+        }
 
         reset($this->defaults);
         foreach (array_keys($this->defaults) as $key) {
@@ -961,8 +1150,24 @@ class LiveUser extends User {
         if (empty($user->id)) $this->commit();
         $this->activityprefs      = load_activity_preferences($user->id);
         $this->accountprefs       = load_account_preferences($user->id);
+
+        // If user has chosen a language while logged out, save it as their lang pref.
+        $sessionlang = $this->SESSION->get('lang');
+        if (!empty($sessionlang) && $sessionlang != 'default'
+            && (empty($this->accountprefs['lang']) || $sessionlang != $this->accountprefs['lang'])) {
+            $this->set_account_preference('lang', $sessionlang);
+        }
+
+        // Set language for the current request
+        if (!empty($this->accountprefs['lang'])) {
+            current_language($this->accountprefs['lang']);
+        }
+
         $this->reset_institutions();
         $this->reset_grouproles();
+        $this->load_views();
+        $this->store_sessionid();
+
         $this->commit();
 
         // finally, after all is done, call the (maybe non existant) hook on their auth plugin
@@ -1027,6 +1232,7 @@ class LiveUser extends User {
         $this->find_by_id($id);
         $this->activityprefs = load_activity_preferences($id);
         $this->accountprefs = load_account_preferences($id);
+        $this->load_views();
     }
 
     public function change_identity_to($userid) {
@@ -1073,5 +1279,23 @@ class LiveUser extends User {
         $this->reset_institutions();
         $this->commit();
     }
+
+    public function reset_institutions() {
+        global $THEME;
+        parent::reset_institutions();
+        if (isset($THEME->basename) && $this->theme != $THEME->basename && !defined('INSTALLER')) {
+            $THEME = new Theme($this->theme);
+        }
+    }
+
+    private function store_sessionid() {
+        $sessionid = $this->get('sessionid');
+        delete_records('usr_session', 'session', $sessionid);
+        insert_record('usr_session', (object) array(
+            'usr' => $this->get('id'),
+            'session' => $sessionid,
+            'ctime' => db_format_timestamp(time()),
+        ));
+    }
+
 }
-?>
