@@ -31,10 +31,11 @@ $string['title'] = 'External Feed';
 $string['description'] = 'Embed an external RSS or ATOM feed';
 $string['feedlocation'] = 'Feed location';
 $string['feedlocationdesc'] = 'URL of a valid RSS or ATOM feed';
+$string['itemstoshow'] = 'Items to show';
+$string['itemstoshowdescription'] = 'Between 1 and 20';
 $string['showfeeditemsinfull'] = 'Show feed items in full?';
-$string['showfeeditemsinfulldesc'] = 'Whether to show a summary of the feed items, or show the description for each one too';
+$string['showfeeditemsinfulldesc'] = 'Whether to show a summary of the feed items, or show the full text for each one too';
 $string['invalidurl'] = 'That URL is invalid. You can only view feeds for http and https URLs.';
 $string['invalidfeed'] = 'The feed appears to be invalid. The error reported was: %s';
 $string['lastupdatedon'] = 'Last updated on %s';
 $string['defaulttitledescription'] = 'If you leave this blank, the title of the feed will be used';
-?>
