@@ -27,6 +27,8 @@
 
 defined('INTERNAL') || die();
 
+require_once('XML/Feed/Parser.php');
+
 class PluginBlocktypeExternalfeed extends SystemBlocktype {
 
     public static function get_title() {
@@ -38,7 +40,7 @@ class PluginBlocktypeExternalfeed extends SystemBlocktype {
     }
 
     public static function get_categories() {
-        return array('feeds');
+        return array('external');
     }
 
     public static function postinst($prevversion) {
@@ -50,17 +52,25 @@ class PluginBlocktypeExternalfeed extends SystemBlocktype {
             else if (is_mysql()) {
                 execute_sql('ALTER TABLE {blocktype_externalfeed_data} ADD UNIQUE {blocextedata_url_uix} (url(255))');
             }
+            else {
+                // TODO: support other databases
+            }
         }
     }
 
     public static function render_instance(BlockInstance $instance, $editing=false) {
         $configdata = $instance->get('configdata');
         if (!empty($configdata['feedid'])) {
-            $data = get_record('blocktype_externalfeed_data', 'id', $configdata['feedid']);
+
+            $data = $instance->get_data('feed', $configdata['feedid']);
 
             $data->content = unserialize($data->content);
             $data->image   = unserialize($data->image);
 
+            // only keep the number of entries the user asked for
+            $chunks = array_chunk($data->content, isset($configdata['count']) ? $configdata['count'] : 10);
+            $data->content = $chunks[0];
+
             // Attempt to fix relative URLs in the feeds
             if (!empty($data->image['link'])) {
                 $data->description = preg_replace(
@@ -86,12 +96,20 @@ class PluginBlocktypeExternalfeed extends SystemBlocktype {
             $smarty->assign('link', $data->link);
             $smarty->assign('entries', $data->content);
             $smarty->assign('feedimage', self::make_feed_image_tag($data->image));
-            $smarty->assign('lastupdated', get_string('lastupdatedon', 'blocktype.externalfeed', format_date(time($data->lastupdate))));
+            $smarty->assign('lastupdated', get_string('lastupdatedon', 'blocktype.externalfeed', format_date($data->lastupdate)));
             return $smarty->fetch('blocktype:externalfeed:feed.tpl');
         }
         return '';
     }
 
+    // Called by $instance->get_data('feed', ...).
+    public static function get_instance_feed($id) {
+        return get_record(
+            'blocktype_externalfeed_data', 'id', $id, null, null, null, null,
+            'id,url,link,title,description,content,' . db_format_tsfield('lastupdate') . ',image'
+        );
+    }
+
     public static function has_instance_config() {
         return true;
     }
@@ -100,7 +118,7 @@ class PluginBlocktypeExternalfeed extends SystemBlocktype {
         $configdata = $instance->get('configdata');
 
         if (!empty($configdata['feedid'])) {
-            $url = get_field('blocktype_externalfeed_data', 'url', 'id', $configdata['feedid']);
+            $url = $instance->get_data('feed', $configdata['feedid'])->url;
         }
         else {
             $url = '';
@@ -125,6 +143,15 @@ class PluginBlocktypeExternalfeed extends SystemBlocktype {
                     'maxlength' => 2048, // See install.xml for this plugin - MySQL can only safely handle up to 255 chars
                 ),
             ),
+            'count' => array(
+                'type' => 'text',
+                'title' => get_string('itemstoshow', 'blocktype.externalfeed'),
+                'description' => get_string('itemstoshowdescription', 'blocktype.externalfeed'),
+                'defaultvalue' => isset($configdata['count']) ? $configdata['count'] : 10,
+                'size' => 3,
+                'minvalue' => 1,
+                'maxvalue' => 20,
+            ),
             'full' => array(
                 'type'         => 'checkbox',
                 'title'        => get_string('showfeeditemsinfull', 'blocktype.externalfeed'),
@@ -142,7 +169,7 @@ class PluginBlocktypeExternalfeed extends SystemBlocktype {
         $configdata = $bi->get('configdata');
 
         if (!empty($configdata['feedid'])) {
-            if ($title = get_field('blocktype_externalfeed_data', 'title', 'id', $configdata['feedid'])) {
+            if ($title = $bi->get_data('feed', $configdata['feedid'])->title) {
                 return $title;
             }
         }
@@ -204,7 +231,7 @@ class PluginBlocktypeExternalfeed extends SystemBlocktype {
         $cleanup = new StdClass;
         $cleanup->callfunction = 'cleanup_feeds';
         $cleanup->hour = '3';
-        $cleanup->minute = '0';
+        $cleanup->minute = '30';
 
         return array($refresh, $cleanup);
 
@@ -212,10 +239,21 @@ class PluginBlocktypeExternalfeed extends SystemBlocktype {
 
     public static function refresh_feeds() {
         if (!$feeds = get_records_select_array('blocktype_externalfeed_data', 
-            'lastupdate < ?', array(db_format_timestamp(strtotime('-30 minutes'))))) {
+            'lastupdate < ?', array(db_format_timestamp(strtotime('-30 minutes'))),
+            '', 'id,url,' . db_format_tsfield('lastupdate', 'tslastupdate'))) {
             return;
         }
+        $yesterday = time() - 60*60*24;
         foreach ($feeds as $feed) {
+            // Hack to stop the updating of dead feeds from delaying other
+            // more important stuff that runs on cron.
+            if (defined('CRON') && $feed->tslastupdate < $yesterday) {
+                // We've been trying for 24 hours already, so waste less
+                // time on this one and just try it once a day
+                if (mt_rand(0, 24) != 0) {
+                    continue;
+                }
+            }
             try {
                 $data = self::parse_feed($feed->url);
                 $data->id = $feed->id;
@@ -269,9 +307,10 @@ class PluginBlocktypeExternalfeed extends SystemBlocktype {
             return $cache[$source];
         }
 
-        require_once('XML/Feed/Parser.php');
-
-        $config = array(CURLOPT_URL => $source);
+        $config = array(
+            CURLOPT_URL => $source,
+            CURLOPT_TIMEOUT => 15,
+        );
 
         $result = mahara_http_request($config);
 
@@ -308,7 +347,7 @@ class PluginBlocktypeExternalfeed extends SystemBlocktype {
 
         $data->content = array();
         foreach ($feed as $count => $item) {
-            if ($count == 10) {
+            if ($count == 20) {
                 break;
             }
             $description = $item->content ? $item->content : ($item->description ? $item->description : ($item->summary ? $item->summary : null));
@@ -381,7 +420,7 @@ class PluginBlocktypeExternalfeed extends SystemBlocktype {
      */
     public static function export_blockinstance_config(BlockInstance $bi) {
         $config = $bi->get('configdata');
-        $url = ($config['feedid']) ? get_field('blocktype_externalfeed_data', 'url', 'id', $config['feedid']) : '';
+        $url = !empty($config['feedid']) ? get_field('blocktype_externalfeed_data', 'url', 'id', $config['feedid']) : '';
         return array(
             'url' => $url,
             'full' => isset($config['full']) ? ($config['full'] ? 1 : 0) : 0,
@@ -420,5 +459,3 @@ class PluginBlocktypeExternalfeed extends SystemBlocktype {
     }
 
 }
-
-?>
