@@ -83,6 +83,15 @@ abstract class PluginBlocktype extends Plugin {
 
     public static abstract function render_instance(BlockInstance $instance, $editing=false);
 
+    /**
+    * This function must be implemented in the subclass if it requires
+    * javascript. It returns an array of javascript files, either local
+    * or remote.
+    */
+    public static function get_instance_javascript(BlockInstance $instance) {
+        return array();
+    }
+
     /**
      * If this blocktype contains artefacts, and uses the artefactchooser 
      * Pieform element to choose them, this method must return the definition 
@@ -116,6 +125,15 @@ abstract class PluginBlocktype extends Plugin {
         throw new SystemException(get_string('blocktypemissingconfigform', 'error', $instance->get('blocktype')));
     }
 
+    /**
+    * Thus function must be implemented in the subclass is it has an
+    * instance config form that requires javascript. It returns an
+    * array of javascript files, either local or remote.
+    */
+    public static function get_instance_config_javascript(BlockInstance $instance) {
+        return array();
+    }
+
     /**
      * Blocktype plugins can implement this to perform custom pieform 
      * validation, should they need it
@@ -176,8 +194,15 @@ abstract class PluginBlocktype extends Plugin {
 
         $blocktypes = array();
 
+        if (function_exists('local_get_allowed_blocktypes')) {
+            $localallowed = local_get_allowed_blocktypes($category, $view);
+        }
+
         foreach ($bts as $bt) {
             $namespaced = blocktype_single_to_namespaced($bt->name, $bt->artefactplugin);
+            if (isset($localallowed) && is_array($localallowed) && !in_array($namespaced, $localallowed)) {
+                continue;
+            }
             safe_require('blocktype', $namespaced); 
             // Note for later: this is Blocktype::allowed_in_view, which 
             // returns true if the blocktype should be insertable into the 
@@ -305,7 +330,7 @@ abstract class PluginBlocktype extends Plugin {
     }
 
     /**
-     * Exports configuration data the format required for LEAP2A export.
+     * Exports configuration data the format required for Leap2A export.
      *
      * This format is XML, and as the exporter can't generate complicated XML
      * structures, we have to json_encode all the values.
@@ -351,6 +376,31 @@ abstract class PluginBlocktype extends Plugin {
         return $bi;
     }
 
+    /**
+     * defines if the title should be shown if there is no content in the block
+     *
+     * If the title of the block should be hidden when there is no content,
+     * override the the function in the blocktype class.
+     *
+     * @return boolean  whether the title of the block should be shown or not
+     */
+    public static function hide_title_on_empty_content() {
+        return false;
+    }
+
+    /**
+     * Defines if the title should be linked to an artefact view (if possible)
+     * when viewing the block
+     *
+     * This method should be overridden in the child class, if a title link
+     * is not desired.
+     *
+     * @return boolean whether to link the title or not
+     */
+    public static function has_title_link() {
+        return true;
+    }
+
 }
 
 abstract class SystemBlockType extends PluginBlockType {
@@ -382,6 +432,8 @@ class BlockInstance {
     private $canmoveup;
     private $canmovedown;
     private $maxorderincolumn;
+    private $artefacts = array();
+    private $temp = array();
 
     public function __construct($id=0, $data=null) {
          if (!empty($id)) {
@@ -468,20 +520,22 @@ class BlockInstance {
         $title = (isset($values['title'])) ? $values['title'] : '';
         unset($values['title']);
         $this->set('configdata', $values);
+        $this->set('title', $title);
 
-        $blocktypeclass = generate_class_name('blocktype', $this->get('blocktype'));
-        if (!$title && $title !== '0' && method_exists($blocktypeclass, 'get_instance_title')) {
-            // Get the default title for the block if one isn't set
-            $title = call_static_method($blocktypeclass, 'get_instance_title', $this);
+        try {
+            $rendered = $this->render_editing(false, false, $form->submitted_by_js());
+        }
+        catch (HTMLPurifier_Exception $e) {
+            $message = get_string('blockconfigurationrenderingerror', 'view') . ' ' . $e->getMessage();
+            $form->reply(PIEFORM_ERR, array('message' => $message));
         }
 
-        $this->set('title', $title);
         $this->commit();
 
         $result = array(
             'error'   => false,
             'message' => get_string('blockinstanceconfiguredsuccessfully', 'view'),
-            'data'    => $this->render_editing(false, false, $form->submitted_by_js()),
+            'data'    => $rendered,
             'blockid' => $this->get('id'),
             'viewid'  => $this->get('view'),
         );
@@ -497,6 +551,20 @@ class BlockInstance {
         $form->reply(PIEFORM_OK, $result);
     }
 
+    public function get_title() {
+        $blocktypeclass = generate_class_name('blocktype', $this->get('blocktype'));
+        if ($override = call_static_method($blocktypeclass, 'override_instance_title', $this)) {
+            return $override;
+        }
+        if ($title = $this->get('title') and $title != '') {
+            return $title;
+        }
+        if (method_exists($blocktypeclass, 'get_instance_title')) {
+            return call_static_method($blocktypeclass, 'get_instance_title', $this);
+        }
+        return '';
+    }
+
     /**
      * Builds the HTML for the block, inserting the blocktype content at the 
      * appropriate place
@@ -511,6 +579,9 @@ class BlockInstance {
         $js = '';
         $movecontrols = array();
 
+        $blocktypeclass = generate_class_name('blocktype', $this->get('blocktype'));
+        $title = $this->get_title();
+
         if ($configure) {
             list($content, $js) = array_values($this->build_configure_form($new));
         }
@@ -535,9 +606,7 @@ class BlockInstance {
                     $movecontrols[] = array(
                         'column' => $this->get('column') - 1,
                         'order'  => $this->get('order'),
-                        'title'  => trim($this->get('title')) == '' ?
-                                           get_string('movethisblockleft', 'view') :
-                                           get_string('moveblockleft', 'view', "'".$this->get('title')."'"),
+                        'title'  => $title == '' ? get_string('movethisblockleft', 'view') : get_string('moveblockleft', 'view', "'$title'"),
                         'arrow'  => '&larr;',
                         'dir'    => 'left',
                     );
@@ -546,9 +615,7 @@ class BlockInstance {
                     $movecontrols[] = array(
                         'column' => $this->get('column'),
                         'order'  => $this->get('order') + 1,
-                        'title'  => trim($this->get('title')) == '' ?
-                                           get_string('movethisblockdown', 'view') :
-                                           get_string('moveblockdown', 'view', "'".$this->get('title')."'"),
+                        'title'  => $title == '' ? get_string('movethisblockdown', 'view') : get_string('moveblockdown', 'view', "'$title'"),
                         'arrow'  => '&darr;',
                         'dir'    => 'down',
                     );
@@ -557,9 +624,7 @@ class BlockInstance {
                     $movecontrols[] = array(
                         'column' => $this->get('column'),
                         'order'  => $this->get('order') - 1,
-                        'title'  => trim($this->get('title')) == '' ?
-                                           get_string('movethisblockup', 'view') :
-                                           get_string('moveblockup', 'view', "'".$this->get('title')."'"),
+                        'title'  => $title == '' ? get_string('movethisblockup', 'view') : get_string('moveblockup', 'view', "'$title'"),
                         'arrow'  => '&uarr;',
                         'dir'    => 'up',
                     );
@@ -568,32 +633,33 @@ class BlockInstance {
                     $movecontrols[] = array(
                         'column' => $this->get('column') + 1,
                         'order'  => $this->get('order'),
-                        'title'  => trim($this->get('title')) == '' ?
-                                           get_string('movethisblockright', 'view') :
-                                           get_string('moveblockright', 'view', "'".$this->get('title')."'"),
+                        'title'  => $title == '' ? get_string('movethisblockright', 'view') : get_string('moveblockright', 'view', "'$title'"),
                         'arrow'  => '&rarr;',
                         'dir'    => 'right',
                     );
                 }
             }
         }
+
+        $configtitle = $title == '' ? call_static_method($blocktypeclass, 'get_title') : $title;
+
         $smarty = smarty_core();
 
         $smarty->assign('id',     $this->get('id'));
         $smarty->assign('viewid', $this->get('view'));
-        $title = call_static_method(generate_class_name('blocktype', $this->get('blocktype')), 'override_instance_title', $this);
-        $smarty->assign('title', $title ? $title : $this->get('title'));
+        $smarty->assign('title',  $title);
         $smarty->assign('column', $this->get('column'));
         $smarty->assign('order',  $this->get('order'));
 
         $smarty->assign('movecontrols', $movecontrols);
-        $smarty->assign('configurable', call_static_method(generate_class_name('blocktype', $this->get('blocktype')), 'has_instance_config'));
+        $smarty->assign('configurable', call_static_method($blocktypeclass, 'has_instance_config'));
         $smarty->assign('configure', $configure); // Used by the javascript to rewrite the block, wider.
+        $smarty->assign('configtitle',  $configtitle);
         $smarty->assign('content', $content);
         $smarty->assign('javascript', defined('JSON'));
         $smarty->assign('strnotitle', get_string('notitle', 'view'));
-        $smarty->assign('strconfigtitletext', trim($this->get('title')) == '' ? get_string('configurethisblock', 'view') : get_string('configureblock', 'view', "'".$this->get('title')."'"));
-        $smarty->assign('strremovetitletext', trim($this->get('title')) == '' ? get_string('removethisblock', 'view') : get_string('removeblock', 'view', "'".$this->get('title')."'"));
+        $smarty->assign('strconfigtitletext', $title == '' ? get_string('configurethisblock', 'view') : get_string('configureblock', 'view', "'$title'"));
+        $smarty->assign('strremovetitletext', $title == '' ? get_string('removethisblock', 'view') : get_string('removeblock', 'view', "'$title'"));
 
         return array('html' => $smarty->fetch('view/blocktypecontainerediting.tpl'), 'javascript' => $js);
     }
@@ -601,8 +667,9 @@ class BlockInstance {
     public function render_viewing() {
 
         safe_require('blocktype', $this->get('blocktype'));
+        $classname = generate_class_name('blocktype', $this->get('blocktype'));
         try {
-            $content = call_static_method(generate_class_name('blocktype', $this->get('blocktype')), 'render_instance', $this);
+            $content = call_static_method($classname, 'render_instance', $this);
         }
         catch (ArtefactNotFoundException $e) {
             // Whoops - where did the image go? There is possibly a bug
@@ -619,17 +686,26 @@ class BlockInstance {
         $smarty = smarty_core();
         $smarty->assign('id',     $this->get('id'));
         $smarty->assign('blocktype', $this->get('blocktype'));
-        $title = call_static_method(generate_class_name('blocktype', $this->get('blocktype')), 'override_instance_title', $this);
-        $smarty->assign('title', $title ? $title : $this->get('title'));
+        // hide the title if required and no content is present
+        if (call_static_method($classname, 'hide_title_on_empty_content')
+            && !trim($content)) {
+            return;
+        }
+        $smarty->assign('title', $this->get_title());
 
         // If this block is for just one artefact, we set the title of the
         // block to be a link to view more information about that artefact
         $configdata = $this->get('configdata');
         if (!empty($configdata['artefactid'])) {
-            $smarty->assign('viewartefacturl', get_config('wwwroot') . 'view/artefact.php?artefact='
-                . $configdata['artefactid'] . '&view=' . $this->get('view'));
+            if (call_static_method($classname, 'has_title_link')) {
+                $smarty->assign('viewartefacturl', get_config('wwwroot') . 'view/artefact.php?artefact='
+                    . $configdata['artefactid'] . '&view=' . $this->get('view'));
+            }
         }
 
+        if (method_exists($classname, 'feed_url')) {
+            $smarty->assign('feedlink', call_static_method($classname, 'feed_url', $this));
+        }
         $smarty->assign('content', $content);
 
         return $smarty->fetch('view/blocktypecontainerviewing.tpl');
@@ -649,32 +725,30 @@ class BlockInstance {
         }
 
         safe_require('blocktype', $this->get('blocktype'));
-        $elements = call_static_method(generate_class_name('blocktype', $this->get('blocktype')), 'instance_config_form', $this, $this->get_view()->get('template'));
-
         $blocktypeclass = generate_class_name('blocktype', $this->get('blocktype'));
-        if ($this->get('title') != call_static_method($blocktypeclass, 'get_title')) {
-            // If the title for this block has been set to something other than 
-            // the block title, use it unconditionally
-            $title = $this->get('title');
-        }
-        else if (method_exists($blocktypeclass, 'get_instance_title')) {
-            // Block types can specify a default title for a block
-            $title = call_static_method($blocktypeclass, 'get_instance_title', $this);
-        }
-        else {
-            // A block that doesn't have a method for setting an instance 
-            // title, and hasn't had its title changed (e.g. a new textbox)
-            $title = $this->get('title');
-        }
+        $elements = call_static_method($blocktypeclass, 'instance_config_form', $this, $this->get_view()->get('template'));
+
+        // @todo: If we know the title is going to be overridden in override_instance_title(),
+        // hide or disable the title field in the form.  Currently not a problem, because the
+        // blocktypes that override the instance title don't have configurable instances.
+        // Maybe just remove or simplify title in the elements list below and make all the
+        // blocktype classes pass the title element in their instance_config_form().
+
+        // Block types may specify a method to generate a default title for a block
+        $hasdefault = method_exists($blocktypeclass, 'get_instance_title');
+
+        $title = $this->get('title');
 
         $elements = array_merge(
             array(
                 'title' => array(
                     'type' => 'text',
                     'title' => get_string('blocktitle', 'view'),
-                    'description' => (method_exists($blocktypeclass, 'get_instance_title'))
-                        ? get_string('defaulttitledescription', 'blocktype.' . blocktype_name_to_namespaced($this->get('blocktype'))) : null,
+                    'description' => $hasdefault ? get_string('defaulttitledescription', 'blocktype.' . blocktype_name_to_namespaced($this->get('blocktype'))) : null,
                     'defaultvalue' => $title,
+                    'rules' => array('maxlength' => 255),
+                    'hidewhenempty' => $hasdefault,
+                    'expandtext'    => get_string('setblocktitle'),
                 ),
                 'blockconfig' => array(
                     'type'  => 'hidden',
@@ -770,6 +844,24 @@ class BlockInstance {
             }
         }
 
+        $configjs = call_static_method($blocktypeclass, 'get_instance_config_javascript', $this);
+        foreach($configjs as &$jsfile) {
+            if(strpos($jsfile, 'http://') === false) {
+                if($this->artefactplugin) {
+                    $jsfile = 'artefact/' . $this->artefactplugin . '/blocktype/' .
+                        $this->blocktype . '/' . $jsfile;
+                }
+                else {
+                    $jsfile = 'blocktype/' . $this->blocktype . '/' . $jsfile;
+                }
+                $jsfile = '$j.getScript("' . get_config('wwwroot') . $jsfile . '");';
+            }
+            else {
+                $jsfile = '$j.getScript("' . $jsfile . '");';
+            }
+        }
+        $js .= implode('', $configjs);
+
         $renderedform = array('html' => $html, 'javascript' => $js);
         return $renderedform;
     }
@@ -836,7 +928,7 @@ class BlockInstance {
         // Get list of allowed artefacts
         require_once('view.php');
         $searchdata = array(
-            'extraselect'          => 'id IN (' . join(',', $artefacts) . ')',
+            'extraselect'          => array(array('fieldname' => 'id', 'type' => 'int', 'values' => $artefacts)),
             'userartefactsallowed' => true,  // If this is a group view, the user can add personally owned artefacts
         );
         list($allowed, $count) = View::get_artefactchooser_artefacts(
@@ -931,7 +1023,7 @@ class BlockInstance {
         }
 
         if (isset($configdata['artefactids']) && is_array($configdata['artefactids'])) {
-            $configdata['artefactids'] = array_diff($configdata['artefactids'], array($artefact));
+            $configdata['artefactids'] = array_values(array_diff($configdata['artefactids'], array($artefact)));
             $changed = true;
         }
 
@@ -971,7 +1063,7 @@ class BlockInstance {
                 }
             }
             else if (isset($blockdata->configdata['artefactids'])) {
-                $blockdata->configdata['artefactids'] = array_diff($blockdata->configdata['artefactids'], $blockdata->artefacts);
+                $blockdata->configdata['artefactids'] = array_values(array_diff($blockdata->configdata['artefactids'], $blockdata->artefacts));
                 $change = true;
             }
             if ($change) {
@@ -984,6 +1076,10 @@ class BlockInstance {
      * Get an artefact instance, checking republish permissions
      */
     public function get_artefact_instance($id) {
+        if (isset($this->artefacts[$id])) {
+            return $this->artefacts[$id];
+        }
+
         require_once(get_config('docroot') . 'artefact/lib.php');
         $a = artefact_instance_from_id($id);
         $viewowner = $this->get_view()->get('owner');
@@ -997,7 +1093,8 @@ class BlockInstance {
                 throw new ArtefactNotFoundException(get_string('artefactnotpublishable', 'mahara', $id, $this->get_view()->get('id')));
             }
         }
-        return $a;
+
+        return $this->artefacts[$id] = $a;
     }
 
 
@@ -1108,7 +1205,14 @@ class BlockInstance {
         return true;
     }
 
+    public function get_data($key, $id) {
+        if (!isset($this->temp[$key][$id])) {
+            $blocktypeclass = generate_class_name('blocktype', $this->get('blocktype'));
+            if (!isset($this->temp[$key])) {
+                $this->temp[$key] = array();
+            }
+            $this->temp[$key][$id] = call_static_method($blocktypeclass, 'get_instance_' . $key, $id);
+        }
+        return $this->temp[$key][$id];
+    }
 }
-
-
-?>
