@@ -29,6 +29,8 @@ defined('INTERNAL') || die();
 
 $CFG = new StdClass;
 $CFG->docroot = dirname(__FILE__) . '/';
+//array containing site options from database that are overrided by $CFG
+$OVERRIDDEN = array();
 
 // Figure out our include path
 if (!empty($_SERVER['MAHARA_LIBDIR'])) {
@@ -63,7 +65,7 @@ $CFG = (object)array_merge((array)$cfg, (array)$CFG);
 
 // Fix up paths in $CFG
 foreach (array('docroot', 'dataroot') as $path) {
-    $CFG->{$path} = (substr($CFG->{$path}, -1) != DIRECTORY_SEPARATOR) ? $CFG->{$path} . DIRECTORY_SEPARATOR : $CFG->{$path};
+    $CFG->{$path} = (substr($CFG->{$path}, -1) != '/') ? $CFG->{$path} . '/' : $CFG->{$path};
 }
 
 // xmldb stuff
@@ -156,7 +158,7 @@ catch (SQLException $e) {
 }
 
 // Make sure wwwroot is set and available, either in the database or in the
-// config file. Cron requires it for some purposes.
+// config file. Cron requires it when sending out forums emails.
 if (!isset($CFG->wwwroot) && isset($_SERVER['HTTP_HOST'])) {
     $proto = (isset($_SERVER['HTTPS']) && strtolower($_SERVER['HTTPS']) != 'off') ? 'https://' : 'http://';
     $host  =  (isset($_SERVER['HTTP_X_FORWARDED_HOST'])) ? $_SERVER['HTTP_X_FORWARDED_HOST'] : $_SERVER['HTTP_HOST'];
@@ -164,7 +166,10 @@ if (!isset($CFG->wwwroot) && isset($_SERVER['HTTP_HOST'])) {
         list($host) = explode(',', $host);
         $host = trim($host);
     }
-    $path  = substr(dirname(__FILE__), strlen($_SERVER['DOCUMENT_ROOT']));
+    $path = '';
+    if (strpos(dirname(__FILE__), strlen($_SERVER['DOCUMENT_ROOT'])) === 0) {
+        $path  = substr(dirname(__FILE__), strlen($_SERVER['DOCUMENT_ROOT']));
+    }
     if ($path) {
         $path = str_replace('\\', '/', $path);  // windows
         if (substr($path, 0, 1) != '/') {
@@ -183,11 +188,16 @@ if (!isset($CFG->wwwroot) && isset($_SERVER['HTTP_HOST'])) {
         $CFG->wwwroot = $wwwroot;
     }
 }
-if (isset($CFG->httpswwwroot)) {
-    if (substr($CFG->httpswwwroot, -1, 1) != '/') {
-        $CFG->httpswwwroot .= '/';
+if (isset($CFG->wwwroot)) {
+    if (substr($CFG->wwwroot, -1, 1) != '/') {
+        $CFG->wwwroot .= '/';
     }
 }
+// Make sure that we are using ssl if wwwroot expects us to do so
+if (isset($_SERVER['REMOTE_ADDR']) && (!isset($_SERVER['HTTPS']) || strtolower($_SERVER['HTTPS']) == 'off') &&
+    parse_url($CFG->wwwroot, PHP_URL_SCHEME) === 'https'){
+    redirect(get_relative_script_path());
+}
 if (!isset($CFG->noreplyaddress) && isset($_SERVER['HTTP_HOST'])) {
     $noreplyaddress = 'noreply@';
     $host  =  (isset($_SERVER['HTTP_X_FORWARDED_HOST'])) ? $_SERVER['HTTP_X_FORWARDED_HOST'] : $_SERVER['HTTP_HOST'];
@@ -232,7 +242,16 @@ header('Content-type: text/html; charset=UTF-8');
 require_once('auth/lib.php');
 $SESSION = Session::singleton();
 $USER    = new LiveUser();
-$THEME   = new Theme($USER);
+
+// try to set the theme, or catch the thrown exception (eg if the name is invalid)
+try {
+    $THEME   = new Theme($USER);
+} catch (SystemException $exception) {
+    // set the theme to 'default' and put up an error message
+    $THEME = new Theme('default');
+    $SESSION->add_error_msg($exception->getMessage());
+}
+
 // The installer does its own auth_setup checking, because some upgrades may
 // break logging in and so need to allow no logins.
 if (!defined('INSTALLER')) {
@@ -294,7 +313,7 @@ function init_performance_info() {
     global $PERF;
   
     $PERF = new StdClass;
-    $PERF->dbreads = $PERF->dbwrites = 0;
+    $PERF->dbreads = $PERF->dbwrites = $PERF->dbcached = 0;
     $PERF->logwrites = 0;
     if (function_exists('microtime')) {
         $PERF->starttime = microtime();
@@ -306,5 +325,3 @@ function init_performance_info() {
         $PERF->startposixtimes = posix_times();  
     }
 }
-
-?>
