@@ -68,9 +68,9 @@ $forums = get_records_sql_array(
     array($USER->get('id'), $groupid)
 );
 
-// query gets a new forum object for every moderator of that forum
-// this combines all moderators together into one object per forum
 if ($forums) {
+    // query gets a new forum object for every moderator of that forum
+    // this combines all moderators together into one object per forum
     $count = count($forums);
     for ($i = 0; $i < $count; $i++) {
         $forums[$i]->moderators = array();
@@ -83,54 +83,62 @@ if ($forums) {
             $forums[$temp]->moderators[] = $forums[$i]->moderator;
             unset($forums[$i]);
         }
-   }
-}
+    }
 
-$i = 0;
-if ($forums && $membership) {
+    $i = 0;
     foreach ($forums as $forum) {
-        $forum->subscribe = pieform(array(
-            'name'     => 'subscribe_forum' . ($i == 0 ? '' : $i),
-            'plugintype' => 'interaction',
-            'pluginname' => 'forum',
-            'validatecallback' => 'subscribe_forum_validate',
-            'successcallback' => 'subscribe_forum_submit',
-            'autofocus' => false,
-            'elements' => array(
-                'submit' => array(
+        $forum->feedlink = get_config('wwwroot') . 'interaction/forum/atom.php?type=f&id=' . $forum->id;
+
+        if ($membership) {
+            $forum->subscribe = pieform(array(
+                'name'     => 'subscribe_forum' . ($i == 0 ? '' : $i),
+                'plugintype' => 'interaction',
+                'pluginname' => 'forum',
+                'validatecallback' => 'subscribe_forum_validate',
+                'successcallback' => 'subscribe_forum_submit',
+                'autofocus' => false,
+                'elements' => array(
+                    'submit' => array(
                     'type'  => 'submit',
-                    'class' => 'btn-subscribe',
-                    'value' => $forum->subscribed ? get_string('Unsubscribe', 'interaction.forum') : get_string('Subscribe', 'interaction.forum'),
-                    'help' => $i == 0 ? true : false
-                ),
-                'forum' => array(
-                    'type' => 'hidden',
-                    'value' => $forum->id
-                ),
-                'redirect' => array(
-                    'type' => 'hidden',
-                    'value' => 'index'
-                ),
-                'group' => array(
-                    'type' => 'hidden',
-                    'value' => $groupid
-                ),
-                'type' => array(
-                    'type' => 'hidden',
-                    'value' => $forum->subscribed ? 'unsubscribe' : 'subscribe'
+                        'class' => 'btn-subscribe',
+                        'value' => $forum->subscribed ? get_string('Unsubscribe', 'interaction.forum') : get_string('Subscribe', 'interaction.forum'),
+                        'help' => $i == 0 ? true : false
+                    ),
+                    'forum' => array(
+                        'type' => 'hidden',
+                        'value' => $forum->id
+                    ),
+                    'redirect' => array(
+                        'type' => 'hidden',
+                        'value' => 'index'
+                    ),
+                    'group' => array(
+                        'type' => 'hidden',
+                        'value' => $groupid
+                    ),
+                    'type' => array(
+                        'type' => 'hidden',
+                        'value' => $forum->subscribed ? 'unsubscribe' : 'subscribe'
+                    ),
                 )
-            )
-        ));
-        $i++;
+            ));
+            $i++;
+        }
     }
 }
 
-$smarty = smarty();
+$feedlink = get_config('wwwroot') . 'interaction/forum/atom.php?type=g&id=' . $group->id;
+$headers = array();
+if ($group->public) {
+    $headers[] ='<link rel="alternate" type="application/atom+xml" href="' . $feedlink . '" />';
+}
+
+$smarty = smarty(array(), $headers, array(), array());
 $smarty->assign('groupid', $groupid);
+$smarty->assign('publicgroup', $group->public);
+$smarty->assign('feedlink', $feedlink);
 $smarty->assign('heading', $group->name);
 $smarty->assign('admin', $membership == 'admin');
 $smarty->assign('groupadmins', group_get_admin_ids($groupid));
 $smarty->assign('forums', $forums);
 $smarty->display('interaction:forum:index.tpl');
-
-?>
