@@ -1,8 +1,24 @@
 /**
  * Javascript for the views interface
+ * @source: http://gitorious.org/mahara/mahara
  *
- * Copyright: 2006-2008 Catalyst IT Ltd
- * This file is licensed under the same terms as Mahara itself
+ * @licstart
+ * Copyright (C) 2006-2010  Catalyst IT Ltd
+ *
+ * The JavaScript code in this page is free software: you can
+ * redistribute it and/or modify it under the terms of the GNU
+ * General Public License (GNU GPL) as published by the Free Software
+ * Foundation, either version 3 of the License, or (at your option)
+ * any later version.  The code is distributed WITHOUT ANY WARRANTY;
+ * without even the implied warranty of MERCHANTABILITY or FITNESS
+ * FOR A PARTICULAR PURPOSE.  See the GNU GPL for more details.
+ *
+ * As additional permission under GNU GPL version 3 section 7, you
+ * may distribute non-source (e.g., minimized or compacted) forms of
+ * that code without the copy of the GNU GPL normally required by
+ * section 4, provided you include this license notice and a URL
+ * through which recipients can access the Corresponding Source.
+ * @licend
  */
 
 function ViewManager() {
@@ -10,6 +26,7 @@ function ViewManager() {
 
     this.init = function () {
         self.bottomPane = $('bottom-pane');
+        self.viewThemeSelect = $('viewtheme-select');
 
         if (!self.isIE6) {
             // Set up the column container reference, and make the container the
@@ -62,6 +79,9 @@ function ViewManager() {
             // Change the intruction to be for ajax
             self.ajaxInstructions();
 
+            // Wire up the view theme selector
+            self.rewriteViewThemeSelector();
+
             // Make the top pane a dropzone for cancelling adding block types
             if (!self.isIE6) {
                 var count = 0;
@@ -76,6 +96,12 @@ function ViewManager() {
                 });
             }
         }
+        // Unhide the radio button if the browser is iPhone, IPad or IPod
+        else if ((navigator.userAgent.match(/iPhone/i)) || (navigator.userAgent.match(/iPod/i)) || (navigator.userAgent.match(/iPad/i))) {
+            forEach(getElementsByTagAndClassName('input', 'blocktype-radio', 'top-pane'), function(i) {
+                    setNodeAttribute(i, 'style', 'display:inline');
+                });
+        }
 
         // Now we're done, remove the loading message and display the page
         removeElement('views-loading');
@@ -269,6 +295,11 @@ function ViewManager() {
         var contentDiv = getFirstElementByTagAndClassName('div', 'blockinstance-content', blockinstance);
 
         var pd = {'id': $('viewid').value, 'change': 1};
+        if (config.blockeditormaxwidth) {
+            // Shouldn't have to pass browser window dimensions here, but can't find
+            // another way to get tinymce elements to use up the available height.
+            pd['cfheight'] = getViewportDimensions().h - 100;
+        }
         pd[getNodeAttribute(button, 'name')] = 1;
 
         var oldContent = contentDiv.innerHTML;
@@ -346,16 +377,32 @@ function ViewManager() {
         hideElement(newblock);
         appendChildNodes(getFirstElementByTagAndClassName('body'), newblock);
 
-        var d = getElementDimensions(newblock);
-        var vpdim = getViewportDimensions();
-        var newtop = getViewportPosition().y + Math.max((vpdim.h - d.h) / 2, 5);
-        setStyle(newblock, {
-            'width': d.w + 'px',
-            'left': (vpdim.w - d.w) / 2 + 'px',
-            'top': newtop + 'px',
+        var style = {
             'position': 'absolute',
             'z-index': 1
-        });
+        };
+
+        var d = getElementDimensions(newblock);
+        var vpdim = getViewportDimensions();
+
+        var h = Math.max(d.h, 200);
+        var w = Math.max(d.w, 500);
+        if (config.blockeditormaxwidth && getFirstElementByTagAndClassName('textarea', 'wysiwyg', newblock)) {
+            w = vpdim.w - 80;
+            style.height = h + 'px';
+        }
+
+        var tborder = parseFloat(getStyle(newblock, 'border-top-width'));
+        var tpadding = parseFloat(getStyle(newblock, 'padding-top'));
+        var newtop = getViewportPosition().y + Math.max((vpdim.h - h) / 2 - tborder - tpadding, 5);
+        style.top = newtop + 'px';
+
+        var lborder = parseFloat(getStyle(newblock, 'border-left-width'));
+        var lpadding = parseFloat(getStyle(newblock, 'padding-left'));
+        style.left = ((vpdim.w - w) / 2 - lborder - lpadding) + 'px';
+        style.width = w + 'px';
+
+        setStyle(newblock, style);
 
         var deletebutton = getFirstElementByTagAndClassName('input', 'deletebutton', newblock);
 
@@ -763,6 +810,22 @@ function ViewManager() {
         $('blocksinstruction').innerHTML = get_string('blocksinstructionajax');
     }
 
+    /**
+     * Wire up the view theme selector
+     */
+    this.rewriteViewThemeSelector = function() {
+        if (!self.viewThemeSelect) {
+            return;
+        }
+        var currentTheme = self.viewThemeSelect.selectedIndex;
+        connect(self.viewThemeSelect, 'onchange', function(e) {
+            var choice = self.viewThemeSelect.options[self.viewThemeSelect.selectedIndex];
+            if (self.viewThemeSelect.selectedIndex != currentTheme && choice.value) {
+                self.viewThemeSelect.form.submit();
+            }
+        });
+    }
+
     /**
      * Place hotzones over the blockinstances on the page, so that we can work
      * out where to drop the blockinstance.
@@ -963,6 +1026,9 @@ function ViewManager() {
                     'change': 1,
                     'blocktype': getFirstElementByTagAndClassName('input', 'blocktype-radio', self.currentlyMovingObject).value
                 };
+                if (config.blockeditormaxwidth) {
+                    pd['cfheight'] = getViewportDimensions().h - 100;
+                }
                 pd['action_addblocktype_column_' + whereTo['column'] + '_order_' + whereTo['order']] = true;
                 sendjsonrequest(config['wwwroot'] + 'view/blocks.json.php', pd, 'POST', function(data) {
                     var div = DIV();
@@ -1109,12 +1175,20 @@ function ViewManager() {
     // The bottom pane - set in self.init
     this.bottomPane = null;
 
+    // The view theme select element - set in self.init
+    this.viewThemeSelect = null;
+
     // Whether the browser is IE7 - needed for some hacks
     this.isIE7 = document.all && document.documentElement && typeof(document.documentElement.style.maxHeight) != "undefined" && !window.opera;
 
     // Whether the browser is IE6
     this.isIE6 = !this.isIE7 && document.all && !window.opera;
 
+    // Whether the brower is iPhone, IPad or IPod
+    if ((navigator.userAgent.match(/iPhone/i)) || (navigator.userAgent.match(/iPod/i)) || (navigator.userAgent.match(/iPad/i))) {
+        this.isIE6 = true; // work-around for broken drag-and-drop
+    }
+
     addLoadEvent(self.init);
 }
 
@@ -1138,5 +1212,4 @@ function blockConfigError(form, data) {
         eval(data.formelementerror + '(form, data)');
         return;
     }
-    formError(form, data);
 }
