@@ -60,9 +60,8 @@ else {
     $data = search_user($query, $limit, $offset, $options);
 }
 
-json_headers();
-$data['error'] = false;
-$data['message'] = false;
-echo json_encode($data);
+foreach ($data['data'] as &$result) {
+    $result = array('id' => $result['id'], 'name' => $result['name']);
+}
 
-?>
+json_reply(false, $data);
