@@ -34,9 +34,12 @@ defined('INTERNAL') || die();
  * @param string $activitytype type of activity
  * @param mixed $data data 
  */
-function activity_occurred($activitytype, $data, $plugintype=null, $pluginname=null, $overridedelay=false) {
+function activity_occurred($activitytype, $data, $plugintype=null, $pluginname=null, $delay=null) {
     $at = activity_locate_typerecord($activitytype, $plugintype, $pluginname);
-    if (!empty($at->delay) && !$overridedelay) {
+    if (is_null($delay)) {
+        $delay = !empty($at->delay);
+    }
+    if ($delay) {
         $delayed = new StdClass;
         $delayed->type = $at->id;
         $delayed->data = serialize($data);
@@ -96,7 +99,8 @@ function activity_get_users($activitytype, $userids=null, $userobjs=null, $admin
     $sql = '
         SELECT
             u.id, u.username, u.firstname, u.lastname, u.preferredname, u.email, u.admin, u.staff, 
-            p.method, ap.value AS lang, aic.value AS mnethostwwwroot, h.appname AS mnethostapp
+            p.method, ap.value AS lang, apm.value AS maildisabled, aic.value AS mnethostwwwroot,
+            h.appname AS mnethostapp
         FROM {usr} u
         LEFT JOIN {usr_activity_preference} p
             ON (p.usr = u.id AND p.activity = ?)' . (empty($admininstitutions) ? '' : '
@@ -105,6 +109,8 @@ function activity_get_users($activitytype, $userids=null, $userobjs=null, $admin
                 AND ui.institution IN ('.join(',',array_map('db_quote',$admininstitutions)).'))') . '
         LEFT OUTER JOIN {usr_account_preference} ap
             ON (ap.usr = u.id AND ap.field = \'lang\')
+        LEFT OUTER JOIN {usr_account_preference} apm
+            ON (apm.usr = u.id AND ap.field = \'maildisabled\')
         LEFT OUTER JOIN {auth_instance} ai
             ON (ai.id = u.authinstance AND ai.authname = \'xmlrpc\')
         LEFT OUTER JOIN {auth_instance_config} aic
@@ -124,7 +130,7 @@ function activity_get_users($activitytype, $userids=null, $userobjs=null, $admin
         $sql .= '
         GROUP BY
             u.id, u.username, u.firstname, u.lastname, u.preferredname, u.email, u.admin, u.staff,
-            p.method, ap.value, aic.value, h.appname
+            p.method, ap.value, apm.value, aic.value, h.appname
         HAVING (u.admin = 1 OR SUM(ui.admin) > 0)';
     } else if ($adminonly) {
         $sql .= ' AND u.admin = 1';
@@ -228,20 +234,21 @@ function activity_get_viewaccess_users($view, $owner, $type) {
                     FROM {usr_friend} f
                     JOIN {view} v ON (v.owner = f.usr1 OR v.owner = f.usr2)
                     JOIN {view_access} vu ON vu.view = v.id
-                        WHERE (usr1 = ? OR usr2 = ?) AND vu.accesstype = ? AND v.id = ? 
+                        WHERE (usr1 = ? OR usr2 = ?) AND vu.accesstype = 'friends' AND v.id = ? 
                 UNION SELECT usr AS userid 
-                    FROM {view_access_usr} u 
+                    FROM {view_access} u 
                         WHERE u.view = ?
                 UNION SELECT m.member 
                     FROM {group_member} m
-                    JOIN {view_access_group} vg ON vg.group = m.group
-                    JOIN {group} g ON (g.id = vg.group AND g.deleted = 0)
+                    JOIN {view_access} vg ON vg.group = m.group
+                    JOIN {group} g ON (g.id = vg.group AND g.deleted = 0 AND g.viewnotify = 1)
+                    JOIN {group_member} og ON (g.id = og.group AND og.member = ?)
                         WHERE vg.view = ? AND (vg.role IS NULL OR vg.role = m.role)
                 ) AS userlist
                 JOIN {usr} u ON u.id = userlist.userid
                 LEFT JOIN {usr_activity_preference} p ON p.usr = u.id AND p.activity = ?
                 LEFT JOIN {usr_account_preference} ap ON ap.usr = u.id AND ap.field = 'lang'";
-    $values = array($owner, $owner, $owner, 'friends', $view, $view, $view, $type->id);
+    $values = array($owner, $owner, $owner, $view, $view, $owner, $view, $type->id);
     if (!$u = get_records_sql_assoc($sql, $values)) {
         $u = array();
     }
@@ -266,7 +273,7 @@ function activity_locate_typerecord($activitytype, $plugintype=null, $pluginname
         }
     }
     if (empty($at)) {
-        throw new Exception("Invalid activity type $activitytype");
+        throw new SystemException("Invalid activity type $activitytype");
     }
     return $at;
 }
@@ -299,13 +306,16 @@ abstract class ActivityType {
 
     protected $subject;
     protected $message;
+    protected $strings;
     protected $users = array();
     protected $url;
+    protected $urltext;
     protected $id;
     protected $type;
     protected $activityname;
     protected $cron;
     protected $overridemessagecontents;
+    protected $parent;
    
     public function get_id() {
         if (!isset($this->id)) {
@@ -355,11 +365,44 @@ abstract class ActivityType {
        return (object)get_object_vars($this); 
     }
 
+    public function get_string_for_user($user, $string) {
+        if (empty($string) || empty($this->strings->{$string}->key)) {
+            return;
+        }
+        $args = array_merge(
+            array(
+                $user->lang,
+                $this->strings->{$string}->key,
+                empty($this->strings->{$string}->section) ? 'mahara' : $this->strings->{$string}->section,
+            ),
+            empty($this->strings->{$string}->args) ? array() : $this->strings->{$string}->args
+        );
+        return call_user_func_array('get_string_from_language', $args);
+    }
+
+    // Optional string to use for the link text.
+    public function add_urltext(array $stringdef) {
+        $this->strings->urltext = (object) $stringdef;
+    }
+
+    public function get_urltext($user) {
+        if (empty($this->urltext)) {
+            return $this->get_string_for_user($user, 'urltext');
+        }
+        return $this->urltext;
+    }
+
     public function get_message($user) {
+        if (empty($this->message)) {
+            return $this->get_string_for_user($user, 'message');
+        }
         return $this->message;
     }
         
     public function get_subject($user) {
+        if (empty($this->subject)) {
+            return $this->get_string_for_user($user, 'subject');
+        }
         return $this->subject;
     }
 
@@ -381,14 +424,17 @@ abstract class ActivityType {
         if (empty($user->lang) || $user->lang == 'default') {
             $user->lang = get_config('lang');
         }
-        $userdata->message = $this->get_message($user);
-        $userdata->subject = $this->get_subject($user);
         if (empty($user->method)) {
             $user->method = call_static_method(get_class($this), 'default_notification_method');
         }
 
         // always do internal
-        $userdata->internalid = call_static_method('PluginNotificationInternal', 'notify_user', $user, $userdata);
+        foreach (PluginNotificationInternal::$userdata as &$p) {
+            $function = 'get_' . $p;
+            $userdata->$p = $this->$function($user);
+        }
+
+        $userdata->internalid = PluginNotificationInternal::notify_user($user, $userdata);
         if ($this->update_url($userdata->internalid)) {
             $changes->url = $userdata->url = $this->url;
         }
@@ -402,14 +448,33 @@ abstract class ActivityType {
         if ($user->method != 'internal') {
             $method = $user->method;
             safe_require('notification', $method);
+            $notificationclass = generate_class_name('notification', $method);
+            $classvars = get_class_vars($notificationclass);
+            if (!empty($classvars['userdata'])) {
+                foreach ($classvars['userdata'] as &$p) {
+                    $function = 'get_' . $p;
+                    if (!isset($userdata->$p) && method_exists($this, $function)) {
+                        $userdata->$p = $this->$function($user);
+                    }
+                }
+            }
             try {
-                call_static_method(generate_class_name('notification', $method), 'notify_user', $user, $userdata);
+                call_static_method($notificationclass, 'notify_user', $user, $userdata);
             }
             catch (MaharaException $e) {
-                // We don't mind other notification methods failing, as it'll 
+                // We don't mind other notification methods failing, as it'll
                 // go into the activity log as 'unread'
                 $changes->read = 0;
                 update_record('notification_internal_activity', $changes);
+                if (!($e instanceof EmailDisabledException || $e instanceof InvalidEmailException)) {
+                    // Though, admins should probably know about the error
+                    $message = (object) array(
+                        'users' => get_column('usr', 'id', 'admin', 1),
+                        'subject' => get_string('adminnotificationerror', 'activity'),
+                        'message' => $e,
+                    );
+                    activity_occurred('maharamessage', $message);
+                }
             }
         }
 
@@ -419,7 +484,8 @@ abstract class ActivityType {
         safe_require('notification', 'internal');
         $this->type = $this->get_id();
 
-        foreach ($this->get_users() as $user) {
+        while (!empty($this->users)) {
+            $user = array_shift($this->users);
             $this->notify_user($user);
         }
     }
@@ -484,6 +550,7 @@ class ActivityTypeObjectionable extends ActivityTypeAdmin {
     protected $view;
     protected $artefact;
     protected $reporter;
+    protected $ctime;
 
     /**
      * @param array $data Parameters:
@@ -491,31 +558,94 @@ class ActivityTypeObjectionable extends ActivityTypeAdmin {
      *                    - view (int)
      *                    - artefact (int) (optional)
      *                    - reporter (int)
+     *                    - ctime (int) (optional)
      */
     function __construct($data, $cron=false) { 
         parent::__construct($data, $cron);
+
+        require_once('view.php');
+        $this->view = new View($this->view);
+
+        if (!empty($this->artefact)) {
+            require_once(get_config('docroot') . 'artefact/lib.php');
+            $this->artefact = artefact_instance_from_id($this->artefact);
+        }
+
+        if ($owner = $this->view->get('owner')) {
+            // Notify institutional admins of the view owner
+            if ($institutions = get_column('usr_institution', 'institution', 'usr', $owner)) {
+                $this->users = activity_get_users($this->get_id(), null, null, null, $institutions);
+            }
+        }
+
         if (empty($this->artefact)) {
-            $this->url = get_config('wwwroot') . 'view/view.php?id=' . $this->view;
+            $this->url = $this->view->get_url();
         }
         else {
-            $this->url = get_config('wwwroot') . 'view/artefact.php?artefact=' . $this->artefact . '&view=' . $this->view;
+            $this->url = get_config('wwwroot') . 'view/artefact.php?artefact=' . $this->artefact->get('id') . '&view=' . $this->view->get('id');
+        }
+
+        if (empty($this->strings->subject)) {
+            $this->overridemessagecontents = true;
+            $viewtitle = $this->view->get('title');
+            if (empty($this->artefact)) {
+                $this->strings->subject = (object) array(
+                    'key'     => 'objectionablecontentview',
+                    'section' => 'activity',
+                    'args'    => array($viewtitle, display_default_name($this->reporter)),
+                );
+            }
+            else {
+                $title = $this->artefact->get('title');
+                $this->strings->subject = (object) array(
+                    'key'     => 'objectionablecontentviewartefact',
+                    'section' => 'activity',
+                    'args'    => array($viewtitle, $title, display_default_name($this->reporter)),
+                );
+            }
         }
     }
 
-    function get_subject($user) {
-        if (!$viewtitle = get_field('view', 'title', 'id', $this->view)) {
-            throw new ViewNotFoundException(get_string('viewnotfound', 'error', $this->view));
-        }
+    public function get_emailmessage($user) {
+        $reporterurl = get_config('wwwroot') . 'user/view.php?id=' . $this->reporter;
+        $ctime = strftime(get_string_from_language($user->lang, 'strftimedaydatetime'), $this->ctime);
         if (empty($this->artefact)) {
-            return get_string_from_language($user->lang, 'objectionablecontentview', 'activity',
-                                            $viewtitle, display_name($this->reporter, $user));
+            return get_string_from_language(
+                $user->lang, 'objectionablecontentviewtext', 'activity',
+                $this->view->get('title'), display_default_name($this->reporter), $ctime,
+                $this->message, $this->view->get_url(), $reporterurl
+            );
         }
         else {
-            if (!$artefacttitle = get_field('artefact', 'title', 'id', $this->artefact)) {
-                throw new ArtefactNotFoundException(get_string('artefactnotfound', 'error', $this->artefact));
-            }
-            return get_string_from_language($user->lang, 'objectionablecontentartefact', 'activity',
-                                            $artefacttitle, display_name($this->reporter, $user));
+            return get_string_from_language(
+                $user->lang, 'objectionablecontentviewartefacttext', 'activity',
+                $this->view->get('title'), $this->artefact->get('title'), display_default_name($this->reporter), $ctime,
+                $this->message, $this->view->get_url(), $reporterurl
+            );
+        }
+    }
+
+    public function get_htmlmessage($user) {
+        $viewtitle = hsc($this->view->get('title'));
+        $reportername = hsc(display_default_name($this->reporter));
+        $reporterurl = get_config('wwwroot') . 'user/view.php?id=' . $this->reporter;
+        $ctime = strftime(get_string_from_language($user->lang, 'strftimedaydatetime'), $this->ctime);
+        $message = hsc($this->message);
+        if (empty($this->artefact)) {
+            return get_string_from_language(
+                $user->lang, 'objectionablecontentviewhtml', 'activity',
+                $viewtitle, $reportername, $ctime,
+                $message, $this->view->get_url(), $viewtitle,
+                $reporterurl, $reportername
+            );
+        }
+        else {
+            return get_string_from_language(
+                $user->lang, 'objectionablecontentviewartefacthtml', 'activity',
+                $viewtitle, hsc($this->artefact->get('title')), $reportername, $ctime,
+                $message, $this->view->get_url(), $viewtitle,
+                $reporterurl, $reportername
+            );
         }
     }
 
@@ -591,9 +721,11 @@ class ActivityTypeInstitutionmessage extends ActivityType {
             $this->url = get_config('wwwroot') . 'admin/users/institutionusers.php';
             $this->users = activity_get_users($this->get_id(), null, null, null,
                                               array($this->institution->name));
+            $this->add_urltext(array('key' => 'institutionmembers', 'section' => 'admin'));
         } else if ($this->messagetype == 'invite') {
             $this->url = get_config('wwwroot') . 'account/institutions.php';
             $this->users = activity_get_users($this->get_id(), $this->users);
+            $this->add_urltext(array('key' => 'institutionmembership', 'section' => 'mahara'));
         }
     }
 
@@ -632,10 +764,18 @@ class ActivityTypeUsermessage extends ActivityType {
      *                    - userfrom (int)
      *                    - subject (string)
      *                    - message (string)
+     *                    - parent (int)
      */
     public function __construct($data, $cron=false) { 
         parent::__construct($data, $cron);
+        if ($this->userfrom) {
+            $this->fromuser = $this->userfrom;
+        }
         $this->users = activity_get_users($this->get_id(), array($this->userto));
+        $this->add_urltext(array(
+            'key'     => 'Reply',
+            'section' => 'group',
+        ));
     } 
 
     public function get_subject($user) {
@@ -647,7 +787,7 @@ class ActivityTypeUsermessage extends ActivityType {
     }
 
     protected function update_url($internalid) {
-        $this->url = get_config('wwwroot') . 'user/sendmessage.php?id=' . $this->userfrom . '&replyto=' . $internalid;
+        $this->url = get_config('wwwroot') . 'user/sendmessage.php?id=' . $this->userfrom . '&replyto=' . $internalid . '&returnto=inbox';
         return true;
     }
 
@@ -657,65 +797,6 @@ class ActivityTypeUsermessage extends ActivityType {
     
 }
 
-class ActivityTypeFeedback extends ActivityType { 
-
-    protected $view;
-    protected $artefact;
-
-    private $viewrecord;
-    private $artefactinstance;
-
-    /**
-     * @param array $data Parameters:
-     *                    - view (int)
-     *                    - artefact (int) (optional)
-     *                    - message (string)
-     */
-    public function __construct($data, $cron=false) { 
-        parent::__construct($data, $cron);
-
-        if (!empty($this->artefact)) { // feedback on artefact
-            $userid = null;
-            require_once(get_config('docroot') . 'artefact/lib.php');
-            $this->artefactinstance = artefact_instance_from_id($this->artefact);
-            if ($this->artefactinstance->feedback_notify_owner()) {
-                $userid = $this->artefactinstance->get('owner');
-            }
-            if (empty($this->url)) {
-                $this->url = get_config('wwwroot') . 'view/artefact.php?artefact=' 
-                    . $this->artefact . '&view=' . $this->view;
-            }
-        } 
-        else { // feedback on view.
-            if (!$this->viewrecord = get_record('view', 'id', $this->view)) {
-                throw new ViewNotFoundException(get_string('viewnotfound', 'error', $this->view));
-            }
-            $userid = $this->viewrecord->owner;
-            if (empty($this->url)) {
-                $this->url = get_config('wwwroot') . 'view/view.php?id=' . $this->view;
-            }
-        }
-        if ($userid) {
-            $this->users = activity_get_users($this->get_id(), array($userid));
-        } 
-    }
-
-    public function get_subject($user) {
-        if (!empty($this->artefact)) { // feedback on artefact
-            return get_string_from_language($user->lang, 'newfeedbackonartefact', 'activity')
-                . ' ' . $this->artefactinstance->get('title');
-        }
-        else {
-            return get_string_from_language($user->lang, 'newfeedbackonview', 'activity')
-                . ' ' . $this->viewrecord->title;
-        }
-    }
-
-    public function get_required_parameters() {
-        return array('message', 'view');
-    }
-}
-
 class ActivityTypeWatchlist extends ActivityType { 
 
     protected $view;
@@ -756,6 +837,26 @@ class ActivityTypeWatchlist extends ActivityType {
         $this->users = get_records_sql_array($sql, 
                                        array(get_config('wwwroot') . 'view/view.php?id=' 
                                              . $this->view, $this->get_id(), $this->view));
+
+        // Remove the view from the watchlist of users who can no longer see it
+        if ($this->users) {
+            $userstodelete = array();
+            foreach($this->users as $k => &$u) {
+                if (!can_view_view($this->view, $u->id)) {
+                    $userstodelete[] = $u->id;
+                    unset($this->users[$k]);
+                }
+            }
+            if ($userstodelete) {
+                delete_records_select(
+                    'usr_watchlist_view',
+                    'view = ? AND usr IN (' . join(',', $userstodelete) . ')',
+                    array($this->view)
+                );
+            }
+        }
+
+        $this->add_urltext(array('key' => 'View', 'section' => 'view'));
     }
 
     public function get_subject($user) {
@@ -816,7 +917,7 @@ class ActivityTypeViewaccess extends ActivityType {
     protected $owner;
     protected $oldusers; // this can be empty though
 
-    private $viewinfo;
+    private $title, $ownername;
 
     /**
      * @param array $data Parameters:
@@ -826,9 +927,15 @@ class ActivityTypeViewaccess extends ActivityType {
      */
     public function __construct($data, $cron=false) { 
         parent::__construct($data, $cron);
-        if (!$this->viewinfo = get_record_sql('SELECT v.title, u.* FROM {view} v
-                                         LEFT JOIN {usr} u ON v.owner = u.id
-                                         WHERE v.id = ?', array($this->view))) {
+        if (!$viewinfo = get_record_sql('
+            SELECT v.title, v.owner, v.group, v.institution,
+                u.id, u.username, u.preferredname, u.firstname, u.lastname, u.staff, u.admin,
+                g.name AS groupname, i.displayname AS institutionname
+            FROM {view} v
+                LEFT JOIN {usr} u ON v.owner = u.id
+                LEFT JOIN {group} g ON v.group = g.id
+                LEFT JOIN {institution} i ON v.institution = i.name
+            WHERE v.id = ?', array($this->view))) {
             if (!empty($this->cron)) { // probably deleted already
                 return;
             }
@@ -839,6 +946,19 @@ class ActivityTypeViewaccess extends ActivityType {
             activity_get_viewaccess_users($this->view, $this->owner, $this->get_id()),
             $this->oldusers
         );
+        $this->title = $viewinfo->title;
+        if ($this->users) {
+            if ($viewinfo->group) {
+                $this->ownername = $viewinfo->groupname;
+            }
+            else if ($viewinfo->institution) {
+                $this->ownername = $viewinfo->institutionname;
+            }
+            else if ($viewinfo->owner) {
+                $this->ownername = display_name($viewinfo, null, true);
+            }
+        }
+        $this->add_urltext(array('key' => 'View', 'section' => 'view'));
     }
 
     public function get_subject($user) {
@@ -846,11 +966,11 @@ class ActivityTypeViewaccess extends ActivityType {
     }
     
     public function get_message($user) {
-        if ($this->viewinfo->id) {
+        if ($this->ownername) {
             return get_string_from_language($user->lang, 'newviewaccessmessage', 'activity',
-                                            $this->viewinfo->title, display_name($this->viewinfo, $user));
+                                            $this->title, $this->ownername);
         }
-        return get_string_from_language($user->lang, 'newviewaccessmessagenoowner', 'activity', $this->viewinfo->title);
+        return get_string_from_language($user->lang, 'newviewaccessmessagenoowner', 'activity', $this->title);
     }
     
     public function get_required_parameters() {
@@ -929,4 +1049,91 @@ abstract class ActivityTypePlugin extends ActivityType {
     }
 }
 
-?>
+
+function format_notification_whitespace($message, $type=null) {
+    $message = preg_replace('/^(\s|<br( ?\/)?>|&nbsp;|\xc2\xa0)*/', '', $message);
+    $message = format_whitespace($message);
+    // @todo: Sensibly distinguish html notifications, notifications where the full text
+    // appears on another page and this is just an abbreviated preview, and text-only
+    // notifications where the entire text must appear here because there's nowhere else
+    // to see it.
+    $replace = ($type == 'newpost' || $type == 'feedback') ? '<br>' : '<br><br>';
+    return preg_replace('/(<br( ?\/)?>\s*){2,}/', $replace, $message);
+}
+
+/**
+ * Get one page of notifications and return html
+ */
+function activitylist_html($type='all', $limit=10, $offset=0) {
+    global $USER;
+
+    $userid = $USER->get('id');
+
+    $typesql = '';
+    if ($type != 'all') {
+        // Treat as comma-separated list of activity type names
+        $types = split(',', preg_replace('/[^a-z,]+/', '', $type));
+        if ($types) {
+            $typesql = ' at.name IN (' . join(',', array_map('db_quote', $types)) . ')';
+            if (in_array('adminmessages', $types)) {
+                $typesql = '(' . $typesql . ' OR at.admin = 1)';
+            }
+            $typesql = ' AND ' . $typesql;
+        }
+    }
+
+    $from = "
+        FROM {notification_internal_activity} a
+        JOIN {activity_type} at ON a.type = at.id
+        WHERE a.usr = ? $typesql";
+    $values = array($userid);
+
+    $count = count_records_sql('SELECT COUNT(*)' . $from, $values);
+
+    $pagination = build_pagination(array(
+        'id'         => 'activitylist_pagination',
+        'url'        => get_config('wwwroot') . 'account/activity/index.php?type=' . hsc($type),
+        'jsonscript' => 'account/activity/index.json.php',
+        'datatable'  => 'activitylist',
+        'count'      => $count,
+        'limit'      => $limit,
+        'offset'     => $offset,
+    ));
+
+    $result = array(
+        'count'         => $count,
+        'limit'         => $limit,
+        'offset'        => $offset,
+        'type'          => $type,
+        'tablerows'     => '',
+        'pagination'    => $pagination['html'],
+        'pagination_js' => $pagination['javascript'],
+    );
+
+    if ($count < 1) {
+        return $result;
+    }
+
+    $records = get_records_sql_array('
+        SELECT
+            a.*, at.name AS type, at.plugintype, at.pluginname' . $from . '
+        ORDER BY a.ctime DESC',
+        $values,
+        $offset,
+        $limit
+    );
+    if ($records) {
+        foreach ($records as &$r) {
+            $r->date = format_date(strtotime($r->ctime), 'strfdaymonthyearshort');
+            $section = empty($r->plugintype) ? 'activity' : "{$r->plugintype}.{$r->pluginname}";
+            $r->strtype = get_string('type' . $r->type, $section);
+            $r->message = format_notification_whitespace($r->message);
+        }
+    }
+
+    $smarty = smarty_core();
+    $smarty->assign('data', $records);
+    $result['tablerows'] = $smarty->fetch('account/activity/activitylist.tpl');
+
+    return $result;
+}
