@@ -58,8 +58,6 @@ define('LOG_LEVEL_WARN', 8);
 define('DEVMODE_DEBUGJS', 1);
 /** include debug.css */
 define('DEVMODE_DEBUGCSS', 2);
-/** include firebug lite */
-define('DEVMODE_FIREBUGLITE', 4);
 /** include unpacked mochikit */
 define('DEVMODE_UNPACKEDJS', 8);
 // more here.. start at 16 :)
@@ -257,7 +255,9 @@ function log_message ($message, $loglevel, $escape, $backtrace, $file=null, $lin
     }
 
     if (function_exists('get_config')) {
-        $logfilename = get_config('log_file');
+        if (!$logfilename = get_config('log_file')) {
+            $logfilename = get_config('dataroot') . 'error.log';
+        }
         if (($targets & LOG_TARGET_FILE) && $logfilename) {
             global $LOGFILE_FH;
             static $logfile_open_attempted = null;
@@ -336,7 +336,7 @@ function log_build_backtrace($backtrace) {
                         $args .= 'object(' . get_class($arg) . ')';
                         break;
                     case 'resource':
-                        $args .= 'resource(' . strstr($arg, '#') . ')';
+                        $args .= 'resource(' . strstr((string)$arg, '#') . ')';
                         break;
                     case 'boolean':
                         $args .= $arg ? 'true' : 'false';
@@ -573,15 +573,23 @@ class MaharaException extends Exception {
         $outputmessage = trim($this->render_exception());
 
         if (function_exists('smarty') && !$this instanceof ConfigSanityException) {
-            $smarty = smarty(array(), array(), array(), array('sidebars' => false));
-            $smarty->assign('title', $outputtitle);
-            $smarty->assign('message', $outputmessage);
-            $smarty->display('error.tpl');
+            try {
+                $smarty = smarty(array(), array(), array(), array('sidebars' => false));
+                $smarty->assign('title', $outputtitle);
+                $smarty->assign('message', $outputmessage);
+                $smarty->display('error.tpl');
+                die();
+            }
+            catch (Exception $e) {
+                // If an exception is thrown in smarty(), ignore it
+                // and print the message out the ugly way
+                log_warn("Exception thrown by smarty call while handling exception");
+            }
         }
-        else {
-            $outputtitle   = htmlspecialchars($outputtitle, ENT_COMPAT, 'UTF-8');
-            $outputmessage = nl2br(htmlspecialchars($outputmessage, ENT_COMPAT, 'UTF-8'));
-            echo <<<EOF
+
+        $outputtitle   = htmlspecialchars($outputtitle, ENT_COMPAT, 'UTF-8');
+        $outputmessage = nl2br(htmlspecialchars($outputmessage, ENT_COMPAT, 'UTF-8'));
+        echo <<<EOF
 <html>
 <head>
     <title>$outputtitle</title>
@@ -618,13 +626,12 @@ class MaharaException extends Exception {
 </head>
 <body>
 EOF;
-    echo <<<EOF
+        echo <<<EOF
 <h1>$outputtitle</h1>
 <div id="message">$outputmessage</div>
 </body>
 </html>
 EOF;
-        }
         // end of printing stuff to the screen...
         die();
     }
@@ -790,6 +797,16 @@ class CryptException extends SystemException {}
  */
 class EmailException extends SystemException {}
 
+/**
+ * Exception - Invalid address
+ */
+class InvalidEmailException extends EmailException {}
+
+/**
+ * Exception - Email is disabled for this user
+ */
+class EmailDisabledException extends EmailException {}
+
 /** 
  * Exception - artefact not found 
  */
@@ -847,6 +864,11 @@ class QuotaExceededException extends UserException {}
  */
 class UploadException extends UserException {}
 
+/**
+ * Exception - collection not found
+ */
+class CollectionNotFoundException extends NotFoundException {}
+
 /**
  * Exception - Access denied. Throw this if a user is trying to view something they can't
  */
@@ -936,12 +958,16 @@ class ImportException extends SystemException {
     }
 }
 
+/**
+* something has happened during export.
+*/
 class ExportException extends SystemException {
 
     public function __construct($exporter, $message=null, $code=0) {
         parent::__construct($message, $code);
     }
+
+    public function render_exception() {
+        return $this->getMessage();
+    }
 }
-
-
-?>
