@@ -177,6 +177,7 @@ function serve_file($path, $filename, $mimetype, $options=array()) {
     header('Content-Length: ' . $filesize);
     while (@ob_end_flush()); //flush the buffers - save memory and disable sid rewrite
     readfile_chunked($path);
+    perf_to_log();
     exit;
 }
 
@@ -316,12 +317,24 @@ function file_mime_type($file) {
     static $mimetypes = null;
 
     if (class_exists('finfo')) {
+        // upstream bug in php #54714
+        // http://bugs.php.net/bug.php?id=54714
+        //
+        // according to manual (http://www.php.net/manual/en/function.finfo-open.php)
+        // default option is /usr/share/misc/magic, then /usr/share/misc/magic.mgc
+        //
+        // if /usr/share/misc/magic is a directory then finfo still succeeds and 
+        // doesn't fall back onto the .mcg magic_file
+        // force /usr/share/misc/magic.mgc instead in this case
+
+        $magicfile = !is_file('/usr/share/misc/magic') ? '/usr/share/misc/magic.mgc' : null;
+
         if (defined('FILEINFO_MIME_TYPE')) {
-            if ($finfo = @new finfo(FILEINFO_MIME_TYPE)) {
+            if ($finfo = @new finfo(FILEINFO_MIME_TYPE, $magicfile)) {
                 $type = @$finfo->file($file);
             }
         }
-        else if ($finfo = @new finfo(FILEINFO_MIME)) {
+        else if ($finfo = @new finfo(FILEINFO_MIME, $magicfile)) {
             if ($typecharset = @$finfo->file($file)) {
                 if ($bits = explode(';', $typecharset)) {
                     $type = $bits[0];
@@ -525,17 +538,17 @@ function get_dataroot_image_path($path, $id, $size=null) {
                 case 'image/x-bmp':
                 case 'image/ms-bmp':
                 case 'image/x-ms-bmp':
-                    if (!extension_loaded('imagick')) {
+                    if (!extension_loaded('imagick') || !class_exists('Imagick')) {
                         log_info('Bitmap image detected for resizing, but imagick extension is not available');
                         return false;
                     }
 
-                    $ih = imagick_readimage($originalimage);
-                    if (!$newdimensions = image_get_new_dimensions(imagick_getwidth($ih), imagick_getheight($ih), $size)) {
+                    $ih = new Imagick($originalimage);
+                    if (!$newdimensions = image_get_new_dimensions($ih->getImageWidth(), $ih->getImageHeight(), $size)) {
                         return false;
                     }
-                    imagick_resize($ih, $newdimensions['w'], $newdimensions['h'], IMAGICK_FILTER_LANCZOS, 1);
-                    if (imagick_writeimage($ih, $resizedimagefile)) {
+                    $ih->resizeImage($newdimensions['w'], $newdimensions['h'], imagick::FILTER_LANCZOS, 1);
+                    if ($ih->writeImage($resizedimagefile)) {
                         return $resizedimagefile;
                     }
                     return false;
@@ -720,7 +733,7 @@ function rmdirr($dirname)
         }
  
         // Recurse
-        rmdirr($dirname . DIRECTORY_SEPARATOR . $entry);
+        rmdirr($dirname . '/' . $entry);
     }
  
     // Clean up
@@ -771,5 +784,3 @@ function copyr($source, $dest)
     $dir->close();
     return true;
 }
-
-?>
