@@ -33,6 +33,7 @@
  * @return string           The HTML for the element
  */
 function pieform_element_viewacl(Pieform $form, $element) {
+    global $USER;
     $smarty = smarty_core();
     $smarty->left_delimiter  = '{{';
     $smarty->right_delimiter = '}}';
@@ -40,15 +41,18 @@ function pieform_element_viewacl(Pieform $form, $element) {
     $value = $form->get_value($element);
 
     // Look for the presets and split them into two groups
+    $public = get_config('allowpublicviews') == '1';
     $presets = array();
-    if (get_config('allowpublicviews') == '1') {
-        $presets = array('public', 'loggedin', 'friends', 'token');
+    $loggedinindex = 0;
+    if ($public) {
+        $presets[] = 'public';
         $loggedinindex = 1;
     }
-    else {
-        $presets = array('loggedin', 'friends');
-        $loggedinindex = 0;
+    $presets[] = 'loggedin';
+    if ($form->get_property('userview')) {
+        $presets[] = 'friends';
     }
+
     if ($value) {
         foreach ($value as $key => &$item) {
             if (is_array($item)) {
@@ -59,6 +63,13 @@ function pieform_element_viewacl(Pieform $form, $element) {
                 else {
                     $item['name'] = pieform_render_viewacl_getvaluebytype($item['type'], $item['id']);
                 }
+                if (mb_strlen($item['name']) > 30) {
+                    $item['shortname'] = str_shorten_text($item['name'], 30, true);
+                }
+                // only show access that is still current. Expired access will be deleted if the form is saved
+                if($item['stopdate'] && (time() > strtotime($item['stopdate']))) {
+                    unset($value[$key]);
+                }
             }
             else {
                 unset($value[$key]);
@@ -77,12 +88,38 @@ function pieform_element_viewacl(Pieform $form, $element) {
             'preset' => true
         );
     }
+
+    $allgroups = array(
+        'type'   => 'allgroups',
+        'id'     => 'allgroups',
+        'start'  => null,
+        'end'    => null,
+        'name'   => get_string('allmygroups', 'group'),
+        'preset' => true
+    );
+    $mygroups = array();
+    foreach (group_get_user_groups($USER->get('id')) as $g) {
+        $mygroups[] = array(
+            'type' => 'group',
+            'id'   => $g->id,
+            'start' => null,
+            'end'   => null,
+            'name' => $g->name,
+            'preset' => false
+        );
+        if (mb_strlen($g->name) > 30) {
+            $mygroups[key($mygroups)]['shortname'] = str_shorten_text($g->name, 30, true);
+        }
+    }
     
     $smarty->assign('potentialpresets', json_encode($potentialpresets));
     $smarty->assign('loggedinindex', $loggedinindex);
     $smarty->assign('accesslist', json_encode($value));
     $smarty->assign('viewid', $form->get_property('viewid'));
     $smarty->assign('formname', $form->get_property('name'));
+    $smarty->assign('allowcomments', $element['allowcomments']);
+    $smarty->assign('allgroups', json_encode($allgroups));
+    $smarty->assign('mygroups', json_encode($mygroups));
     return $smarty->fetch('form/viewacl.tpl');
 }
 
@@ -120,7 +157,17 @@ function pieform_element_viewacl_get_value(Pieform $form, $element) {
             }
         }
     }
-    return $values;
-}
 
-?>
+    /*
+        If the above foreach() loop removes any items, json_encode() converts
+        it into an object, which can't be iterated over - array_merge() with
+        only one argument effects a renumber of the array, which json_encode()
+        then handles with expected results.
+    */
+    if (is_array($values)) {
+        return array_values($values);
+    }
+    else {
+        return $values;
+    }
+}
