@@ -62,10 +62,10 @@ function pieform_renderer_maharatable(Pieform $form, $element) {
     $result = '';
     if (isset($element['labelhtml']) && $element['labelhtml'] !== '') {
         $result .= "\t<tr";
-        $result .= ' id="' . $formname . '_' . $element['name'] . '_header"';
+        $result .= ' id="' . $formname . '_' . Pieform::hsc($element['name']) . '_header"';
         // Set the class of the enclosing <tr> to match that of the element
         if ($element['class']) {
-            $result .= ' class="' . $element['class'] . '"';
+            $result .= ' class="' . Pieform::hsc($element['class']) . '"';
         }
         $result .= ">\n\t\t";
 
@@ -73,7 +73,11 @@ function pieform_renderer_maharatable(Pieform $form, $element) {
         $result .= $element['labelhtml'];
         $result .= "</th>\n\t</tr>\n";
     }
-    $result .= "\t<tr id=\"{$formname}_{$element['name']}_container\">\n\t\t<td>";
+    $result .= "\t<tr id=\"{$formname}_{$element['name']}_container\"";
+    if ($element['class']) {
+        $result .= ' class="' . Pieform::hsc($element['class']) . '"';
+    }
+    $result .= ">\n\t\t<td>";
 
     // Wrap WYSIWYG elements in a table with two cells side by side, one for the element and one for the help icon
     if (!empty($element['help']) && $element['type'] == 'wysiwyg') {
@@ -148,5 +152,3 @@ function {$id}_remove_all_errors() {
 EOF;
     return $result;
 }
-
-?>
