@@ -76,7 +76,7 @@ function search_user($query_string, $limit, $offset = 0, $data = array()) {
     $results = call_static_method(generate_class_name('search', $plugin), 'search_user', $query_string, $limit, $offset, $data);
 
     if ($results['data']) {
-        $userlist = '('.join(',', array_map(create_function('$u','return $u[\'id\'];'), $results['data'])).')';
+        $userlist = '('.join(',', array_map(create_function('$u','return (int)$u[\'id\'];'), $results['data'])).')';
 
         $public_fields = get_records_sql_array('
             SELECT 
@@ -283,15 +283,14 @@ function build_admin_user_search_results($search, $offset, $limit, $sortby, $sor
             $params[] = $k . '=' . $v;
         }
     }
-    $searchurl = get_config('wwwroot') . 'admin/users/search.php?' . join('&amp;', $params)
-        . '&amp;limit=' . $limit;
+    $searchurl = get_config('wwwroot') . 'admin/users/search.php?' . join('&', $params) . '&limit=' . $limit;
 
     $usernametemplate = '<a href="' . get_config('wwwroot')
-        . '{if $USER->is_admin_for_user($r.id)}admin/users/edit.php?id={$r.id}{else}user/view.php?id={$r.id}{/if}">{$r.username|escape}</a>';
+        . '{if $USER->is_admin_for_user($r.id)}admin/users/edit.php?id={$r.id}{else}user/view.php?id={$r.id}{/if}">{$r.username}</a>';
 
     $cols = array(
         'icon'        => array('name'     => '',
-                               'template' => '<img src="' . get_config('wwwroot') . 'thumb.php?type=profileicon&maxwidth=40&maxheight=40&id={$r.id}" alt="' . get_string('profileimage') . '" />',
+                               'template' => '<img src="{profile_icon_url user=$r maxwidth=40 maxheight=40}" alt="' . get_string('profileimage') . '" />',
                                'class'    => 'center'),
         'firstname'   => array('name'     => get_string('firstname')),
         'lastname'    => array('name'     => get_string('lastname')),
@@ -303,7 +302,7 @@ function build_admin_user_search_results($search, $offset, $limit, $sortby, $sor
     $institutions = get_records_assoc('institution', '', '', '', 'name,displayname');
     if (count($institutions) > 1) {
         $cols['institution'] = array('name'     => get_string('institution'),
-                                     'template' => '{if empty($r.institutions)}{$institutions.mahara->displayname|escape}{else}{foreach from=$r.institutions item=i}<div>{$institutions[$i]->displayname|escape}</div>{/foreach}{/if}{if !empty($r.requested)}{foreach from=$r.requested item=i}<div class="pending">{str tag=requestto section=admin} {$institutions[$i]->displayname|escape}{if $USER->is_institutional_admin("$i")} (<a href="{$WWWROOT}admin/users/addtoinstitution.php?id={$r.id}&institution={$i}">{str tag=confirm section=admin}</a>){/if}</div>{/foreach}{/if}{if !empty($r.invitedby)}{foreach from=$r.invitedby item=i}<div class="pending">{str tag=invitedby section=admin} {$institutions[$i]->displayname|escape}</div>{/foreach}{/if}');
+                                     'template' => '{if !$r.institutions}{$institutions.mahara->displayname}{else}{foreach from=$r.institutions item=i}<div>{$institutions[$i]->displayname}</div>{/foreach}{/if}{if !$r.requested}{foreach from=$r.requested item=i}<div class="pending">{str tag=requestto section=admin} {$institutions[$i]->displayname}{if $USER->is_institutional_admin("$i")} (<a href="{$WWWROOT}admin/users/addtoinstitution.php?id={$r.id}&institution={$i}">{str tag=confirm section=admin}</a>){/if}</div>{/foreach}{/if}{if !$r.invitedby}{foreach from=$r.invitedby item=i}<div class="pending">{str tag=invitedby section=admin} {$institutions[$i]->displayname}</div>{/foreach}{/if}');
     }
 
     $smarty = smarty_core();
@@ -333,14 +332,15 @@ function admin_user_search($queries, $constraints, $offset, $limit, $sortfield,
  *
  * The search term is applied against first and last names of the users in the group
  *
- * @param int    $group  The group to build results for
- * @param string $query  A search string to filter by
- * @param int    $offset What result to start showing paginated results from
- * @param int    $limit  How many results to show
- * @param array  $extra  User membershiptype
+ * @param int    $group             The group to build results for
+ * @param string $query             A search string to filter by
+ * @param int    $offset            What result to start showing paginated results from
+ * @param int    $limit             How many results to show
+ * @param array  $membershiptype    User membershiptype
+ * @param bool   $random            Set to true if you want the result to be ordered by random, default false
  *
  */
-function get_group_user_search_results($group, $query, $offset, $limit, $membershiptype) {
+function get_group_user_search_results($group, $query, $offset, $limit, $membershiptype, $order=null) {
     $queries = array();
     $constraints = array();
     if (!empty($query)) {
@@ -363,29 +363,31 @@ function get_group_user_search_results($group, $query, $offset, $limit, $members
         }
     }
 
-    $results = group_user_search($group, $queries, $constraints, $offset, $limit, $membershiptype);
+    $results = group_user_search($group, $queries, $constraints, $offset, $limit, $membershiptype, $order);
     if ($results['count']) {
         $userids = array_map(create_function('$a', 'return $a["id"];'), $results['data']);
-        $introductions = get_records_sql_assoc("SELECT owner, title
+        $introductions = get_records_sql_assoc("SELECT \"owner\", title
             FROM {artefact}
             WHERE artefacttype = 'introduction'
-            AND owner IN (" . implode(',', db_array_to_ph($userids)) . ')',
+            AND \"owner\" IN (" . implode(',', db_array_to_ph($userids)) . ')',
             $userids);
         foreach ($results['data'] as &$result) {
             $result['name'] = display_name($result);
             $result['introduction'] = isset($introductions[$result['id']]) ? $introductions[$result['id']]->title : '';
-            $result['jointime'] = strftime(get_string('strftimedate'), $result['jointime']);
+            if (isset($result['jointime'])) {
+                $result['jointime'] = strftime(get_string('strftimedate'), $result['jointime']);
+            }
         }
     }
     return $results;
 }
 
 
-function group_user_search($group, $queries, $constraints, $offset, $limit, $membershiptype) {
+function group_user_search($group, $queries, $constraints, $offset, $limit, $membershiptype, $order=null) {
     $plugin = get_config('searchplugin');
     safe_require('search', $plugin);
     return call_static_method(generate_class_name('search', $plugin), 'group_search_user', 
-                              $group, $queries, $constraints, $offset, $limit, $membershiptype);
+                              $group, $queries, $constraints, $offset, $limit, $membershiptype, $order);
 }
 
 /**
@@ -421,11 +423,11 @@ function group_user_search($group, $queries, $constraints, $offset, $limit, $mem
  *               ),
  *           );
  */
-function search_group($query_string, $limit, $offset = 0, $type = 'member') {
+function search_group($query_string, $limit, $offset = 0, $type = 'member', $groupcategory = '') {
     $plugin = get_config('searchplugin');
     safe_require('search', $plugin);
 
-    return call_static_method(generate_class_name('search', $plugin), 'search_group', $query_string, $limit, $offset, $type);
+    return call_static_method(generate_class_name('search', $plugin), 'search_group', $query_string, $limit, $offset, $type, $groupcategory);
 }
 
 function search_selfsearch($query_string, $limit, $offset, $type = 'all') {
@@ -468,7 +470,7 @@ function get_portfolio_items_by_tag($tag, $owner, $limit, $offset, $sort='name',
 function get_search_plugins() {
     $searchpluginoptions = array();
 
-    if ($searchplugins = get_records_array('search_installed')) {
+    if ($searchplugins = plugins_installed('search')) {
         foreach ($searchplugins as $plugin) {
             $searchpluginoptions[$plugin->name] = $plugin->name;
 
@@ -485,4 +487,76 @@ function get_search_plugins() {
 
     return $searchpluginoptions;
 }
-?>
+
+/**
+ * Given a filter string and limits, return an array of matching friends.
+ *
+ * @param string  The filter string
+ * @param integer How many results to return
+ * @param integer What result to start at (0 == first result)
+ * @return array  A data structure containing results looking like ...
+ *         $results = array(
+ *               count   => integer, // total number of results
+ *               limit   => integer, // how many results are returned
+ *               offset  => integer, // starting from which result
+ *               results => array(   // the result records
+ *                   array(
+ *                       id            => integer, //user id
+ *                   ),
+ *                   array(...),
+ *               ),
+ *           );
+ */
+function search_friend($filter, $limit, $offset) {
+    global $USER;
+    $userid = $USER->get('id');
+
+    if (!in_array($filter, array('all','current','pending'))) {
+        throw new SystemException('Invalid search filter');
+    }
+
+    $sql = array();
+    $count = 0;
+
+    if (in_array($filter, array('all', 'current'))) {
+        $count += count_records_sql('SELECT COUNT(usr1) FROM {usr_friend}
+            JOIN {usr} u1 ON (u1.id = usr1 AND u1.deleted = 0)
+            JOIN {usr} u2 ON (u2.id = usr2 AND u2.deleted = 0)
+            WHERE usr1 = ? OR usr2 = ?',
+            array($userid, $userid)
+        );
+
+        array_push($sql, 'SELECT usr2 AS id, 2 AS status FROM {usr_friend} WHERE usr1 = ?
+        ');
+        array_push($sql, 'SELECT usr1 AS id, 2 AS status FROM {usr_friend} WHERE usr2 = ?
+        ');
+    }
+
+    if (in_array($filter, array('all', 'pending'))) {
+        $count += count_records_sql('SELECT COUNT("owner") FROM {usr_friend_request}
+            JOIN {usr} u ON (u.id = requester AND u.deleted = 0)
+            WHERE "owner" = ?',
+            array($userid)
+        );
+
+        array_push($sql, 'SELECT requester AS id, 1 AS status FROM {usr_friend_request} WHERE "owner" = ?
+        ');
+    }
+
+    $data = get_column_sql('SELECT f.id FROM (' . join('UNION ', $sql) . ') f
+        JOIN {usr} u ON (f.id = u.id AND u.deleted = 0)
+        ORDER BY status, firstname, lastname, u.id
+        LIMIT ?
+        OFFSET ?', array_merge(array_pad($values=array(), count($sql), $userid), array($limit, $offset)));
+
+    foreach ($data as &$result) {
+        $result = array('id' => $result);
+    }
+
+    return array(
+    'count'   => $count,
+    'limit'   => $limit,
+    'offset'  => $offset,
+    'data'    => $data,
+    );
+}
