@@ -37,6 +37,10 @@ require_once('ddl.php');
 /**
  * This function checks core and plugins for which need to be upgraded/installed
  *
+ * Note: This function is sometimes executed during upgrades from
+ * ancient databases.  Avoid rash assumptions about what's installed
+ * or these upgrades may fail.
+ *
  * @param string $name The name of the plugin to check. If no name is specified,
  *                     all plugins are checked.
  * @return array of objects
@@ -149,7 +153,7 @@ function check_upgrades($name=null) {
         foreach ($pluginstocheck as $plugin) {
             $dirhandle = opendir(get_config('docroot') . $plugin);
             while (false !== ($dir = readdir($dirhandle))) {
-                if (strpos($dir, '.') === 0) {
+                if (strpos($dir, '.') === 0 or 'CVS' == $dir) {
                     continue;
                 }
                 if (!is_dir(get_config('docroot') . $plugin . '/' . $dir)) {
@@ -170,7 +174,7 @@ function check_upgrades($name=null) {
                     }
                     $btdirhandle = opendir($btlocation);
                     while (false !== ($btdir = readdir($btdirhandle))) {
-                        if (strpos($btdir, '.') === 0) {
+                        if (strpos($btdir, '.') === 0 or 'CVS' == $btdir) {
                             continue;
                         }
                         if (!is_dir(get_config('docroot') . $plugin . '/' . $dir . '/blocktype/' . $btdir)) {
@@ -331,6 +335,10 @@ function upgrade_local($upgrade) {
 /**
  * Upgrades the plugin to a new version
  *
+ * Note: This function is sometimes executed during upgrades from
+ * ancient databases.  Avoid rash assumptions about what's installed
+ * or these upgrades may fail.
+ *
  * @param object $upgrade   Information about the plugin to upgrade
  * @return bool             Whether the upgrade succeeded or not
  * @throws SQLException     If the upgrade failed due to a database error
@@ -460,9 +468,11 @@ function upgrade_plugin($upgrade) {
             }
             $activity->plugintype = $plugintype;
             $activity->pluginname = $pluginname;
-            $where = $activity;
-            unset($where->admin);
-            unset($where->delay);
+            $where = (object) array(
+                'name'       => $activity->name,
+                'plugintype' => $plugintype,
+                'pluginname' => $pluginname,
+            );
             // Work around the fact that insert_record cached the columns that
             // _were_ in the activity_type table before it was upgraded
             global $INSERTRECORD_NOCACHE;
@@ -560,6 +570,15 @@ function core_postinst() {
 
     set_config('lang', 'en.utf8');
     set_config('installation_key', get_random_key());
+    set_config('installation_time', $now);
+    set_config('stats_installation_time', $now);
+
+    // Pre-define SMTP settings
+    set_config('smtphosts', '');
+    set_config('smtpport', '');
+    set_config('smtpuser', '');
+    set_config('smtppass', '');
+    set_config('smtpsecure', '');
 
     // PostgreSQL supports indexes over functions of columns, MySQL does not. 
     // We make use if this if we can
@@ -583,7 +602,18 @@ function core_postinst() {
         (owner IS NULL     AND "group" IS NOT NULL AND institution IS NULL) OR
         (owner IS NULL     AND "group" IS NULL     AND institution IS NOT NULL)
     )');
+    execute_sql('ALTER TABLE {artefact} ADD CHECK (
+        (author IS NOT NULL AND authorname IS NULL    ) OR
+        (author IS NULL     AND authorname IS NOT NULL)
+    )');
+    execute_sql('ALTER TABLE {view_access} ADD CHECK (
+        (accesstype IS NOT NULL AND "group" IS NULL     AND usr IS NULL     AND token IS NULL) OR
+        (accesstype IS NULL     AND "group" IS NOT NULL AND usr IS NULL     AND token IS NULL) OR
+        (accesstype IS NULL     AND "group" IS NULL     AND usr IS NOT NULL AND token IS NULL) OR
+        (accesstype IS NULL     AND "group" IS NULL     AND usr IS NULL     AND token IS NOT NULL)
+    )');
 
+    set_antispam_defaults();
     reload_html_filters();
     return $status;
 }
@@ -596,6 +626,7 @@ function core_install_lastcoredata_defaults() {
     $institution->displayname = 'No Institution';
     $institution->authplugin  = 'internal';
     $institution->theme  = 'default';
+    $institution->priority = 0;
     insert_record('institution', $institution);
 
     $auth_instance = new StdClass;
@@ -626,12 +657,16 @@ function core_install_lastcoredata_defaults() {
         insert_record('usr', $user);
     }
 
+    require_once('group.php');
     install_system_profile_view();
+    install_system_dashboard_view();
+    install_system_grouphomepage_view();
 
     // Insert the admin user
     $user = new StdClass;
     $user->username = 'admin';
-    $user->password = 'mahara';
+    $user->salt = auth_get_random_salt();
+    $user->password = sha1($user->salt . 'mahara');
     $user->authinstance = $auth_instance->id;
     $user->passwordchange = 1;
     $user->admin = 1;
@@ -665,11 +700,17 @@ function core_install_firstcoredata_defaults() {
     set_config('createpublicgroups', 'all');
     set_config('allowpublicviews', 1);
     set_config('allowpublicprofiles', 1);
-    set_config('captchaoncontactform', 1);
-    set_config('captchaonregisterform', 1);
     set_config('showselfsearchsideblock', 0);
     set_config('showtagssideblock', 1);
     set_config('tagssideblockmaxtags', 20);
+    set_config('usersallowedmultipleinstitutions', 1);
+    set_config('viewmicroheaders', 0);
+    set_config('userscanchooseviewthemes', 0);
+    set_config('anonymouscomments', 1);
+    set_config('homepageinfo', 1);
+    set_config('showonlineuserssideblock', 1);
+    set_config('footerlinks', serialize(array('privacystatement', 'about', 'contactus')));
+    set_config('searchusernames', 1);
 
     // install the applications
     $app = new StdClass;
@@ -737,7 +778,6 @@ function core_install_firstcoredata_defaults() {
     $activitytypes = array(
         array('maharamessage', 0, 0),
         array('usermessage', 0, 0),
-        array('feedback', 0, 0),
         array('watchlist', 0, 1),
         array('viewaccess', 0, 1),
         array('contactus', 1, 1),
@@ -745,7 +785,7 @@ function core_install_firstcoredata_defaults() {
         array('virusrepeat', 1, 1),
         array('virusrelease', 1, 1),
         array('institutionmessage', 0, 0),
-        array('groupmessage', 0, 0),
+        array('groupmessage', 0, 1),
     );
 
     foreach ($activitytypes as $at) {
@@ -758,18 +798,22 @@ function core_install_firstcoredata_defaults() {
 
     // install the cronjobs...
     $cronjobs = array(
-        'rebuild_artefact_parent_cache_dirty'    => array('*', '*', '*', '*', '*'),
-        'rebuild_artefact_parent_cache_complete' => array('0', '4', '*', '*', '*'),
-        'auth_clean_partial_registrations'       => array('5', '0', '*', '*', '*'),
-        'auth_handle_account_expiries'           => array('5', '10', '*', '*', '*'),
-        'auth_handle_institution_expiries'       => array('5', '9', '*', '*', '*'),
-        'activity_process_queue'                 => array('*/5', '*', '*', '*', '*'),
-        'auth_remove_old_session_files'          => array('30', '20', '*', '*', '*'),
-        'recalculate_quota'                      => array('15', '2', '*', '*', '*'),
-        'import_process_queue'                   => array('*/5', '*', '*', '*', '*'),
-        'cron_send_registration_data'            => array(rand(0, 59), rand(0, 23), '*', '*', rand(0, 6)),
-        'export_cleanup_old_exports'             => array('0', '3,15', '*', '*', '*'),
-        'import_cleanup_old_imports'             => array('0', '4,16', '*', '*', '*'),
+        'rebuild_artefact_parent_cache_dirty'       => array('*', '*', '*', '*', '*'),
+        'rebuild_artefact_parent_cache_complete'    => array('0', '4', '*', '*', '*'),
+        'auth_clean_partial_registrations'          => array('5', '0', '*', '*', '*'),
+        'auth_handle_account_expiries'              => array('5', '10', '*', '*', '*'),
+        'auth_handle_institution_expiries'          => array('5', '9', '*', '*', '*'),
+        'activity_process_queue'                    => array('*/5', '*', '*', '*', '*'),
+        'auth_remove_old_session_files'             => array('30', '20', '*', '*', '*'),
+        'recalculate_quota'                         => array('15', '2', '*', '*', '*'),
+        'import_process_queue'                      => array('*/5', '*', '*', '*', '*'),
+        'cron_send_registration_data'               => array(rand(0, 59), rand(0, 23), '*', '*', rand(0, 6)),
+        'export_cleanup_old_exports'                => array('0', '3,15', '*', '*', '*'),
+        'import_cleanup_old_imports'                => array('0', '4,16', '*', '*', '*'),
+        'cron_site_data_weekly'                     => array('55', '23', '*', '*', '6'),
+        'cron_site_data_daily'                      => array('51', '23', '*', '*', '*'),
+        'cron_check_for_updates'                    => array(rand(0, 59), rand(0, 23), '*', '*', '*'),
+        'cron_clean_internal_activity_notifications'=> array(45, 22, '*', '*', '*'),
     );
     foreach ($cronjobs as $callfunction => $times) {
         $cron = new StdClass;
@@ -785,7 +829,7 @@ function core_install_firstcoredata_defaults() {
     // install the view column widths
     install_view_column_widths();
 
-    $viewtypes = array('portfolio', 'profile');
+    $viewtypes = array('dashboard', 'portfolio', 'profile', 'grouphomepage');
     foreach ($viewtypes as $vt) {
         insert_record('view_type', (object)array(
             'type' => $vt,
@@ -911,20 +955,23 @@ function sort_upgrades($k1, $k2) {
 /** blocktype categories the system exports (including artefact categories)
 */
 function get_blocktype_categories() {
-    return array('general', 'internal', 'blog', 'resume', 'fileimagevideo', 'feeds');
+    return array('general', 'internal', 'blog', 'resume', 'fileimagevideo', 'external');
 }
 
 function install_blocktype_categories_for_plugin($blocktype) {
     safe_require('blocktype', $blocktype);
     $blocktype = blocktype_namespaced_to_single($blocktype);
+    $catsinstalled = get_column('blocktype_category', 'name');
     db_begin();
     delete_records('blocktype_installed_category', 'blocktype', $blocktype);
     if ($cats = call_static_method(generate_class_name('blocktype', $blocktype), 'get_categories')) {
         foreach ($cats as $cat) {
-            insert_record('blocktype_installed_category', (object)array(
-                'blocktype' => $blocktype,
-                'category' => $cat
-            ));
+            if (in_array($cat, $catsinstalled)) {
+                insert_record('blocktype_installed_category', (object)array(
+                    'blocktype' => $blocktype,
+                    'category' => $cat
+                ));
+            }
         }
     }
     db_commit();
@@ -933,14 +980,17 @@ function install_blocktype_categories_for_plugin($blocktype) {
 function install_blocktype_viewtypes_for_plugin($blocktype) {
     safe_require('blocktype', $blocktype);
     $blocktype = blocktype_namespaced_to_single($blocktype);
+    $vtinstalled = get_column('view_type', 'type');
     db_begin();
     delete_records('blocktype_installed_viewtype', 'blocktype', $blocktype);
     if ($viewtypes = call_static_method(generate_class_name('blocktype', $blocktype), 'get_viewtypes')) {
         foreach($viewtypes as $vt) {
-            insert_record('blocktype_installed_viewtype', (object)array(
-                'blocktype' => $blocktype,
-                'viewtype'  => $vt,
-            ));
+            if (in_array($vt, $vtinstalled)) {
+                insert_record('blocktype_installed_viewtype', (object)array(
+                    'blocktype' => $blocktype,
+                    'viewtype'  => $vt,
+                ));
+            }
         }
     }
     db_commit();
@@ -994,7 +1044,6 @@ function install_view_column_widths() {
  */
 function reload_html_filters() {
     require_once('xmlize.php');
-    log_info('Reading HTML filters');
 
     $newlist = xmlize(file_get_contents(get_config('libroot') . 'htmlpurifiercustom/filters.xml'));
     $filters = $newlist['filters']['#']['filter'];
@@ -1003,10 +1052,107 @@ function reload_html_filters() {
             'site' => $f['#']['site'][0]['#'],
             'file' => $f['#']['filename'][0]['#']
         );
-        log_info('- ' . $f->file);
     }
-    $filters[] = (object) array('site' => 'http://www.youtube.com', 'file' => 'YouTube');
-    log_info('- YouTube');
     set_config('filters', serialize($filters));
+    log_info('Enabled ' . count($filters) . ' HTML filters.');
+}
+
+/**
+ * Use meaningful defaults for the antispam settings.
+ */
+function set_antispam_defaults() {
+    set_config('formsecret', get_random_key());
+    require_once(get_config('docroot') . 'lib/antispam.php');
+    if(checkdnsrr('test.uribl.com.black.uribl.com', 'A')) {
+        set_config('antispam', 'advanced');
+    }
+    else {
+        set_config('antispam', 'simple');
+    }
+    set_config('spamhaus', 0);
+    set_config('surbl', 0);
+}
+
+function activate_plugin_form($plugintype, $plugin) {
+    return pieform(array(
+        'name'            => 'activate_' . $plugintype . '_' . $plugin->name,
+        'renderer'        => 'oneline',
+        'elementclasses'  => false,
+        'successcallback' => 'activate_plugin_submit',
+        'class'           => 'oneline inline',
+        'jsform'          => false,
+        'action'          => get_config('wwwroot') . 'admin/extensions/pluginconfig.php',
+        'elements' => array(
+            'plugintype' => array('type' => 'hidden', 'value' => $plugintype),
+            'pluginname' => array('type' => 'hidden', 'value' => $plugin->name),
+            'disable'    => array('type' => 'hidden', 'value' => $plugin->active),
+            'enable'     => array('type' => 'hidden', 'value' => 1-$plugin->active),
+            'submit'     => array(
+                'type'  => 'submit',
+                'class' => 'linkbtn',
+                'value' => $plugin->active ? get_string('hide') : get_string('show')
+            ),
+        ),
+    ));
+}
+
+function activate_plugin_submit(Pieform $form, $values) {
+    global $SESSION;
+    if ($values['plugintype'] == 'blocktype') {
+        if (strpos($values['pluginname'], '/') !== false) {
+            list($artefact, $values['pluginname']) = split('/', $values['pluginname']);
+            // Don't enable blocktypes unless the artefact plugin that provides them is also enabled
+            if ($values['enable'] && !get_field('artefact_installed', 'active', 'name', $artefact)) {
+                $SESSION->add_error_msg(get_string('pluginnotenabled', 'mahara', $artefact));
+                redirect('/admin/extensions/plugins.php');
+            }
+        }
+    }
+    else if ($values['plugintype'] == 'artefact' && $values['disable']) {
+        // Disable all the artefact's blocktypes too
+        set_field('blocktype_installed', 'active', 0, 'artefactplugin', $values['pluginname']);
+    }
+    set_field($values['plugintype'] . '_installed', 'active', $values['enable'], 'name', $values['pluginname']);
+    $SESSION->add_ok_msg(get_string('plugin' . (($values['enable']) ? 'enabled' : 'disabled')));
+    redirect('/admin/extensions/plugins.php');
+}
+
+// site warnings for the admin to consider
+function site_warnings() {
+
+    $warnings = array();
+
+    // Warn about nasty php settings that Mahara can still sort of deal with.
+    if (ini_get_bool('register_globals')) {
+        $warnings[] = get_string('registerglobals', 'error');
+    }
+    if (!defined('CRON') && ini_get_bool('magic_quotes_gpc')) {
+        $warnings[] = get_string('magicquotesgpc', 'error');
+    }
+    if (ini_get_bool('magic_quotes_runtime')) {
+        $warnings[] = get_string('magicquotesruntime', 'error');
+    }
+    if (ini_get_bool('magic_quotes_sybase')) {
+        $warnings[] = get_string('magicquotessybase', 'error');
+    }
+
+    // Check if the host returns a usable value for the timezone identifier %z
+    $tz_count = preg_match("/[\+\-][0-9]{4}/", strftime("%z"));
+    if ($tz_count == 0 || $tz_count == FALSE) {
+        $warnings[] = get_string('timezoneidentifierunusable', 'error');
+    }
+
+    // Check file upload settings.
+    $postmax       = ini_get('post_max_size');
+    $uploadmax     = ini_get('upload_max_filesize');
+    $realpostmax   = get_real_size($postmax);
+    $realuploadmax = get_real_size($uploadmax);
+    if ($realpostmax && $realpostmax < $realuploadmax) {
+        $warnings[] = get_string('postmaxlessthanuploadmax', 'error', $postmax, $uploadmax, $postmax);
+    }
+    else if ($realpostmax && $realpostmax < 9000000) {
+        $warnings[] = get_string('smallpostmaxsize', 'error', $postmax, $postmax);
+    }
+
+    return $warnings;
 }
-?>
