@@ -27,5 +27,4 @@
 
 defined('INTERNAL') || die();
 
-$string['name'] = 'Activity log';
-?>
+$string['name'] = 'Inbox';
