@@ -34,55 +34,123 @@ require(dirname(dirname(__FILE__)) . '/init.php');
 require_once('pieforms/pieform.php');
 require_once('pieforms/pieform/elements/calendar.php');
 require_once(get_config('libroot') . 'view.php');
+require_once(get_config('libroot') . 'collection.php');
 require_once(get_config('libroot') . 'group.php');
 
-$view = new View(param_integer('id'));
-$group = $view->get('group');
-$institution = $view->get('institution');
-View::set_nav($group, $institution);
-$new = param_boolean('new');
-
-if ($new) {
-    define('TITLE', get_string('createviewstepthree', 'view'));
+$collection = null;
+if ($collectionid = param_integer('collection', null)) {
+    $collection = new Collection($collectionid);
+    $views = $collection->views();
+    if (empty($views)) {
+        $SESSION->add_error_msg(get_string('emptycollectionnoeditaccess', 'collection'));
+        redirect('/collection/views.php?id=' . $collectionid);
+    }
+    // Pick any old view, they all have the same access records.
+    $viewid = $views['views'][0]->view;
 }
 else {
-    define('TITLE', get_string('editaccessforview', 'view', $view->get('title')));
+    $viewid = param_integer('id');
 }
 
+$view = new View($viewid);
+
+if (empty($collection)) {
+    $collection = $view->get_collection();
+}
+
+define('TITLE', get_string('editaccess', 'view'));
+
+$group = $view->get('group');
+$institution = $view->get('institution');
+View::set_nav($group, $institution, true);
+
 if (!$USER->can_edit_view($view)) {
     throw new AccessDeniedException();
 }
 
-$js = '';
-if (!count_records('block_instance', 'view', $view->get('id'))) {
-    $confirmmessage = get_string('reallyaddaccesstoemptyview', 'view');
-    $js .= <<<EOF
-addLoadEvent(function() {
-    connect('editaccess_submit', 'onclick', function () {
-        var accesslistrows = getElementsByTagAndClassName('tr', null, 'accesslistitems');
-        if (accesslistrows.length > 0 && !confirm('{$confirmmessage}')) {
-            replaceChildNodes('accesslistitems', []);
-        }
-    });
-});
-EOF;
-}
-
-// @todo need a rule here that prevents stopdate being smaller than startdate
 $form = array(
     'name' => 'editaccess',
     'renderer' => 'div',
     'plugintype' => 'core',
     'pluginname' => 'view',
     'viewid' => $view->get('id'),
+    'userview' => (int) $view->get('owner'),
     'elements' => array(
         'id' => array(
             'type' => 'hidden',
             'value' => $view->get('id'),
         ),
-        'new' => array(
-            'type' => 'hidden',
-            'value' => $new,
+    )
+);
+
+// Create checkboxes to allow the user to apply these access rules to
+// any of their views/collections.
+// For institution views, force edit access of one view at a time for now.  Editing multiple
+// institution views requires doing some tricky stuff with the 'copy for new users/groups'
+// options, and there's not much room for the 'Share' tab in the admin area anyway
+if (!$institution) {
+    list($collections, $views) = View::get_views_and_collections(
+        $view->get('owner'), $group, $institution, $view->get('accessconf')
+    );
+}
+
+if (!empty($collections)) {
+    foreach ($collections as &$c) {
+        $c = array(
+            'title'        => $c['name'],
+            'value'        => $c['id'],
+            'defaultvalue' => $collectionid == $c['id'] || !empty($c['match']),
+            'views'        => $c['views'], // Keep these hanging around to check in submit function
+        );
+    }
+    $form['elements']['collections'] = array(
+        'type'         => 'checkboxes',
+        'title'        => get_string('collections', 'collection'),
+        'elements'     => $collections,
+    );
+}
+
+if (!empty($views)) {
+    foreach ($views as &$v) {
+        $v = array(
+            'title'        => $v['name'],
+            'value'        => $v['id'],
+            'defaultvalue' => $viewid == $v['id'] || !empty($v['match']),
+        );
+    }
+    $form['elements']['views'] = array(
+        'type'         => 'checkboxes',
+        'title'        => get_string('views'),
+        'elements'     => $views,
+    );
+}
+
+$allowcomments = $view->get('allowcomments');
+
+$form['elements']['accesslist'] = array(
+    'type'          => 'viewacl',
+    'allowcomments' => $allowcomments,
+    'defaultvalue'  => $view->get_access(get_string('strftimedatetimeshort')),
+);
+
+
+$form['elements']['more'] = array(
+    'type' => 'fieldset',
+    'collapsible' => true,
+    'collapsed' => true,
+    'legend' => get_string('moreoptions', 'view'),
+    'elements' => array(
+        'allowcomments' => array(
+            'type'         => 'checkbox',
+            'title'        => get_string('allowcomments','artefact.comment'),
+            'description'  => get_string('allowcommentsonview','view'),
+            'defaultvalue' => $view->get('allowcomments'),
+        ),
+        'approvecomments' => array(
+            'type'         => 'checkbox',
+            'title'        => get_string('moderatecomments', 'artefact.comment'),
+            'description'  => get_string('moderatecommentsdescription', 'artefact.comment'),
+            'defaultvalue' => $view->get('approvecomments'),
         ),
         'template' => array(
             'type'         => 'checkbox',
@@ -90,22 +158,24 @@ $form = array(
             'description'  => get_string('templatedescription', 'view'),
             'defaultvalue' => $view->get('template'),
         ),
-    )
+    ),
 );
 
+$js = '';
+
 if ($institution) {
     if ($institution == 'mahara') {
-        $form['elements']['copynewuser'] = array(
+        $form['elements']['more']['elements']['copynewuser'] = array(
             'type'         => 'checkbox',
             'title'        => get_string('copyfornewusers', 'view'),
             'description'  => get_string('copyfornewusersdescription', 'view'),
             'defaultvalue' => $view->get('template') && $view->get('copynewuser'),
         );
-        $form['elements']['copyfornewgroups'] = array(
+        $form['elements']['more']['elements']['copyfornewgroups'] = array(
             'type'         => 'html',
             'value'        => '<label>' . get_string('copyfornewgroups', 'view') . '</label>',
         );
-        $form['elements']['copyfornewgroupsdescription'] = array(
+        $form['elements']['more']['elements']['copyfornewgroupsdescription'] = array(
             'type'         => 'html',
             'value'        => '<div class="description">' . get_string('copyfornewgroupsdescription', 'view') . '</div>',
         );
@@ -118,7 +188,7 @@ if ($institution) {
             foreach (call_static_method('GroupType' . $grouptype, 'allowed_join_types', true) as $jointype) {
                 $jointypestrings[] = get_string('membershiptype.'.$jointype, 'group');
             }
-            $form['elements']['copyfornewgroups_'.$grouptype] = array(
+            $form['elements']['more']['elements']['copyfornewgroups_'.$grouptype] = array(
                 'type'         => 'checkbox',
                 'title'        => get_string('name', 'grouptype.' . $grouptype) . ' (' . join(', ', $jointypestrings) . ')',
                 'defaultvalue' => $view->get('template') && in_array($grouptype, $createfor),
@@ -128,10 +198,13 @@ if ($institution) {
         }
     }
     else {
-        $form['elements']['copynewuser'] = array(
+        require_once('institution.php');
+        $i = new Institution($institution);
+        $instname = hsc($i->displayname);
+        $form['elements']['more']['elements']['copynewuser'] = array(
             'type'         => 'checkbox',
             'title'        => get_string('copyfornewmembers', 'view'),
-            'description'  => get_string('copyfornewmembersdescription', 'view', get_field('institution', 'displayname', 'name', $institution)),
+            'description'  => get_string('copyfornewmembersdescription', 'view', $instname),
             'defaultvalue' => $view->get('template') && $view->get('copynewuser'),
         );
         $copyoptions = array('copynewuser');
@@ -166,9 +239,9 @@ function update_loggedin_access() {
 }
 addLoadEvent(function() {
     update_copy_options();
-    connect('editaccess_template', 'onchange', update_copy_options);
+    connect('editaccess_template', 'onclick', update_copy_options);
     forEach({$needsaccessstr}, function (id) {
-        connect('editaccess_'+id, 'onchange', update_loggedin_access);
+        connect('editaccess_'+id, 'onclick', update_loggedin_access);
     });
 });
 EOF;
@@ -176,48 +249,63 @@ EOF;
     $js .= "function update_loggedin_access() {}\n";
 }
 
-$form['elements']['accesslist'] = array(
-    'type'         => 'viewacl',
-    'defaultvalue' => isset($view) ? $view->get_access(get_string('strftimedatetimeshort')) : null
-);
+if (!$allowcomments) {
+    $form['elements']['more']['elements']['approvecomments']['class'] = 'hidden';
+}
+$allowcomments = json_encode((int) $allowcomments);
 
-$form['elements']['overrides'] = array(
-    'type' => 'fieldset',
-    'legend' => get_string('overridingstartstopdate', 'view'),
-    'elements' => array(
-        'description' => array(
-            'type' => 'html',
-            'value' => get_string('overridingstartstopdatesdescription', 'view'),
-        ),
-        'startdate'        => array(
-            'type'         => 'calendar',
-            'title'        => get_string('startdate','view'),
-            'defaultvalue' => isset($view) ? strtotime($view->get('startdate')) : null,
-            'caloptions'   => array(
-                'showsTime'      => true,
-                'ifFormat'       => get_string('strftimedatetimeshort'),
-            ),
-            'help'         => true,
-        ),
-        'stopdate'  => array(
-            'type'         => 'calendar',
-            'title'        => get_string('stopdate','view'),
-            'defaultvalue' => isset($view) ? strtotime($view->get('stopdate')) : null,
-            'caloptions'   => array(
-                'showsTime'      => true,
-                'ifFormat'       => get_string('strftimedatetimeshort'),
-            ),
-            'help'         => true,
-        ),
+$js .= <<<EOF
+var allowcomments = {$allowcomments};
+function update_comment_options() {
+    allowcomments = $('editaccess_allowcomments').checked;
+    if (allowcomments) {
+        removeElementClass($('editaccess_approvecomments'), 'hidden');
+        removeElementClass($('editaccess_approvecomments_container'), 'hidden');
+        forEach(getElementsByTagAndClassName(null, 'comments', 'accesslisttable'), function (elem) {
+            addElementClass(elem, 'hidden');
+        });
+    }
+    else {
+        addElementClass($('editaccess_approvecomments_container'), 'hidden');
+        forEach(getElementsByTagAndClassName(null, 'comments', 'accesslisttable'), function (elem) {
+            removeElementClass(elem, 'hidden');
+        });
+    }
+}
+addLoadEvent(function() {
+    connect('editaccess_allowcomments', 'onclick', update_comment_options);
+});
+EOF;
+
+$form['elements']['more']['elements']['overrides'] = array(
+    'type' => 'html',
+    'value' => '<strong>' . get_string('overridingstartstopdate', 'view') . '</strong>',
+    'description' => get_string('overridingstartstopdatesdescription', 'view'),
+);
+$form['elements']['more']['elements']['startdate'] = array(
+    'type'         => 'calendar',
+    'title'        => get_string('startdate','view'),
+    'description'  => get_string('datetimeformatguide'),
+    'defaultvalue' => isset($view) ? strtotime($view->get('startdate')) : null,
+    'caloptions'   => array(
+        'showsTime'      => true,
+        'ifFormat'       => get_string('strftimedatetimeshort'),
+    ),
+);
+$form['elements']['more']['elements']['stopdate'] = array(
+    'type'         => 'calendar',
+    'title'        => get_string('stopdate','view'),
+    'description'  => get_string('datetimeformatguide'),
+    'defaultvalue' => isset($view) ? strtotime($view->get('stopdate')) : null,
+    'caloptions'   => array(
+        'showsTime'      => true,
+        'ifFormat'       => get_string('strftimedatetimeshort'),
     ),
 );
 
 $form['elements']['submit'] = array(
-    'type'  => !empty($new) ? 'cancelbackcreate' : 'submitcancel',
-    'value' => !empty($new) 
-        ? array(get_string('cancel'), get_string('back','view'), get_string('save'))
-        : array(get_string('save'), get_string('cancel')),
-    'confirm' => !empty($new) ? array(get_string('confirmcancelcreatingview', 'view'), null, null) : null,
+    'type'  => 'submitcancel',
+    'value' => array(get_string('save'), get_string('cancel')),
 );
 
 if (!function_exists('strptime')) {
@@ -273,7 +361,7 @@ function ptimetotime($ptime) {
 }
 
 function editaccess_validate(Pieform $form, $values) {
-    global $institution, $group;
+    global $SESSION, $institution, $group;
     if ($institution && $values['copynewuser'] && !$values['template']) {
         $form->set_error('copynewuser', get_string('viewscopiedfornewusersmustbecopyable', 'view'));
     }
@@ -290,7 +378,7 @@ function editaccess_validate(Pieform $form, $values) {
         }
     }
     if ($values['startdate'] && $values['stopdate'] && $values['startdate'] > $values['stopdate']) {
-        $form->set_error('startdate', get_string('startdatemustbebeforestopdate', 'view'));
+        $form->set_error('startdate', get_string('newstartdatemustbebeforestopdate', 'view', 'Overriding'));
     }
     $loggedinaccess = false;
     if ($values['accesslist']) {
@@ -300,21 +388,30 @@ function editaccess_validate(Pieform $form, $values) {
                 $item['startdate'] = null;
             }
             else if (!$item['startdate'] = strptime($item['startdate'], $dateformat)) {
-                $form->set_error('accesslist', get_string('unrecogniseddateformat', 'view'));
+                $SESSION->add_error_msg(get_string('unrecogniseddateformat', 'view'));
+                $form->set_error('accesslist', '');
                 break;
             }
             if (empty($item['stopdate'])) {
                 $item['stopdate'] = null;
             }
             else if (!$item['stopdate'] = strptime($item['stopdate'], $dateformat)) {
-                $form->set_error('accesslist', get_string('invaliddate', 'view'));
+                $SESSION->add_error_msg(get_string('unrecogniseddateformat', 'view'));
+                $form->set_error('accesslist', '');
                 break;
             }
             if ($item['type'] == 'loggedin' && !$item['startdate'] && !$item['stopdate']) {
                 $loggedinaccess = true;
             }
+            $now = strptime(date('Y/m/d H:i'), $dateformat);
+            if ($item['stopdate'] && ptimetotime($now) > ptimetotime($item['stopdate'])) {
+                $SESSION->add_error_msg(get_string('newstopdatecannotbeinpast', 'view', get_string($item['type'], 'view')));
+                $form->set_error('accesslist', '');
+                break;
+            }
             if ($item['startdate'] && $item['stopdate'] && ptimetotime($item['startdate']) > ptimetotime($item['stopdate'])) {
-                $form->set_error('accesslist', get_string('startdatemustbebeforestopdate', 'view'));
+                $SESSION->add_error_msg(get_string('newstartdatemustbebeforestopdate', 'view', get_string($item['type'], 'view')));
+                $form->set_error('accesslist', '');
                 break;
             }
         }
@@ -322,31 +419,32 @@ function editaccess_validate(Pieform $form, $values) {
 
     // Must have logged in user access for copy new user/group settings.
     if (($createforgroup || ($institution && $values['copynewuser'])) && !$loggedinaccess) {
-        $form->set_error('accesslist', get_string('copynewusergroupneedsloggedinaccess', 'view'));
+        $SESSION->add_error_msg(get_string('copynewusergroupneedsloggedinaccess', 'view'));
+        $form->set_error('accesslist', '');
     }
 }
 
 function editaccess_cancel_submit() {
-    global $view, $new, $group, $institution;
-    if ($new) {
-        $view->delete();
+    global $institution, $group;
+    if (!empty($institution)) {
+        if ($institution == 'mahara') {
+            $redirecturl = '/admin/site/shareviews.php';
+        } else {
+            $redirecturl = '/view/institutionshare.php';
+        }
     }
-    if ($group) {
-        redirect('/view/groupviews.php?group='.$group);
+    else if (!empty($group)) {
+        $redirecturl = '/group/shareviews.php?group=' . $group;
     }
-    if ($institution) {
-        redirect('/view/institutionviews.php?institution='.$institution);
+    else {
+        $redirecturl = '/view/share.php';
     }
-    redirect('/view');
+    redirect($redirecturl);
 }
 
 
 function editaccess_submit(Pieform $form, $values) {
-    global $SESSION, $view, $new, $group, $institution;
-
-    if (param_boolean('back')) {
-        redirect('/view/blocks.php?id=' . $view->get('id') . '&new=' . $new);
-    }
+    global $SESSION, $institution, $collections, $views, $view;
 
     if ($values['accesslist']) {
         $dateformat = get_string('strftimedatetimeshort');
@@ -359,50 +457,75 @@ function editaccess_submit(Pieform $form, $values) {
             }
         }
     }
-    $view->set_access($values['accesslist']);
 
-    $view->set('startdate', $values['startdate']);
-    $view->set('stopdate', $values['stopdate']);
-    $istemplate = (int) $values['template'];
-    $view->set('template', $istemplate);
-    if (isset($values['copynewuser'])) {
-        $view->set('copynewuser', (int) ($istemplate && $values['copynewuser']));
-    }
-    if ($institution == 'mahara') {
-        $createfor = array();
-        foreach (group_get_grouptypes() as $grouptype) {
-            if ($istemplate && $values['copyfornewgroups_'.$grouptype]) {
-                $createfor[] = $grouptype;
-            }
+    $viewconfig = array(
+        'startdate'       => $values['startdate'],
+        'stopdate'        => $values['stopdate'],
+        'template'        => (int) $values['template'],
+        'allowcomments'   => (int) $values['allowcomments'],
+        'approvecomments' => (int) ($values['allowcomments'] && $values['approvecomments']),
+        'accesslist'      => $values['accesslist'],
+    );
+
+    $toupdate = array();
+
+    if ($institution) {
+        if (isset($values['copynewuser'])) {
+            $viewconfig['copynewuser'] = (int) ($values['template'] && $values['copynewuser']);
         }
-        $view->set('copynewgroups', $createfor);
-    }
-
-    $view->commit();
-
-    if ($values['new']) {
-        $str = get_string('viewcreatedsuccessfully', 'view');
+        if ($institution == 'mahara') {
+            $createfor = array();
+            foreach (group_get_grouptypes() as $grouptype) {
+                if ($values['template'] && $values['copyfornewgroups_'.$grouptype]) {
+                    $createfor[] = $grouptype;
+                }
+            }
+            $viewconfig['copynewgroups'] = $createfor;
+        }
+        $toupdate[] = $view->get('id');
     }
     else {
-        $str = get_string('viewaccesseditedsuccessfully', 'view');
+        if (isset($values['collections'])) {
+            foreach ($values['collections'] as $cid) {
+                if (!isset($collections[$cid])) {
+                    throw new UserException(get_string('editaccessinvalidviewset', 'view'));
+                }
+                $toupdate = array_merge($toupdate, array_keys($collections[$cid]['views']));
+            }
+        }
+    
+        foreach ($values['views'] as $viewid) {
+            if (!isset($views[$viewid])) {
+                throw new UserException(get_string('editaccessinvalidviewset', 'view'));
+            }
+            $toupdate[] = $viewid;
+        }
     }
-    $SESSION->add_ok_msg($str);
-    if ($group) {
-        redirect('/view/groupviews.php?group='.$group);
-    }
-    if ($institution) {
-        redirect('/view/institutionviews.php?institution='.$institution);
-    }
-    redirect('/view/');
 
+    if (!empty($toupdate)) {
+        View::update_view_access($viewconfig, $toupdate);
+    }
+
+    $SESSION->add_ok_msg(get_string('updatedaccessfornumviews', 'view', count($toupdate)));
+
+    if ($view->get('owner')) {
+        redirect('/view/share.php');
+    }
+    $view->post_edit_redirect();
 }
 
 $form = pieform($form);
 
-$smarty = smarty(array('tablerenderer'), array(), array('mahara' => array('From', 'To')), array('sidebars' => false));
+$smarty = smarty(
+    array('tablerenderer'),
+    array(),
+    array(
+        'mahara' => array('From', 'To', 'datetimeformatguide'),
+        'artefact.comment' => array('Comments', 'Allow', 'Moderate')
+    ),
+    array('sidebars' => false)
+);
 $smarty->assign('INLINEJAVASCRIPT', $js);
-$smarty->assign('PAGEHEADING', hsc(TITLE));
+$smarty->assign('PAGEHEADING', TITLE);
 $smarty->assign('form', $form);
 $smarty->display('view/access.tpl');
-
-?>
