@@ -33,6 +33,7 @@ define('SECTION_PAGE', 'artefact');
 
 require(dirname(dirname(__FILE__)) . '/init.php');
 require_once(get_config('libroot') . 'view.php');
+safe_require('artefact', 'comment');
 
 $artefactid = param_integer('artefact');
 $viewid     = param_integer('view');
@@ -44,30 +45,39 @@ if (!can_view_view($viewid)) {
 }
 
 if (!artefact_in_view($artefactid, $viewid)) {
-    throw new AccessDeniedException("Artefact $artefactid not in View $viewid");
+    throw new AccessDeniedException(get_string('artefactnotinview', 'error', $artefactid, $viewid));
 }
 
 // Feedback list pagination requires limit/offset params
-$limit    = param_integer('limit', 10);
-$offset   = param_integer('offset', 0);
+$limit       = param_integer('limit', 10);
+$offset      = param_integer('offset', 0);
+$showcomment = param_integer('showcomment', null);
 
 require_once(get_config('docroot') . 'artefact/lib.php');
 $artefact = artefact_instance_from_id($artefactid);
 
-// Create the "make feedback private form" now if it's been submitted
-if (param_variable('make_private_submit', null)) {
-    pieform(make_private_form(param_integer('feedback')));
+if (!$artefact->in_view_list()) {
+    throw new AccessDeniedException(get_string('artefactsonlyviewableinview', 'error'));
 }
 
-if (!$artefact->in_view_list()) {
-    throw new AccessDeniedException("Artefacts of this type are only viewable within a View");
+// Create the "make feedback private form" now if it's been submitted
+if (param_variable('make_public_submit', null)) {
+    pieform(ArtefactTypeComment::make_public_form(param_integer('comment')));
+}
+else if (param_variable('delete_comment_submit', null)) {
+    pieform(ArtefactTypeComment::delete_comment_form(param_integer('comment')));
 }
 
 define('TITLE', $artefact->display_title() . ' ' . get_string('in', 'view') . ' ' . $view->get('title'));
 
 // Render the artefact
-$options = array('viewid' => $viewid,
-                 'path' => $path);
+$options = array(
+    'viewid' => $viewid,
+    'path' => $path
+);
+if (param_integer('details', 0)) {
+    $options['metadata'] = 1;
+}
 $rendered = $artefact->render_self($options);
 $content = '';
 if (!empty($rendered['javascript'])) {
@@ -99,39 +109,70 @@ $artefactpath[] = array(
 
 
 // Feedback
-$feedback = $artefact->get_feedback($limit, $offset, $viewid);
-build_feedback_html($feedback);
+$feedback = ArtefactTypeComment::get_comments($limit, $offset, $showcomment, $view, $artefact);
 
-$javascript = <<<EOF
+$inlinejavascript = <<<EOF
 var viewid = {$viewid};
 addLoadEvent(function () {
     paginator = {$feedback->pagination_js}
 });
 EOF;
 
-$feedbackform = pieform(add_feedback_form(false));
+$javascript = array('paginator', 'viewmenu');
+$extrastylesheets = array('style/views.css');
+
+if ($artefact->get('allowcomments')) {
+    $anonfeedback = !$USER->is_logged_in() && view_has_token($viewid, get_cookie('viewaccess:'.$viewid));
+    $addfeedbackform = pieform(ArtefactTypeComment::add_comment_form(false, $artefact->get('approvecomments')));
+    $extrastylesheets[] = 'style/jquery.rating.css';
+    $javascript[] = 'jquery';
+    $javascript[] = 'jquery.rating';
+}
 $objectionform = pieform(objection_form());
+if ($notrudeform = $view->notrude_form()) {
+    $notrudeform = pieform($notrudeform);
+}
 
 $viewbeingwatched = (int)record_exists('usr_watchlist_view', 'usr', $USER->get('id'), 'view', $viewid);
 
+$headers = array('<link rel="stylesheet" type="text/css" href="' . get_config('wwwroot') . 'theme/views.css">',);
+
+$hasfeed = false;
+$feedlink = '';
+// add a link to the ATOM feed in the header if the view is public
+if($artefact->get('artefacttype') == 'blog' && $view->is_public()) {
+    $hasfeed = true;
+    $feedlink = get_config('wwwroot') . 'artefact/blog/atom.php?artefact=' .
+        $artefactid . '&view=' . $viewid;
+    $headers[] = '<link rel="alternate" type="application/atom+xml" href="' . $feedlink . '" />';
+}
+
 $smarty = smarty(
-    array('paginator', 'feedbacklist'),
-    array('<link rel="stylesheet" type="text/css" href="' . get_config('wwwroot') . 'theme/views.css">'),
+    $javascript,
+    $headers,
     array(),
     array(
-        'stylesheets' => array('style/views.css'),
+        'stylesheets' => $extrastylesheets,
         'sidebars'    => false,
     )
 );
 
 $smarty->assign('artefact', $content);
 $smarty->assign('artefactpath', $artefactpath);
-$smarty->assign('INLINEJAVASCRIPT', $javascript);
+$smarty->assign('INLINEJAVASCRIPT', $inlinejavascript);
+
+if (get_config('viewmicroheaders')) {
+    $smarty->assign('microheaders', true);
+    $smarty->assign('microheadertitle', $view->display_title(true, false));
+}
 
 $smarty->assign('viewid', $viewid);
 $smarty->assign('viewtitle', $view->get('title'));
 $smarty->assign('feedback', $feedback);
 
+$smarty->assign('hasfeed', $hasfeed);
+$smarty->assign('feedlink', $feedlink);
+
 $viewowner = $view->get('owner');
 if ($viewowner) {
     $smarty->assign('ownerlink', 'user/view.php?id=' . $viewowner);
@@ -141,11 +182,13 @@ else if ($view->get('group')) {
 }
 
 $smarty->assign('ownername', $view->formatted_owner());
-$smarty->assign('addfeedbackform', $feedbackform);
+if (isset($addfeedbackform)) {
+    $smarty->assign('enablecomments', 1);
+    $smarty->assign('anonfeedback', $anonfeedback);
+    $smarty->assign('addfeedbackform', $addfeedbackform);
+}
 $smarty->assign('objectionform', $objectionform);
-$smarty->assign('anonfeedback', !$USER->is_logged_in() && $viewid == get_view_from_token(get_cookie('viewaccess:'.$viewid)));
+$smarty->assign('notrudeform', $notrudeform);
 $smarty->assign('viewbeingwatched', $viewbeingwatched);
 
 $smarty->display('view/artefact.tpl');
-
-?>
