@@ -56,10 +56,10 @@ $form = pieform(array(
     'name' => 'deleteview',
     'autofocus' => false,
     'method' => 'post',
+    'renderer' => 'div',
     'elements' => array(
         'submit' => array(
             'type' => 'submitcancel',
-            'title' => get_string('deleteviewconfirm', 'view'),
             'value' => array(get_string('yes'), get_string('no')),
             'goto' => get_config('wwwroot') . 'view/' . $goto,
         )
@@ -67,7 +67,7 @@ $form = pieform(array(
 ));
 
 $smarty = smarty();
-$smarty->assign('PAGEHEADING', hsc(TITLE));
+$smarty->assign('PAGEHEADING', TITLE);
 $smarty->assign('form', $form);
 $smarty->display('view/delete.tpl');
 
@@ -89,4 +89,3 @@ function deleteview_submit(Pieform $form, $values) {
     }
     redirect('/view/');
 }
-?>
