@@ -32,8 +32,11 @@ define('SECTION_PLUGINNAME', 'view');
 define('SECTION_PAGE', 'view');
 
 require(dirname(dirname(__FILE__)) . '/init.php');
+
 require_once(get_config('libroot') . 'view.php');
+require_once(get_config('libroot') . 'collection.php');
 require_once('group.php');
+safe_require('artefact', 'comment');
 
 // access key for roaming teachers
 $mnettoken = $SESSION->get('mnetuser') ? param_alphanum('mt', null) : null;
@@ -45,49 +48,61 @@ if ($mnettoken) {
     if (!$viewid = get_view_from_token($mnettoken, false)) {
         throw new AccessDeniedException(get_string('accessdenied', 'error'));
     }
-    if ($mnettoken != get_cookie('mviewaccess:'.$viewid)) {
-        set_cookie('mviewaccess:'.$viewid, $mnettoken);
-    }
 }
 else if ($usertoken) {
     if (!$viewid = get_view_from_token($usertoken, true)) {
         throw new AccessDeniedException(get_string('accessdenied', 'error'));
     }
-    if ($usertoken != get_cookie('viewaccess:'.$viewid)) {
-        set_cookie('viewaccess:'.$viewid, $usertoken);
-    }
 }
 else {
     $viewid = param_integer('id');
 }
-$new = param_boolean('new');
 
-if (!can_view_view($viewid, null, $usertoken, $mnettoken)) {
+$new = param_boolean('new');
+$showmore = param_boolean('showmore');
+if (!$showmore) {
+    $showmore = 0;
+}
+
+if (!can_view_view($viewid)) {
     throw new AccessDeniedException(get_string('accessdenied', 'error'));
 }
 
 // Feedback list pagination requires limit/offset params
-$limit    = param_integer('limit', 10);
-$offset   = param_integer('offset', 0);
+$limit       = param_integer('limit', 10);
+$offset      = param_integer('offset', 0);
+$showcomment = param_integer('showcomment', null);
 
 $view = new View($viewid);
 
 // Create the "make feedback private form" now if it's been submitted
-if (param_variable('make_private_submit', null)) {
-    pieform(make_private_form(param_integer('feedback')));
+if (param_variable('make_public_submit', null)) {
+    pieform(ArtefactTypeComment::make_public_form(param_integer('comment')));
+}
+else if (param_variable('delete_comment_submit', null)) {
+    pieform(ArtefactTypeComment::delete_comment_form(param_integer('comment')));
 }
 
-$group = $view->get('group');
+$owner    = $view->get('owner');
+$viewtype = $view->get('type');
 
-$title = $view->get('title');
-define('TITLE', $title);
+if ($viewtype == 'profile' || $viewtype == 'dashboard' || $viewtype == 'grouphomepage') {
+    redirect($view->get_url());
+}
+
+define('TITLE', $view->get('title'));
 
 $submittedgroup = (int)$view->get('submittedgroup');
 if ($USER->is_logged_in() && $submittedgroup && group_user_can_assess_submitted_views($submittedgroup, $USER->get('id'))) {
     // The user is a tutor of the group that this view has
-    // been submitted to, and is entitled to release the view, and to
-    // upload an additional file when submitting feedback.
+    // been submitted to, and is entitled to release the view
     $submittedgroup = get_record('group', 'id', $submittedgroup);
+    if ($view->get('submittedtime')) {
+        $text = get_string('viewsubmittedtogroupon', 'view', get_config('wwwroot') . 'group/view.php?id=' . $submittedgroup->id, hsc($submittedgroup->name), format_date(strtotime($view->get('submittedtime'))));
+    }
+    else {
+        $text = get_string('viewsubmittedtogroup', 'view', get_config('wwwroot') . 'group/view.php?id=' . $submittedgroup->id, hsc($submittedgroup->name));
+    }
     $releaseform = pieform(array(
         'name'     => 'releaseview',
         'method'   => 'post',
@@ -97,7 +112,7 @@ if ($USER->is_logged_in() && $submittedgroup && group_user_can_assess_submitted_
         'elements' => array(
             'submittedview' => array(
                 'type'  => 'html',
-                'value' => get_string('viewsubmittedtogroup', 'view', get_config('wwwroot') . 'group/view.php?id=' . $submittedgroup->id, $submittedgroup->name),
+                'value' => $text,
             ),
             'submit' => array(
                 'type'  => 'submit',
@@ -105,11 +120,9 @@ if ($USER->is_logged_in() && $submittedgroup && group_user_can_assess_submitted_
             ),
         ),
     ));
-    $allowattachments = true;
 }
 else {
     $releaseform = '';
-    $allowattachments = false;
 }
 
 
@@ -125,62 +138,122 @@ function releaseview_submit() {
     }
     redirect(get_config('wwwroot') . 'view/view.php?id='.$view->get('id'));
 }
+
+$javascript = array('paginator', 'viewmenu', 'jquery', 'artefact/resume/resumeshowhide.js');
+$javascript = array_merge($javascript, $view->get_blocktype_javascript());
+
+$extrastylesheets = array('style/views.css');
   
-$viewbeingwatched = (int)record_exists('usr_watchlist_view', 'usr', $USER->get('id'), 'view', $viewid);
-
-$feedback = $view->get_feedback($limit, $offset);
-build_feedback_html($feedback);
-
-$anonfeedback = !$USER->is_logged_in() && ($usertoken || $viewid == get_view_from_token(get_cookie('viewaccess:'.$viewid)));
-if ($USER->is_logged_in() || $anonfeedback) {
-    $addfeedbackform = pieform(add_feedback_form($allowattachments));
+// If the view has comments turned off, tutors can still leave
+// comments if the view is submitted to their group.
+if (!empty($releaseform) || ($commenttype = $view->user_comments_allowed($USER))) {
+    $defaultprivate = !empty($releaseform);
+    $moderate = isset($commenttype) && $commenttype === 'private';
+    $addfeedbackform = pieform(ArtefactTypeComment::add_comment_form($defaultprivate, $moderate));
+    $extrastylesheets[] = 'style/jquery.rating.css';
+    $javascript[] = 'jquery.rating';
 }
 if ($USER->is_logged_in()) {
     $objectionform = pieform(objection_form());
+    if ($notrudeform = $view->notrude_form()) {
+        $notrudeform = pieform($notrudeform);
+    }
+}
+
+$viewbeingwatched = (int)record_exists('usr_watchlist_view', 'usr', $USER->get('id'), 'view', $viewid);
+
+$feedback = ArtefactTypeComment::get_comments($limit, $offset, $showcomment, $view);
+
+// Set up theme
+$viewtheme = $view->get('theme');
+if ($viewtheme && $THEME->basename != $viewtheme) {
+    $THEME = new Theme($viewtheme);
+}
+$headers = array('<link rel="stylesheet" type="text/css" href="' . get_config('wwwroot') . 'theme/views.css">');
+
+if (!$view->is_public()) {
+    $headers[] = '<meta name="robots" content="noindex">';  // Tell search engines not to index non-public views
 }
 
 $can_edit = $USER->can_edit_view($view) && !$submittedgroup && !$view->is_submitted();
 
 $smarty = smarty(
-    array('paginator', 'feedbacklist', 'artefact/resume/resumeshowhide.js'),
-    array('<link rel="stylesheet" type="text/css" href="' . get_config('wwwroot') . 'theme/views.css">'),
+    $javascript,
+    $headers,
     array(),
     array(
-        'stylesheets' => array('style/views.css'),
+        'stylesheets' => $extrastylesheets,
         'sidebars' => false,
     )
 );
 
 $javascript = <<<EOF
 var viewid = {$viewid};
+var showmore = {$showmore};
 addLoadEvent(function () {
     paginator = {$feedback->pagination_js}
 });
 EOF;
 
+// collection top navigation
+if ($collection = $view->get('collection')) {
+    $shownav = $collection->get('navigation');
+    if ($shownav) {
+        if ($views = $collection->get('views')) {
+            if (count($views['views']) > 1) {
+                $smarty->assign_by_ref('collection', array_chunk($views['views'], 5));
+            }
+        }
+    }
+}
+
 $smarty->assign('INLINEJAVASCRIPT', $javascript);
 $smarty->assign('new', $new);
 $smarty->assign('viewid', $viewid);
-$smarty->assign('viewtitle', $view->get('title'));
+$smarty->assign('viewtype', $viewtype);
 $smarty->assign('feedback', $feedback);
-
-$owner = $view->get('owner');
 $smarty->assign('owner', $owner);
 $smarty->assign('tags', $view->get('tags'));
-if ($owner) {
-    $smarty->assign('ownerlink', 'user/view.php?id=' . $owner);
-}
-else if ($group) {
-    $smarty->assign('ownerlink', 'group/view.php?id=' . $group);
-}
-if ($can_edit) {
-    $smarty->assign('can_edit', 1);
-}
-if ($USER->is_logged_in() && !empty($_SERVER['HTTP_REFERER'])) {
-    $page = get_config('wwwroot') . 'view/view.php?id=' . $viewid . ($new ? '&new=1' : '');
-    if ($_SERVER['HTTP_REFERER'] != $page) {
-        $smarty->assign('backurl', $_SERVER['HTTP_REFERER']);
+
+$smarty->assign('PAGEAUTHOR', $view->formatted_owner());
+
+if (get_config('viewmicroheaders')) {
+    $smarty->assign('microheaders', true);
+    $smarty->assign('microheadertitle', $collection ? hsc($collection->get('name')) : $view->display_title(true, false));
+
+    if ($can_edit) {
+        $smarty->assign('visitstring', $view->visit_message());
+        if ($new) {
+            $microheaderlinks = array(
+                array(
+                    'name' => get_string('back'),
+                    'url' => get_config('wwwroot') . 'view/blocks.php?id=' . $viewid . '&new=1',
+                    'type' => 'reply',
+                ),
+            );
+        }
+        else {
+            $microheaderlinks = array(
+                array(
+                    'name' => get_string('editthisview', 'view'),
+                    'image' => $THEME->get_url('images/edit.gif'),
+                    'url' => get_config('wwwroot') . 'view/blocks.php?id=' . $viewid,
+                ),
+            );
+        }
+        $smarty->assign('microheaderlinks', $microheaderlinks);
     }
+
+}
+else if ($can_edit) {
+    $smarty->assign('editurl', get_config('wwwroot') . 'view/blocks.php?id=' . $viewid . ($new ? '&new=1' : ''));
+}
+
+$title = hsc(TITLE);
+
+if (!get_config('viewmicroheaders')) {
+    $title = $collection ? hsc($collection->get('name')) : $view->display_title();
+    $smarty->assign('maintitle', $title);
 }
 
 // Provide a link for roaming teachers to return
@@ -197,19 +270,30 @@ if ($mnetviewlist = $SESSION->get('mnetviewaccess')) {
     }
 }
 
-$smarty->assign('ownername', $view->formatted_owner());
 $smarty->assign('viewdescription', $view->get('description'));
 $smarty->assign('viewcontent', $view->build_columns());
 $smarty->assign('releaseform', $releaseform);
-$smarty->assign('anonfeedback', $anonfeedback);
 if (isset($addfeedbackform)) {
+    $smarty->assign('enablecomments', 1);
     $smarty->assign('addfeedbackform', $addfeedbackform);
 }
 if (isset($objectionform)) {
     $smarty->assign('objectionform', $objectionform);
+    $smarty->assign('notrudeform', $notrudeform);
 }
 $smarty->assign('viewbeingwatched', $viewbeingwatched);
 
+if ($owner && $owner == $USER->get('id')) {
+    if ($tutorgroupdata = group_get_user_course_groups()) {
+        if (!$view->get('submittedgroup') && !$view->get('submittedhost')) {
+            $smarty->assign(
+                'view_group_submission_form',
+                view_group_submission_form($view->get('id'), $tutorgroupdata, 'view')
+            );
+        }
+    }
+}
+
 $smarty->display('view/view.tpl');
 
-?>
+mahara_log('views', "$viewid"); // Log view visits
